"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.massageGuardOptions = exports.command = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const logger_1 = require("../../logger");
const local_registry_populator_1 = require("../../registry/local-registry-populator");
const rule_registry_1 = require("../../rules-engine/registry/rule-registry");
const rules_runtime_1 = require("../../rules-engine/execution/rules-runtime");
const command_1 = require("../lint/command");
const remote_k8s_registry_1 = require("../../registry/remote-k8s-registry");
const combined_k8s_registry_1 = require("../../registry/combined-k8s-registry");
const cached_k8s_registry_1 = require("../../registry/cached-k8s-registry");
const format_1 = require("../lint/format");
const result_1 = require("../../types/result");
const COMMUNITY_RULES_PATH = 'https://raw.githubusercontent.com/kubevious/rules-library/main/index.yaml';
const myLogger = logger_1.logger.sublogger('GuardCommand');
function command(path, options) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!options.skipCommunityRules) {
            path.push(COMMUNITY_RULES_PATH);
        }
        logger_1.logger.info("[PATH] ", path);
        const lintCommandData = yield (0, command_1.command)(path, options);
        const manifestPackage = lintCommandData.manifestPackage;
        const manifestLoader = lintCommandData.manifestLoader;
        const k8sConnector = lintCommandData.k8sConnector;
        const registryPopulator = new local_registry_populator_1.LocalRegistryPopulator(logger_1.logger, lintCommandData.k8sSchemaInfo.k8sJsonSchema, manifestPackage);
        registryPopulator.process();
        const localK8sRegistry = registryPopulator.localK8sRegistry;
        // await processor.localK8sRegistry.debugOutputToDir(logger, 'local-k8s-registry');
        let remoteRegistry;
        if (k8sConnector.isUsed) {
            const myRemoteRegistry = new remote_k8s_registry_1.RemoteK8sRegistry(logger_1.logger, k8sConnector, manifestPackage);
            remoteRegistry = new cached_k8s_registry_1.CachedK8sRegistry(logger_1.logger, myRemoteRegistry);
        }
        const ruleRegistry = new rule_registry_1.RuleRegistry(logger_1.logger, manifestPackage, manifestLoader);
        if (!options.skipRemoteRules) {
            if (remoteRegistry) {
                const ruleRegistryLoadOptions = {
                    skipClusterScope: options.skipClusterScope,
                    onlySelectedNamespaces: options.areNamespacesSpecified,
                    namespaces: options.areNamespacesSpecified
                        ? options.namespaces
                        : manifestPackage.namespaces,
                    skipLibraries: false
                };
                yield ruleRegistry.loadRemotely(remoteRegistry, ruleRegistryLoadOptions);
            }
        }
        if (!options.skipLocalRules) {
            const ruleRegistryLoadOptions = {
                skipClusterScope: options.skipClusterScope,
                onlySelectedNamespaces: true,
                namespaces: options.areNamespacesSpecified
                    ? options.namespaces
                    : manifestPackage.namespaces,
                skipLibraries: false
            };
            yield ruleRegistry.loadLocally(localK8sRegistry, ruleRegistryLoadOptions);
        }
        let combinedRegistry = localK8sRegistry;
        if (remoteRegistry) {
            combinedRegistry = new combined_k8s_registry_1.CombinedK8sRegistry(logger_1.logger, [localK8sRegistry, remoteRegistry]);
        }
        let targetQueryRegistry = localK8sRegistry;
        if (options.includeRemoteTargets) {
            targetQueryRegistry = combinedRegistry;
        }
        const validatorQueryRegistry = combinedRegistry;
        let executionNamespaces = [];
        if (options.areNamespacesSpecified) {
            executionNamespaces = options.namespaces;
        }
        else {
            executionNamespaces = manifestPackage.namespaces;
        }
        const rulesRuntime = new rules_runtime_1.RulesRuntime(logger_1.logger, ruleRegistry, manifestPackage, executionNamespaces, targetQueryRegistry, validatorQueryRegistry, {
            skipRules: options.skipRules,
            onlyRules: options.onlyRules,
            skipRuleCategories: options.skipRuleCategories,
            onlyRuleCategories: options.onlyRuleCategories
        });
        yield rulesRuntime.init();
        yield rulesRuntime.execute();
        const lintResult = (0, format_1.formatResult)(lintCommandData);
        const rulesResult = rulesRuntime.exportResult();
        const severity = (0, result_1.makeObjectSeverityFromChildren)('pass', [lintResult, rulesResult]);
        return {
            severity: severity,
            manifestPackage: manifestPackage,
            k8sSchemaInfo: lintCommandData.k8sSchemaInfo,
            rulesRuntime,
            localK8sRegistry: localK8sRegistry,
            lintResult: lintResult,
            rulesResult: rulesResult
        };
    });
}
exports.command = command;
function massageGuardOptions(options) {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j;
    let areNamespacesSpecified = false;
    let namespaces = [];
    if (options.namespace) {
        areNamespacesSpecified = true;
        namespaces = [options.namespace];
    }
    else {
        if (!the_lodash_1.default.isUndefined(options.namespaces)) {
            if (the_lodash_1.default.isBoolean(options.namespaces)) {
                areNamespacesSpecified = true;
                namespaces = [];
            }
            else {
                areNamespacesSpecified = true;
                namespaces = options.namespaces;
            }
        }
    }
    return Object.assign(Object.assign({}, (0, command_1.massageLintOptions)(options)), { skipCommunityRules: (_a = options.skipCommunityRules) !== null && _a !== void 0 ? _a : false, includeRemoteTargets: (_b = options.includeRemoteTargets) !== null && _b !== void 0 ? _b : false, skipLocalRules: (_c = options.skipLocalRules) !== null && _c !== void 0 ? _c : false, skipRemoteRules: (_d = options.skipRemoteRules) !== null && _d !== void 0 ? _d : false, areNamespacesSpecified: areNamespacesSpecified, namespace: undefined, namespaces: namespaces, skipClusterScope: (_e = options.skipClusterScope) !== null && _e !== void 0 ? _e : false, skipRuleLibraries: false, skipRules: (_f = options.skipRules) !== null && _f !== void 0 ? _f : [], onlyRules: (_g = options.onlyRules) !== null && _g !== void 0 ? _g : [], skipRuleCategories: (_h = options.skipRuleCategories) !== null && _h !== void 0 ? _h : [], onlyRuleCategories: (_j = options.onlyRuleCategories) !== null && _j !== void 0 ? _j : [] });
}
exports.massageGuardOptions = massageGuardOptions;
//# sourceMappingURL=command.js.map