"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outputGuardSummary = exports.output = void 0;
const output_1 = require("../lint/output");
const screen_1 = require("../../screen");
const manifest_1 = require("../../screen/manifest");
function output(result, detailed) {
    detailed = detailed !== null && detailed !== void 0 ? detailed : false;
    (0, output_1.output)(result.lintResult, detailed, {
        skipSummary: true,
        skipResult: true,
    });
    outputRuleEngineResult(result.rules, detailed, 0);
    outputGuardSummary(result);
    if (!detailed) {
        (0, screen_1.print)();
        (0, screen_1.printInfoLine)(`Run with --detailed to see all sources and manifests`);
    }
    (0, screen_1.printProcessStatus)(result.severity, 'Guard');
}
exports.output = output;
function outputGuardSummary(result) {
    (0, screen_1.printSectionTitle)('Summary');
    const lintCounters = result.lintResult.counters;
    const guardCounters = result.counters;
    (0, screen_1.print)(`${screen_1.OBJECT_ICONS.source.get()} Sources: ${lintCounters.sources.total}`, 4);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.failed, 'Sources with Errors', lintCounters.sources.withErrors);
    (0, screen_1.print)(`${screen_1.OBJECT_ICONS.manifest.get()} Manifests: ${lintCounters.manifests.total}`, 4);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.passed, 'Valid Manifests', lintCounters.manifests.passed);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.failed, 'Manifests with Errors', lintCounters.manifests.withErrors);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.warning, 'Manifests with Warnings', lintCounters.manifests.withWarnings);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.passed, 'Manifests Processed for Rules', guardCounters.manifests.processed);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.failed, 'Manifests with Rule Errors', guardCounters.manifests.withErrors);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.warning, 'Manifests with Rule Warnings', guardCounters.manifests.withWarnings);
    (0, screen_1.print)(`${screen_1.OBJECT_ICONS.rule.get()} Rules: ${guardCounters.rules.total}`, 4);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.passed, 'Rules Passed', guardCounters.rules.passed);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.failed, 'Rules Failed', guardCounters.rules.failed);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.error, 'Rules with Errors', guardCounters.rules.withErrors);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.warning, 'Rules with Warnings', guardCounters.rules.withWarnings);
}
exports.outputGuardSummary = outputGuardSummary;
function outputRuleEngineResult(rules, detailed, indent) {
    const nestedIndent = indent + 3;
    (0, screen_1.printSectionTitle)('Rules', indent);
    if (rules.rules.length === 0) {
        (0, screen_1.printWarningLine)('No Rules found.', nestedIndent);
    }
    else {
        if (!detailed && (rules.severity == 'pass')) {
            (0, screen_1.printPassLine)('No issues with rules.', nestedIndent);
        }
        else {
            for (const rule of rules.rules) {
                outputRuleResult(rule, detailed, nestedIndent);
            }
        }
    }
    (0, screen_1.print)();
}
function outputRuleResult(rule, detailed, indent) {
    if (!detailed) {
        if (rule.ruleSeverity === 'pass') {
            return;
        }
    }
    const nestedIndent = indent + 3;
    if (rule.namespace) {
        (0, screen_1.print)(`${screen_1.OBJECT_ICONS.rule.get()} [${rule.ruleManifest.kind}] Namespace: ${rule.namespace}, ${rule.ruleManifest.name}`, indent);
    }
    else {
        (0, screen_1.print)(`${screen_1.OBJECT_ICONS.rule.get()} [${rule.ruleManifest.kind}] ${rule.ruleManifest.name}`, indent);
    }
    if (rule.ruleCategories.length > 0) {
        (0, screen_1.print)(rule.ruleCategories.map(x => `${screen_1.OBJECT_ICONS.ruleCategory.get()} ${x}`).join(' '), nestedIndent);
    }
    (0, manifest_1.outputManifestResultSources)(rule.ruleManifest, nestedIndent, { hideSeverityIcon: true });
    if (rule.isSkipped) {
        (0, screen_1.printInactivePassLine)('Rule skipped.', nestedIndent);
    }
    else {
        if (!rule.compiled) {
            (0, screen_1.printFailLine)(`Failed to compile`, nestedIndent);
        }
        (0, manifest_1.outputMessages)(rule.ruleManifest, nestedIndent);
        if (rule.pass && rule.compiled) {
            if (rule.passed.length > 0) {
                (0, screen_1.printPassLine)('Rule passed', nestedIndent);
            }
            else {
                (0, screen_1.printInactivePassLine)('Rule passed. No manifests found to check.', nestedIndent);
            }
        }
    }
    if (!rule.pass) {
        (0, screen_1.printFailLine)('Rule failed', nestedIndent);
    }
    if (rule.passed.length > 0) {
        (0, screen_1.printSubTitle)('Passed:', nestedIndent);
        for (const manifest of rule.passed) {
            (0, manifest_1.outputManifestResult)(manifest, detailed, nestedIndent + 3);
        }
    }
    if (rule.violations.length > 0) {
        (0, screen_1.printSubTitle)('Violations:', nestedIndent);
        for (const violation of rule.violations) {
            (0, manifest_1.outputManifestResult)(violation, detailed, nestedIndent + 3);
        }
    }
    (0, screen_1.print)();
}
//# sourceMappingURL=output.js.map