"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.massageIndexOptions = exports.command = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const logger_1 = require("../../logger");
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const command_1 = require("../guard/command");
const kubevious_1 = require("../../types/kubevious");
const yaml_1 = __importDefault(require("yaml"));
const path_2 = require("../../utils/path");
const screen_1 = require("../../screen");
function command(dir, options) {
    var _a, _b, _c;
    return __awaiter(this, void 0, void 0, function* () {
        logger_1.logger.info("[Dir] ", dir);
        const guardResult = yield (0, command_1.command)([dir], {
            ignoreUnknown: true,
            ignoreNonK8s: true,
            stream: false,
            skipApplyCrds: false,
            liveK8s: false,
            k8sSkipTlsVerify: false,
            includeRemoteTargets: false,
            skipLocalRules: false,
            skipRemoteRules: true,
            areNamespacesSpecified: false,
            namespaces: [],
            skipClusterScope: false,
            skipCommunityRules: true,
            skipRuleLibraries: true,
            ignorePatterns: [],
            skipRules: [],
            onlyRules: [],
            skipRuleCategories: [],
            onlyRuleCategories: [],
        });
        const manifestPackage = guardResult.manifestPackage;
        const rules = guardResult.localK8sRegistry.query({
            apiName: kubevious_1.KUBEVIOUS_API_NAME,
            kind: kubevious_1.KubeviousKinds.ClusterRule
        });
        const libraryLocationDict = {};
        for (const rule of rules) {
            const ruleConfig = rule.config.spec;
            logger_1.logger.info("LIBRARY RULE: %s", rule.idKey);
            const name = rule.id.name;
            const summary = the_lodash_1.default.trim((_a = ruleConfig.summary) !== null && _a !== void 0 ? _a : "");
            const libraryRule = {
                title: (summary.length > 0) ? summary : name,
                name: name,
                path: (0, path_2.makeRelativePath)(rule.source.id.path, dir),
                location: (0, path_2.makeRelativePath)(path_1.default.dirname(rule.source.id.path), dir),
                category: (0, path_2.makeRelativePath)(path_1.default.dirname(rule.source.id.path), dir),
                summary: summary,
                description: the_lodash_1.default.trim((_b = ruleConfig.description) !== null && _b !== void 0 ? _b : ""),
                categories: (_c = ruleConfig.categories) !== null && _c !== void 0 ? _c : [],
                ruleSpec: ruleConfig,
            };
            if (!libraryLocationDict[libraryRule.location]) {
                libraryLocationDict[libraryRule.location] = {
                    name: libraryRule.location,
                    count: 0,
                    rules: []
                };
            }
            libraryLocationDict[libraryRule.location].rules.push(libraryRule);
        }
        const library = {
            count: the_lodash_1.default.sum(the_lodash_1.default.values(libraryLocationDict).map(x => x.rules.length)),
            locationCount: the_lodash_1.default.keys(libraryLocationDict).length,
            locations: the_lodash_1.default.chain(libraryLocationDict)
                .values()
                .orderBy(x => x.name)
                .value(),
        };
        for (const location of library.locations) {
            location.count = location.rules.length;
            location.rules = the_lodash_1.default.orderBy(location.rules, x => x.name);
        }
        const libraryObject = {
            apiVersion: `${kubevious_1.KUBEVIOUS_API_NAME}/${kubevious_1.KUBEVIOUS_API_VERSION}`,
            kind: kubevious_1.KubeviousKinds.Library,
            metadata: {
                name: options.name
            },
            spec: {
                rules: []
            }
        };
        for (const location of library.locations) {
            for (const rule of location.rules) {
                libraryObject.spec.rules.push({
                    name: rule.name,
                    path: rule.path,
                    location: rule.location,
                    summary: rule.summary,
                    categories: rule.categories
                });
            }
        }
        libraryObject.spec.rules = the_lodash_1.default.orderBy(libraryObject.spec.rules, [x => x.name, x => x.path]);
        const libraryFilePath = path_1.default.join(dir, 'index.yaml');
        const success = guardResult.severity == 'pass' || guardResult.severity == 'warning';
        if (success) {
            yield fs_1.promises.writeFile(libraryFilePath, yaml_1.default.stringify(libraryObject, {
                toStringDefaults: {
                    indent: 2,
                    indentSeq: false
                }
            }));
            yield setupDocs(dir, library);
        }
        return {
            success,
            manifestPackage,
            guardCommandData: guardResult,
            libraryDir: dir,
            libraryPath: libraryFilePath,
            library: library,
        };
    });
}
exports.command = command;
function massageIndexOptions(options) {
    var _a;
    return {
        name: (_a = options.name) !== null && _a !== void 0 ? _a : 'library'
    };
}
exports.massageIndexOptions = massageIndexOptions;
const README_BEGIN = '[//]: # "BEGIN_RULES_DESCRIPTION"';
const README_END = '[//]: # "END_RULES_DESCRIPTION"';
function setupDocs(dir, library) {
    return __awaiter(this, void 0, void 0, function* () {
        const readmePath = path_1.default.join(dir, 'README.md');
        if (!(0, fs_1.existsSync)(readmePath)) {
            return;
        }
        let contents = (yield fs_1.promises.readFile(readmePath)).toString();
        const beginIndex = contents.indexOf(README_BEGIN);
        logger_1.logger.info("[beginIndex] %s", beginIndex);
        if (beginIndex == -1) {
            return;
        }
        const endIndex = contents.indexOf(README_END);
        logger_1.logger.info("[endIndex] %s", endIndex);
        if (endIndex == -1) {
            return;
        }
        const deleteStartIndex = beginIndex + README_BEGIN.length;
        if (endIndex <= deleteStartIndex) {
            return;
        }
        contents =
            contents.substring(0, deleteStartIndex) +
                "\n" +
                generateMDDocs(library) +
                "\n" +
                contents.substring(endIndex);
        yield fs_1.promises.writeFile(readmePath, contents);
    });
}
function generateMDDocs(library) {
    let contents = '';
    contents += '\n';
    contents += '[//]: # "!!! DO NOT EDIT. AUTO-GENERATED WITH:"\n';
    contents += '[//]: # "$ kubevious index-library ."\n';
    contents += '[//]: # "OR PRE-COMMIT HOOK"\n';
    contents += '[//]: # "$ kubevious install-git-hook rule-library ."\n';
    contents += '\n';
    contents += `Total Rules: ${library.count}`;
    contents += '\n';
    contents += `### Locations:`;
    contents += '\n';
    for (const location of library.locations) {
        contents += `- [${screen_1.OBJECT_ICONS.ruleLocation.get()} ${the_lodash_1.default.toUpper(location.name)} (${location.count})](#-${makeMdLink(location.name)})`;
        contents += '\n';
    }
    contents += `### Rules:`;
    contents += '\n';
    for (const location of library.locations) {
        contents += `#### ${screen_1.OBJECT_ICONS.ruleLocation.get()} ${the_lodash_1.default.toUpper(location.name)}`;
        contents += '\n';
        for (const rule of location.rules) {
            contents += `${screen_1.OBJECT_ICONS.rule.get()} **[${rule.title}](${rule.path})**`;
            contents += '\n';
            if (rule.categories.length > 0) {
                contents += '- ' + rule.categories.map(x => `${screen_1.OBJECT_ICONS.ruleCategory.get()} ${x}`).join(' ');
                contents += '\n';
            }
            if (rule.description.length > 0) {
                contents += rule.description;
                contents += '\n';
            }
            contents += '\n';
        }
    }
    return contents;
}
function makeMdLink(str) {
    str = the_lodash_1.default.toLower(str);
    str = str.replace(/\s/g, '-');
    str = str.replace(/\//g, '');
    return str;
}
//# sourceMappingURL=command.js.map