"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.command = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const logger_1 = require("../../logger");
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const yaml_1 = __importDefault(require("yaml"));
const release_1 = require("../../utils/release");
const logger = logger_1.logger.sublogger('InstallGitHookCmd');
const HOOK_REPO = 'https://github.com/kubevious/cli';
function command(origPath, options) {
    var _a;
    return __awaiter(this, void 0, void 0, function* () {
        const repoPath = path_1.default.resolve(origPath !== null && origPath !== void 0 ? origPath : '.');
        const result = {
            success: true,
            steps: [],
            repoPath: repoPath,
            preCommitConfigPath: path_1.default.join(repoPath, '.pre-commit-config.yaml'),
            hook: {
                repo: HOOK_REPO,
                id: options.hook,
            },
            errors: [],
        };
        logger.info("repoPath: %s", result.repoPath);
        logger.info("preCommitConfigPath: %s", result.preCommitConfigPath);
        if (!(yield checkGitRepoPath(result))) {
            result.success = false;
            result.steps.push({ name: `Repository: ${result.repoPath}`, success: false });
            return result;
        }
        result.steps.push({ name: `Repository: ${result.repoPath}`, success: true });
        result.steps.push({ name: `PreCommit Config File: ${result.preCommitConfigPath}`, success: true });
        result.steps.push({ name: `Hook Repo: ${result.hook.repo}`, success: true });
        result.steps.push({ name: `Hook ID: ${result.hook.id}`, success: true });
        let configSpec = { repos: [] };
        if ((0, fs_1.existsSync)(result.preCommitConfigPath)) {
            logger.info("Loading from: %s...", result.preCommitConfigPath);
            const contents = (yield fs_1.promises.readFile(result.preCommitConfigPath)).toString();
            configSpec = yaml_1.default.parseDocument(contents).toJSON();
        }
        logger.info("PreCommitHookConfig: ", configSpec);
        let hookRepoSpec = the_lodash_1.default.find(configSpec.repos, x => x.repo === HOOK_REPO);
        if (!hookRepoSpec) {
            hookRepoSpec = {
                repo: HOOK_REPO
            };
            configSpec.repos.push(hookRepoSpec);
        }
        hookRepoSpec.rev = 'HEAD';
        hookRepoSpec.hooks = (_a = hookRepoSpec.hooks) !== null && _a !== void 0 ? _a : [];
        if (!the_lodash_1.default.find(hookRepoSpec.hooks, x => x.id === options.hook)) {
            hookRepoSpec.hooks.push({
                id: options.hook
            });
        }
        try {
            const tag = yield (0, release_1.getLatestReleaseTag)();
            hookRepoSpec.rev = tag;
        }
        catch (reason) {
            logger.info("Failed to fetch release tag. ", reason);
            result.success = false;
            result.errors.push('Failed to fetch latest release tag.');
            if (reason.message) {
                result.errors.push(reason.message);
            }
            return result;
        }
        {
            const contents = yaml_1.default.stringify(configSpec, {
                toStringDefaults: {
                    indent: 2,
                    indentSeq: true
                }
            });
            yield fs_1.promises.writeFile(result.preCommitConfigPath, contents);
        }
        return result;
    });
}
exports.command = command;
function checkGitRepoPath(result) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!(0, fs_1.existsSync)(result.repoPath)) {
            result.errors.push("Directory not found.");
            return false;
        }
        try {
            const stats = yield fs_1.promises.lstat(result.repoPath);
            if (!stats.isDirectory()) {
                result.errors.push("Doesn't look like a directory.");
                return false;
            }
        }
        catch (_a) {
            result.success = false;
            result.errors.push("Doesn't look like a directory.");
            return false;
        }
        try {
            const stats = yield fs_1.promises.lstat(path_1.default.join(result.repoPath, '.git'));
            if (!stats.isDirectory()) {
                result.errors.push("Doesn't look like a GIT repo.");
                return false;
            }
        }
        catch (_b) {
            result.errors.push("Doesn't look like a GIT repo.");
            return false;
        }
        return true;
    });
}
//# sourceMappingURL=command.js.map