"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outputLintSummary = exports.output = void 0;
const screen_1 = require("../../screen");
const manifest_1 = require("../../screen/manifest");
function output(result, detailed, params) {
    var _a, _b;
    params = params !== null && params !== void 0 ? params : {};
    params.skipSummary = (_a = params.skipSummary) !== null && _a !== void 0 ? _a : false;
    params.skipResult = (_b = params.skipResult) !== null && _b !== void 0 ? _b : false;
    if (!result.foundK8sVersion) {
        (0, screen_1.printFailLine)(`Failed to find Kubernetes Version ${result.targetK8sVersion}`);
    }
    else {
        if (!result.foundExactK8sVersion) {
            (0, screen_1.printWarningLine)(`Could not find requested Kubernetes Version: ${result.targetK8sVersion}`);
        }
    }
    (0, screen_1.printInfoLine)(`Linting against Kubernetes Version: ${result.selectedK8sVersion}`);
    (0, screen_1.print)();
    (0, manifest_1.outputManifestPackageResultSources)(result.packageResult, detailed);
    (0, manifest_1.outputManifestPackageResultManifests)(result.packageResult, detailed);
    if (!params.skipSummary) {
        outputLintSummary(result);
    }
    if (!params.skipResult) {
        if (!detailed) {
            (0, screen_1.print)();
            (0, screen_1.printInfoLine)(`Run with --detailed to see all sources and manifests`);
        }
        (0, screen_1.printProcessStatus)(result.severity, 'Lint');
    }
}
exports.output = output;
function outputLintSummary(result) {
    (0, screen_1.printSectionTitle)('Summary');
    const lintCounters = result.counters;
    (0, screen_1.print)(`${screen_1.OBJECT_ICONS.source.get()} Sources: ${lintCounters.sources.total}`, 4);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.failed, 'Sources with Errors', lintCounters.sources.withErrors);
    (0, screen_1.print)(`${screen_1.OBJECT_ICONS.manifest.get()} Manifests: ${lintCounters.manifests.total}`, 4);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.passed, 'Valid Manifests', lintCounters.manifests.passed);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.failed, 'Manifests with Errors', lintCounters.manifests.withErrors);
    (0, screen_1.printSummaryCounter)(screen_1.STATUS_ICONS.warning, 'Manifests with Warnings', lintCounters.manifests.withWarnings);
}
exports.outputLintSummary = outputLintSummary;
//# sourceMappingURL=output.js.map