"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommandBuilder = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const logger_1 = require("../logger");
class CommandBuilder {
    constructor() {
    }
    perform(action) {
        this._action = action;
        return this;
    }
    format(format) {
        this._format = format;
        return this;
    }
    output(output) {
        this._output = output;
        return this;
    }
    decideSuccess(decideSuccess) {
        this._decideSuccess = decideSuccess;
        return this;
    }
    build() {
        return (...args) => {
            // logger.info("ARG LENGTH: %s", args.length);
            // logger.info("args: ", args);
            const options = the_lodash_1.default.last(the_lodash_1.default.dropRight(args)) || {};
            logger_1.logger.info("OPTIONS: ", options);
            let myResult = undefined;
            return Promise.resolve(null)
                .then(() => {
                if (!this._action) {
                    throw new Error("Action not specified");
                }
                return this._action(...args);
            })
                .then((data) => {
                if (!this._format) {
                    throw new Error("Format not specified");
                }
                return this._format(data);
            })
                .then((result) => {
                var _a;
                myResult = result;
                if (options.json) {
                    console.log(JSON.stringify(result, null, 4));
                }
                else {
                    if (this._output) {
                        return this._output(result, (_a = options.detailed) !== null && _a !== void 0 ? _a : false);
                    }
                }
            })
                .then(() => {
                if (this._decideSuccess) {
                    const exitCode = this._decideSuccess(myResult);
                    if (exitCode !== 0) {
                        process.exit(exitCode);
                    }
                }
            })
                .catch(reason => {
                console.log(`Error executing command. ${reason === null || reason === void 0 ? void 0 : reason.message}`);
                console.log(reason);
                process.exit(111);
            })
                .then(() => { });
        };
    }
}
exports.CommandBuilder = CommandBuilder;
//# sourceMappingURL=command-action.js.map