"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputSourceExtractor = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const the_promise_1 = require("the-promise");
const fs = __importStar(require("fs"));
const original_source_1 = require("../input/original-source");
class InputSourceExtractor {
    constructor(logger, options) {
        this._originalSources = {};
        this._logger = logger.sublogger('InputSourcesExtractor');
        this._options = options;
        this._ignorePatterns = the_lodash_1.default.clone(options.ignorePatterns);
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this._options.gitignore) {
                yield this.loadGitIgnore(this._options.gitignore);
            }
        });
    }
    get sources() {
        return the_lodash_1.default.flatten(this.originalSources.map(x => x.sources));
    }
    get originalSources() {
        return the_lodash_1.default.values(this._originalSources);
    }
    addMany(fileOrPatternOrUrls) {
        for (const x of fileOrPatternOrUrls) {
            this.addSingle(x);
        }
    }
    addSingle(fileOrPatternOrUrl) {
        this._logger.info('[addSingle] %s', fileOrPatternOrUrl);
        const key = fileOrPatternOrUrl;
        if (this._originalSources[key]) {
            return;
        }
        const orignalSource = new original_source_1.OriginalSource(fileOrPatternOrUrl, {
            ignorePatterns: this._ignorePatterns
        });
        this._originalSources[key] = orignalSource;
    }
    extractSources() {
        return __awaiter(this, void 0, void 0, function* () {
            yield the_promise_1.MyPromise.serial(this.originalSources, (x) => Promise.resolve(x.extractInputSources()));
        });
    }
    reconcile() {
        this._logger.info('[reconcile] BEGIN');
        this.debugOutput();
        for (const originalSource of this.originalSources) {
            originalSource.reconcile();
        }
        this._logger.info('[reconcile] END');
        this.debugOutput();
    }
    debugOutput() {
        this._logger.info('[InputSourceExtractor] BEGIN');
        for (const originalSource of this.originalSources) {
            originalSource.debugOutput();
        }
        this._logger.info('[InputSourceExtractor] END');
    }
    loadGitIgnore(gitIgnorePath) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const contents = yield fs.promises.readFile(gitIgnorePath, 'utf8');
                let lines = contents.split('\n');
                lines = lines.map(x => the_lodash_1.default.trim(x));
                lines = lines.filter(x => x.length > 0);
                lines = lines.filter(x => !the_lodash_1.default.startsWith(x, '#'));
                this._ignorePatterns = the_lodash_1.default.concat(this._ignorePatterns, lines);
            }
            catch (reason) {
                throw new Error(`Failed to load gitignore from ${gitIgnorePath}`);
            }
        });
    }
}
exports.InputSourceExtractor = InputSourceExtractor;
//# sourceMappingURL=input-source-extractor.js.map