"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.InputSourceKind = exports.InputSource = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const Path = __importStar(require("path"));
const logger_1 = require("../logger");
const path_1 = require("../utils/path");
const logger = logger_1.rootLogger.sublogger("InputSource");
class InputSource {
    constructor(originalSource, kind, path) {
        this._isSkipped = false;
        this._isLoaded = false;
        this._preprocessor = null;
        logger.info("[construct] kind: %s. path: %s. orig: %s", kind, path, originalSource.originalPath);
        this._originalSource = originalSource;
        this._kind = kind;
        this._path = path;
        this._suffixes = originalSource.suffixes;
        this._key = the_lodash_1.default.stableStringify([this._kind, this._path]);
        if (kind === InputSourceKind.helm) {
            this._file = "";
            this._dir = "";
        }
        else {
            this._file = Path.basename(path);
            this._dir = makeDirStr(Path.dirname(path));
        }
        originalSource.includeRawSource(this);
    }
    get originalSource() {
        return this._originalSource;
    }
    get key() {
        return this._key;
    }
    get kind() {
        return this._kind;
    }
    get path() {
        return this._path;
    }
    get suffixes() {
        return this._suffixes;
    }
    get file() {
        return this._file;
    }
    get dir() {
        return this._dir;
    }
    get isLoaded() {
        return this._isLoaded;
    }
    set isLoaded(value) {
        this._isLoaded = value;
    }
    get isSkipped() {
        return this._isSkipped;
    }
    set isSkipped(value) {
        this._isSkipped = value;
    }
    get preprocessor() {
        return this._preprocessor;
    }
    get isPreprocessor() {
        return the_lodash_1.default.isNotNullOrUndefined(this._preprocessor);
    }
    checkPreprocessor() {
        if (this.kind === 'helm') {
            this._preprocessor = 'helm';
            return;
        }
        if (this.file === 'kustomization.yaml') {
            this._preprocessor = 'kustomize';
        }
        else if (this.file === 'Chart.yaml') {
            this._preprocessor = 'helm';
        }
    }
    static makeFromPath(originalSource, path) {
        const parentDir = (0, path_1.getParentDir)(originalSource.path);
        path = (0, path_1.resolvePath)(path, parentDir);
        let kind = InputSourceKind.file;
        if ((0, path_1.isWebPath)(path)) {
            kind = InputSourceKind.web;
        }
        return new InputSource(originalSource, kind, path);
    }
}
exports.InputSource = InputSource;
var InputSourceKind;
(function (InputSourceKind) {
    InputSourceKind["file"] = "file";
    InputSourceKind["web"] = "web";
    InputSourceKind["helm"] = "helm";
})(InputSourceKind = exports.InputSourceKind || (exports.InputSourceKind = {}));
function makeDirStr(str) {
    if ((str.length > 0) && str[str.length - 1] != "/") {
        str += "/";
    }
    return str;
}
//# sourceMappingURL=input-source.js.map