"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OriginalSource = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const input_source_1 = require("./input-source");
const logger_1 = require("../logger");
const fast_glob_1 = __importDefault(require("fast-glob"));
const fs = __importStar(require("fs"));
const Path = __importStar(require("path"));
const utils_1 = require("./utils");
class OriginalSource {
    constructor(origPath, options) {
        this._logger = logger_1.logger.sublogger("OriginalSource");
        this._isExtracted = false;
        this._sources = {};
        this._allSources = {};
        this._reconcilerDirsToDelete = {};
        this._options = options !== null && options !== void 0 ? options : {};
        this._originalPath = origPath;
        const parsed = (0, utils_1.parseUserInputPath)(origPath);
        this._kind = parsed.kind;
        this._path = parsed.path;
        this._suffixes = parsed.suffixes;
    }
    get kind() {
        return this._kind;
    }
    get originalPath() {
        return this._originalPath;
    }
    get path() {
        return this._path;
    }
    get suffixes() {
        return this._suffixes;
    }
    get sources() {
        return the_lodash_1.default.values(this._sources);
    }
    get hasAnyInput() {
        return the_lodash_1.default.keys(this._allSources).length > 0;
    }
    extractInputSources() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this._isExtracted) {
                return;
            }
            this._isExtracted = true;
            if (this.kind === 'file') {
                yield this._addFromFileOrPattern();
            }
            else if (this.kind === 'web') {
                input_source_1.InputSource.makeFromPath(this, this.path);
            }
            else if (this.kind === 'helm') {
                new input_source_1.InputSource(this, input_source_1.InputSourceKind.helm, this.path);
            }
        });
    }
    reconcile() {
        this._reconcilerDirsToDelete = {};
        for (const source of the_lodash_1.default.values(this._sources)) {
            source.checkPreprocessor();
            if (source.isPreprocessor) {
                this._includePreprocessorSource(source);
            }
        }
        for (const dir of the_lodash_1.default.keys(this._reconcilerDirsToDelete)) {
            for (const source of the_lodash_1.default.values(this._sources)) {
                if (source.dir.startsWith(dir)) {
                    source.isSkipped = true;
                    delete this._sources[source.key];
                }
            }
        }
        for (const source of the_lodash_1.default.flatten(the_lodash_1.default.values(this._reconcilerDirsToDelete))) {
            this.includeRawSource(source);
        }
    }
    _addFromFileOrPattern() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            // this._logger.info("[_addFromFileOrPattern] fileOrPattern: %s", fileOrPattern);
            const pattern = this._makeSearchPattern(this.path);
            this._logger.info('[_addFromFileOrPattern] pattern: %s', pattern);
            if (!pattern) {
                return;
            }
            const ignorePatterns = (_a = this._options.ignorePatterns) !== null && _a !== void 0 ? _a : [];
            const files = yield (0, fast_glob_1.default)(pattern, {
                onlyFiles: true,
                absolute: true,
                ignore: ignorePatterns
            });
            // this._logger.info("[_addFromFileOrPattern] files: %s", files);
            for (const file of files) {
                input_source_1.InputSource.makeFromPath(this, file);
            }
        });
    }
    _includePreprocessorSource(source) {
        for (const parentDir of the_lodash_1.default.keys(this._reconcilerDirsToDelete)) {
            if (source.dir.startsWith(parentDir)) {
                return;
            }
            if (parentDir.startsWith(source.dir)) {
                delete this._reconcilerDirsToDelete[parentDir];
            }
        }
        if (!this._reconcilerDirsToDelete[source.dir]) {
            this._reconcilerDirsToDelete[source.dir] = [];
        }
        this._reconcilerDirsToDelete[source.dir].push(source);
        return true;
    }
    _makeSearchPattern(fileOrPattern) {
        if (fs.existsSync(fileOrPattern)) {
            const stats = fs.statSync(fileOrPattern);
            if (stats.isDirectory()) {
                return Path.join(fileOrPattern, '**/*.{yaml,yml}');
            }
            if (stats.isFile()) {
                return fileOrPattern;
            }
        }
        else {
            return fileOrPattern;
        }
        return null;
    }
    includeRawSource(source) {
        source.isSkipped = false;
        this._sources[source.key] = source;
        this._allSources[source.key] = source;
    }
    debugOutput() {
        this._logger.info('[OrigSource] => %s :: %s', this.kind, this.path);
        if (this.suffixes.length > 0) {
            this._logger.info('              > SUFFIXES: %s', JSON.stringify(this.suffixes));
        }
        for (const source of the_lodash_1.default.values(this._allSources)) {
            if (source.isSkipped) {
                this._logger.info('              > %s [SKIPPED]', source.key);
            }
            else {
                this._logger.info('              > %s', source.key);
            }
        }
    }
}
exports.OriginalSource = OriginalSource;
//# sourceMappingURL=original-source.js.map