"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sClusterConnector = void 0;
const k8s_super_client_1 = require("k8s-super-client");
const spinner_1 = require("../screen/spinner");
class K8sClusterConnector {
    constructor(logger) {
        this._client = null;
        this._isUsed = false;
        this._isConnected = false;
        this._logger = logger.sublogger('K8sApiSchemaFetcher');
    }
    get isUsed() {
        return this._isUsed;
    }
    get isConnected() {
        return this._isConnected;
    }
    get client() {
        return this._client;
    }
    setup(connect, kubeconfigpath, k8sSkipTlsVerify) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!connect) {
                return Promise.resolve();
            }
            this._isUsed = true;
            const spinner = (0, spinner_1.spinOperation)('Connecting to K8s Cluster...');
            const skipAPIFetch = false; // true
            return Promise.resolve()
                .then(() => {
                const connectParams = {
                    skipAPIFetch: skipAPIFetch,
                    skipTLSVerify: k8sSkipTlsVerify
                };
                const k8sLogger = this._logger.sublogger('k8s');
                if (kubeconfigpath) {
                    this._logger.info("[fetchRemote] path: %s", kubeconfigpath);
                    return (0, k8s_super_client_1.connectRemoteCluster)(k8sLogger, kubeconfigpath, undefined, connectParams);
                }
                else {
                    return (0, k8s_super_client_1.connectDefaultRemoteCluster)(k8sLogger, connectParams);
                }
            })
                .then(client => {
                spinner.complete('Connected to K8s Cluster.');
                this._logger.info("Connected.");
                this._isConnected = true;
                this._client = client;
            })
                .catch(reason => {
                const errorMsg = `Could not connect to Kubernetes cluster. ${reason === null || reason === void 0 ? void 0 : reason.message}`;
                spinner.fail(errorMsg);
            });
        });
    }
}
exports.K8sClusterConnector = K8sClusterConnector;
//# sourceMappingURL=k8s-cluster-connector.js.map