"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculateRuleEngineCounters = exports.calculateManifestPackageCounters = void 0;
const logger_1 = require("../logger");
const myLogger = logger_1.logger.sublogger('Counters');
function calculateManifestPackageCounters(manifestPackageR) {
    var _a;
    const counters = {
        sources: {
            total: 0,
            withErrors: 0,
            withWarnings: 0
        },
        manifests: {
            total: 0,
            passed: 0,
            withErrors: 0,
            withWarnings: 0
        }
    };
    for (const source of (_a = manifestPackageR.rootSource.children) !== null && _a !== void 0 ? _a : []) {
        calculateSourceCounters(source, counters);
    }
    return counters;
}
exports.calculateManifestPackageCounters = calculateManifestPackageCounters;
function calculateSourceCounters(source, counters) {
    var _a, _b;
    counters.sources.total++;
    if (source.severity === 'fail') {
        counters.sources.withErrors++;
    }
    else if (source.severity === 'warning') {
        counters.sources.withWarnings++;
    }
    for (const manifest of (_a = source.manifests) !== null && _a !== void 0 ? _a : []) {
        calculateManifestCounters(manifest, counters);
    }
    for (const childSource of (_b = source.children) !== null && _b !== void 0 ? _b : []) {
        calculateSourceCounters(childSource, counters);
    }
}
function calculateManifestCounters(manifest, counters) {
    myLogger.info("[calculateManifestCounters] %s", manifest.name);
    counters.manifests.total++;
    if (manifest.severity === 'fail') {
        counters.manifests.withErrors++;
    }
    else if (manifest.severity === 'warning') {
        counters.manifests.withWarnings++;
    }
    else {
        counters.manifests.passed++;
    }
}
function calculateRuleEngineCounters(ruleEngineR, manifestPackage) {
    const counters = {
        rules: {
            total: 0,
            passed: 0,
            failed: 0,
            withErrors: 0,
            withWarnings: 0
        },
        manifests: {
            total: manifestPackage.manifests.length,
            processed: 0,
            passed: 0,
            withErrors: 0,
            withWarnings: 0
        }
    };
    for (const ruleResult of ruleEngineR.rules) {
        calculateRuleCounters(ruleResult, counters);
    }
    for (const manifest of manifestPackage.manifests) {
        calculateRuleManifestCounters(manifest, counters);
    }
    return counters;
}
exports.calculateRuleEngineCounters = calculateRuleEngineCounters;
function calculateRuleCounters(ruleResult, counters) {
    if (ruleResult.isSkipped) {
        return;
    }
    counters.rules.total++;
    if (!ruleResult.compiled) {
        counters.rules.failed++;
    }
    if (!ruleResult.compiled) {
        counters.rules.failed++;
    }
    if (ruleResult.passed) {
        counters.rules.passed++;
    }
    if (ruleResult.hasViolationErrors) {
        counters.rules.withErrors++;
    }
    if (ruleResult.hasViolationWarnings) {
        counters.rules.withWarnings++;
    }
}
function calculateRuleManifestCounters(manifest, counters) {
    if (manifest.rules.processed) {
        counters.manifests.processed++;
        if (manifest.rules.errors) {
            counters.manifests.withErrors++;
        }
        else {
            counters.manifests.passed++;
        }
        if (manifest.rules.warnings) {
            counters.manifests.withWarnings++;
        }
    }
}
//# sourceMappingURL=counters.js.map