"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeSourceKey = exports.ManifestSource = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const path_1 = require("../utils/path");
const logger_1 = require("../logger");
const base_object_1 = require("../types/base-object");
const result_1 = require("../types/result");
const logger = logger_1.rootLogger.sublogger("ManifestSource");
class ManifestSource extends base_object_1.BaseObject {
    constructor(kind, path, originalSource) {
        super();
        this._manifests = [];
        this._parentSource = null;
        this._childSources = {};
        this.originalSource = null;
        this._id = {
            kind,
            path
        };
        this._idKey = makeSourceKey(kind, path);
        this.originalSource = originalSource;
    }
    get idKey() {
        return this._idKey;
    }
    get id() {
        return this._id;
    }
    get manifests() {
        return this._manifests;
    }
    get parentSource() {
        return this._parentSource;
    }
    get childSources() {
        return the_lodash_1.default.values(this._childSources);
    }
    getSource(kind, path, originalSource, isAbsolutePath) {
        let childPath = path;
        isAbsolutePath = isAbsolutePath !== null && isAbsolutePath !== void 0 ? isAbsolutePath : false;
        if (!isAbsolutePath) {
            if (this.id.path.length > 0) {
                childPath = (0, path_1.resolvePath)(path, this.id.path);
            }
        }
        const sourceKey = makeSourceKey(kind, childPath);
        let source = this._childSources[sourceKey];
        if (!source) {
            source = new ManifestSource(kind, childPath, originalSource);
            this._childSources[sourceKey] = source;
            source._parentSource = this;
        }
        return source;
    }
    addManifest(k8sManifest) {
        this._manifests.push(k8sManifest);
    }
    extractInfoResult() {
        const result = Object.assign({ kind: this.id.kind, path: this.id.path }, this.extractBaseResult());
        return result;
    }
    exportResult() {
        const result = Object.assign({}, this.extractInfoResult());
        if (this.childSources.length > 0) {
            result.children = this.childSources.map(x => x.exportResult());
            result.severity = (0, result_1.makeObjectSeverityFromChildren)(result.severity, result.children);
        }
        if (this.manifests.length > 0) {
            result.manifests = this.manifests.map(x => x.exportInfoResult());
        }
        return result;
    }
    yieldChildren() {
        const list = [this.childSources, this.manifests];
        return the_lodash_1.default.flatten(list);
    }
}
exports.ManifestSource = ManifestSource;
function makeSourceKey(kind, path) {
    return the_lodash_1.default.stableStringify({ kind, path });
}
exports.makeSourceKey = makeSourceKey;
//# sourceMappingURL=manifest-source.js.map