import { ILogger } from 'the-logger';
import YAML from 'yaml';
import { ManifestPackage } from './manifest-package';
import { K8sManifest } from './k8s-manifest';
import { ManifestSource } from "./manifest-source";
import { InputSourceExtractor } from '../input/input-source-extractor';
import { InputSource } from '../input/input-source';
export interface ManifestLoaderOptions {
    ignoreNonK8s: boolean;
}
export declare class ManifestLoader {
    private _logger;
    private _manifestPackage;
    private _inputSourceExtractor;
    private _options;
    constructor(logger: ILogger, manifestPackage: ManifestPackage, inputSourceExtractor: InputSourceExtractor, options?: Partial<ManifestLoaderOptions>);
    get manifestPackage(): ManifestPackage;
    get inputSourceExtractor(): InputSourceExtractor;
    loadFromExtractor(): Promise<void>;
    loadFromStream(): Promise<void>;
    loadSingle(inputSource: InputSource, parentSource?: ManifestSource): Promise<K8sManifest[]>;
    private _loadFromPreProcessor;
    private _loadFile;
    private _loadUrl;
    parseContents(source: ManifestSource, path: string, contents: string): K8sManifest[];
    private addConfigsFromSource;
    addManifest(source: ManifestSource, config: any): K8sManifest | null;
    private _checkK8sManifest;
    parseYamlRaw(contents: string): YAML.Document.Parsed<YAML.ParsedNode>[];
    rawYamlToObj(rawYaml: YAML.Document.Parsed<YAML.ParsedNode>): any;
    rawReadFile(path: string): Promise<string>;
    private _parseYaml;
    private _sanitizeManifest;
}
//# sourceMappingURL=manifests-loader.d.ts.map