"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ManifestLoader = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const the_promise_1 = require("the-promise");
const axios_1 = __importDefault(require("axios"));
const fs = __importStar(require("fs"));
const Path = __importStar(require("path"));
const yaml_1 = __importDefault(require("yaml"));
const stream_1 = require("../utils/stream");
const spinner_1 = require("../screen/spinner");
const k8s_manifest_sanitizer_1 = require("../utils/k8s-manifest-sanitizer");
const input_source_1 = require("../input/input-source");
const executor_1 = require("../preprocessors/executor");
class ManifestLoader {
    constructor(logger, manifestPackage, inputSourceExtractor, options) {
        var _a;
        this._logger = logger.sublogger('ManifestLoader');
        this._manifestPackage = manifestPackage;
        this._inputSourceExtractor = inputSourceExtractor;
        options = options !== null && options !== void 0 ? options : {};
        this._options = {
            ignoreNonK8s: (_a = options.ignoreNonK8s) !== null && _a !== void 0 ? _a : false
        };
        this._logger.info("setup. options: ", this._options);
    }
    get manifestPackage() {
        return this._manifestPackage;
    }
    get inputSourceExtractor() {
        return this._inputSourceExtractor;
    }
    loadFromExtractor() {
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[load] BEGIN");
            const spinner = (0, spinner_1.spinOperation)('Loading manifests...');
            for (const originalSource of this._inputSourceExtractor.originalSources) {
                if (!originalSource.hasAnyInput) {
                    const source = this._manifestPackage.getSource(originalSource.kind, originalSource.path, originalSource);
                    source.reportError(`No input was found.`);
                }
            }
            const sources = this._inputSourceExtractor.sources;
            yield the_promise_1.MyPromise.serial(sources, x => Promise.resolve(this.loadSingle(x)));
            spinner.complete('Manifests loaded.');
        });
    }
    loadFromStream() {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[_loadFromStream] ");
            const source = this._manifestPackage.getSource("stream", 'stream', null);
            try {
                const contents = yield (0, stream_1.readFromInputStream)();
                let manifests = null;
                if (!manifests) {
                    try {
                        manifests = this._parseYaml(contents);
                    }
                    catch (reason) {
                        source.reportError((_a = reason.message) !== null && _a !== void 0 ? _a : 'Error parsing YAML.');
                    }
                }
                if (!manifests) {
                    try {
                        manifests = [JSON.parse(contents)];
                    }
                    catch (reason) {
                        manifests = null;
                    }
                }
                if (manifests) {
                    for (const manifest of manifests) {
                        this.addManifest(source, manifest);
                    }
                }
                else {
                    source.reportError('Failed to parse manifests from stream.');
                }
            }
            catch (reason) {
                source.reportError(`Failed to fetch manifest. Reason: ${(_b = reason.message) !== null && _b !== void 0 ? _b : 'unknown'}`);
            }
        });
    }
    loadSingle(inputSource, parentSource) {
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[loadSingle] %s :: %s", inputSource.kind, inputSource.path);
            this._logger.info("[loadSingle]     suffixes: %s", inputSource.suffixes);
            if (inputSource.isPreprocessor) {
                return yield this._loadFromPreProcessor(inputSource, parentSource);
            }
            if (inputSource.kind == input_source_1.InputSourceKind.web) {
                return yield this._loadUrl(inputSource, parentSource);
            }
            else {
                return yield this._loadFile(inputSource, parentSource);
            }
        });
    }
    _loadFromPreProcessor(inputSource, parentSource) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const kind = inputSource.kind;
            const source = this._manifestPackage.getSource(kind, inputSource.path, inputSource.originalSource, parentSource);
            const preprocessor = new executor_1.PreProcessorExecutor(this._logger, this);
            try {
                yield preprocessor.execute(inputSource, source);
                return source.manifests; // TODO: Include Hierarchy manifests too.
            }
            catch (reason) {
                this._logger.info("[_loadFromPreProcessor] ERROR: ", reason);
                source.reportError(`Failed to execute preprocessor: ${inputSource.preprocessor}. Reason: ${(_a = reason === null || reason === void 0 ? void 0 : reason.message) !== null && _a !== void 0 ? _a : "Unknown"}`);
                return [];
            }
        });
    }
    _loadFile(inputSource, parentSource) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const path = inputSource.path;
            const source = this._manifestPackage.getSource("file", path, inputSource.originalSource, parentSource);
            this._logger.info("[_loadFile] path: %s", path);
            try {
                const contents = yield this.rawReadFile(path);
                return this.parseContents(source, path, contents);
            }
            catch (reason) {
                this._logger.info("[_loadFile] ERROR: ", reason);
                source.reportError('Failed to load manifest. Reason: ' + ((_a = reason === null || reason === void 0 ? void 0 : reason.message) !== null && _a !== void 0 ? _a : "Unknown"));
                return [];
            }
        });
    }
    _loadUrl(inputSource, parentSource) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const url = inputSource.path;
            const source = this._manifestPackage.getSource("web", url, inputSource.originalSource, parentSource);
            this._logger.info("[_loadUrl] url: %s", url);
            try {
                const { data } = yield axios_1.default.get(url);
                const contents = data.toString();
                return this.parseContents(source, url, contents);
            }
            catch (reason) {
                // this._logger.error("_loadUrl] ERROR: ", reason);
                source.reportError('Failed to fetch manifest. Reason: ' + ((_a = reason === null || reason === void 0 ? void 0 : reason.message) !== null && _a !== void 0 ? _a : "Unknown"));
                return [];
            }
        });
    }
    parseContents(source, path, contents) {
        var _a, _b;
        this._logger.info("[parseContents] path: %s", path);
        const manifests = [];
        const extension = Path.extname(path);
        this._logger.info("[parseContents] extension: %s", extension);
        if (extension === '.yaml' || extension === '.yml') {
            let configs = [];
            try {
                configs = this._parseYaml(contents);
            }
            catch (reason) {
                source.reportError((_a = reason.message) !== null && _a !== void 0 ? _a : 'Error parsing YAML.');
            }
            this.addConfigsFromSource(source, configs, manifests);
        }
        else if (extension === '.json') {
            let configs;
            try {
                configs = JSON.parse(contents);
            }
            catch (reason) {
                source.reportError((_b = reason.message) !== null && _b !== void 0 ? _b : 'Error parsing JSON');
            }
            this.addConfigsFromSource(source, configs, manifests);
        }
        else {
            source.reportError('Unknown extension. Should be one of: .yaml, .yml or .json');
        }
        this._logger.info("[parseContents] Manifest Count: %s", manifests.length);
        this._logger.silly("[parseContents] Manifests: ", manifests);
        if (source.success) {
            if (source.manifests.length === 0) {
                if (!this._options.ignoreNonK8s) {
                    // TODO: Move this to post parse validation logic
                    source.reportError('Contains no manifests');
                }
            }
        }
        return manifests;
    }
    addConfigsFromSource(source, configs, outManifests) {
        if (!configs) {
            return;
        }
        if (the_lodash_1.default.isArray(configs)) {
            if (configs.length === 0) {
                this._logger.info("[parseContents] No Manifests Found.");
                return;
            }
            for (const config of configs) {
                this.addConfigsFromSource(source, config, outManifests);
            }
        }
        else {
            const config = configs;
            if (config.apiVersion === 'v1' && config.kind === 'List') {
                this.addConfigsFromSource(source, config.items, outManifests);
                return;
            }
            else {
                const manifest = this.addManifest(source, config);
                if (manifest) {
                    outManifests.push(manifest);
                }
            }
        }
    }
    addManifest(source, config) {
        this._logger.info("[addManifest] source path: %s", source.id.path);
        // this._logger.silly("[addManifest] source path: %s, manifest:", source.id.path, config);
        if (!config) {
            return null;
        }
        const k8sObject = this._sanitizeManifest(config);
        const errors = this._checkK8sManifest(k8sObject);
        if (errors.length > 0) {
            if (!this._options.ignoreNonK8s) {
                source.reportErrors(errors);
            }
            return null;
        }
        return this._manifestPackage.addManifest(source, k8sObject);
    }
    _checkK8sManifest(k8sObject) {
        const errors = [];
        if (!k8sObject.apiVersion) {
            errors.push('Not a Kubernetes manifest. apiVersion is missing.');
        }
        if (!k8sObject.kind) {
            errors.push('Not a Kubernetes manifest. kind is missing.');
        }
        return errors;
    }
    parseYamlRaw(contents) {
        const result = yaml_1.default.parseAllDocuments(contents, {});
        if (!result) {
            return [];
        }
        return result;
    }
    rawYamlToObj(rawYaml) {
        return rawYaml.toJS({});
    }
    rawReadFile(path) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const contents = yield fs.promises.readFile(path, { encoding: 'utf8' });
                return contents;
            }
            catch (reason) {
                this._logger.info("[rawReadFile] ERROR: ", reason);
                throw reason;
            }
        });
    }
    _parseYaml(contents) {
        const result = this.parseYamlRaw(contents);
        const jsons = result.map(x => this.rawYamlToObj(x));
        return jsons;
    }
    _sanitizeManifest(obj) {
        return (0, k8s_manifest_sanitizer_1.sanitizeYaml)(obj);
    }
}
exports.ManifestLoader = ManifestLoader;
//# sourceMappingURL=manifests-loader.js.map