"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PreProcessorExecutor = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const the_promise_1 = require("the-promise");
const fs_1 = require("fs");
const child_process_1 = require("child_process");
const path_1 = __importDefault(require("path"));
const yaml_1 = __importDefault(require("yaml"));
const tmp = __importStar(require("tmp"));
const fast_glob_1 = __importDefault(require("fast-glob"));
const input_source_1 = require("../input/input-source");
const spinner_1 = require("../screen/spinner");
class PreProcessorExecutor {
    constructor(logger, manifestsLoader) {
        this._logger = logger.sublogger("PreProcessorExecutor");
        this._manifestsLoader = manifestsLoader;
        this._manifestPackage = manifestsLoader.manifestPackage;
    }
    execute(inputSource, source) {
        return __awaiter(this, void 0, void 0, function* () {
            if (inputSource.preprocessor === 'kustomize') {
                yield this._kustomize(inputSource, source);
            }
            if (inputSource.preprocessor === 'helm') {
                yield this._helm(inputSource, source);
            }
        });
    }
    _kustomize(inputSource, source) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[_kustomize] inputSource: %s", inputSource.path);
            const kustomizationContents = (yield fs_1.promises.readFile(inputSource.path)).toString();
            const kustomization = yaml_1.default.parseDocument(kustomizationContents).toJSON();
            // this._logger.info("[_kustomize] kustomization: ", kustomization);
            const dirName = path_1.default.dirname(inputSource.path);
            source = source.getSource("kustomize", dirName, source.originalSource);
            let tmpKustomizeFile = null;
            try {
                tmpKustomizeFile = tmp.fileSync();
                let command = `kustomize build ${dirName} -o ${tmpKustomizeFile.name}`;
                if (kustomization['helmCharts']) {
                    command = `${command} --enable-helm`;
                }
                yield this.executeCommand(command);
                const contents = yield fs_1.promises.readFile(tmpKustomizeFile.name, { encoding: 'utf8' });
                if (!contents) {
                    source.reportError(`Could not extract manifest contents from ${inputSource.preprocessor}`);
                }
                else {
                    this._manifestsLoader.parseContents(source, "manifests.yaml", contents);
                }
            }
            catch (reason) {
                this._logger.info("[_kustomize] ERROR: ", reason);
                source.reportError(`Failed to extract manifest from ${inputSource.preprocessor}. Reason: ${(_a = reason === null || reason === void 0 ? void 0 : reason.message) !== null && _a !== void 0 ? _a : "Unknown"}`);
            }
            finally {
                if (tmpKustomizeFile) {
                    tmpKustomizeFile.removeCallback();
                }
            }
        });
    }
    _helm(inputSource, source) {
        var _a, _b, _c;
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[_helm] path: %s, file: %s", inputSource.path, inputSource.file);
            let helmChartName = "";
            let helmChartPath = inputSource.path;
            const isLocalChart = (0, fs_1.existsSync)(helmChartPath);
            this._logger.info("[_helm] isLocalChart: %s", isLocalChart);
            if (isLocalChart) {
                let chartYamlFilePath = helmChartPath;
                if (isDir(helmChartPath)) {
                    chartYamlFilePath = path_1.default.join(chartYamlFilePath, 'Chart.yaml');
                }
                this._logger.info("[_helm] chartYamlFilePath: %s", chartYamlFilePath);
                try {
                    const contents = yield this._manifestsLoader.rawReadFile(chartYamlFilePath);
                    const chart = yaml_1.default.parseDocument(contents).toJS({});
                    helmChartName = chart.name;
                }
                catch (reason) {
                    this._logger.info("[_helm] ERROR: ", reason);
                    source.reportError('Failed to load Helm Chart manifest. Reason: ' + ((_a = reason === null || reason === void 0 ? void 0 : reason.message) !== null && _a !== void 0 ? _a : "Unknown"));
                    return;
                }
                this._logger.info("[_helm] helmChartName: %s", helmChartName);
                if (!helmChartName) {
                    source.reportError('Invalid Helm Chart manifest. Chart name not set.');
                    return;
                }
                helmChartPath = path_1.default.dirname(chartYamlFilePath);
            }
            else if (inputSource.kind === input_source_1.InputSourceKind.helm) {
                helmChartPath = inputSource.path;
            }
            this._logger.info("[_helm] helmChartPath: %s", helmChartPath);
            if (source.id.kind !== 'helm') {
                source = source.getSource("helm", helmChartPath, source.originalSource, !isLocalChart);
            }
            let tmpHelmDir = null;
            try {
                let command = `helm template`;
                for (const suffix of inputSource.suffixes) {
                    if (suffix.key === 'values') {
                        command += ` --values ${suffix.value}`;
                    }
                    else if (suffix.key === 'namespace') {
                        command += ` --namespace ${suffix.value}`;
                    }
                    else if (suffix.key === 'release-name') {
                        command += ` --release-name ${suffix.value}`;
                    }
                    else if (suffix.key === 'crds') {
                        if (suffix.value === 'include') {
                            command += ` --include-crds`;
                        }
                        else if (suffix.value === 'skip') {
                            command += ` --skip-crds`;
                        }
                        else {
                            source.reportError(`Unknown preprocessor key provided: ${suffix.key}=${suffix.value}`);
                        }
                    }
                    else if (suffix.key === 'set') {
                        command += ` --set ${suffix.value}`;
                    }
                    else {
                        source.reportError(`Unknown preprocessor key provided: ${suffix.key}`);
                    }
                }
                if (source.selfErrors.length > 0) {
                    return;
                }
                command += ` ${helmChartPath}`;
                tmpHelmDir = tmp.dirSync({ unsafeCleanup: true });
                command += ` --output-dir ${tmpHelmDir.name}`;
                yield this.executeCommand(command);
                const contentList = yield this._readYamlsFromDir(tmpHelmDir.name);
                if (!contentList || contentList.length === 0) {
                    source.reportError(`Could not extract manifest contents from ${inputSource.preprocessor}`);
                }
                else {
                    try {
                        for (const contents of contentList) {
                            const rawYamls = this._manifestsLoader.parseYamlRaw(contents);
                            for (const rawYaml of rawYamls) {
                                this._processHelm(inputSource, source, rawYaml, helmChartName, isLocalChart);
                            }
                        }
                    }
                    catch (reason) {
                        source.reportError(`Failed to parse YAML manifests from ${inputSource.preprocessor}. Reason: ${(_b = reason === null || reason === void 0 ? void 0 : reason.message) !== null && _b !== void 0 ? _b : "Unknown"}`);
                        return;
                    }
                }
            }
            catch (reason) {
                this._logger.info("[_helm] ERROR: ", reason);
                source.reportError(`Failed to extract manifest from ${inputSource.preprocessor}. Reason: ${(_c = reason === null || reason === void 0 ? void 0 : reason.message) !== null && _c !== void 0 ? _c : "Unknown"}`);
            }
            finally {
                if (tmpHelmDir) {
                    tmpHelmDir.removeCallback();
                }
            }
        });
    }
    _readYamlsFromDir(dir) {
        return __awaiter(this, void 0, void 0, function* () {
            const files = yield (0, fast_glob_1.default)(`**/*.{yaml,yml}`, {
                cwd: dir,
                absolute: true
            });
            return yield the_promise_1.MyPromise.serial(files, (x) => {
                return fs_1.promises.readFile(x, { encoding: 'utf-8' });
            });
        });
    }
    _processHelm(inputSource, source, rawYaml, helmChartName, isLocalChart) {
        var _a;
        const comment = (_a = rawYaml.contents) === null || _a === void 0 ? void 0 : _a.commentBefore;
        this._logger.info("[_processHelm] comment: %s", comment);
        if (comment) {
            const matches = comment.match(/Source: (\S*)$/);
            if (matches) {
                let templatePath = matches[1];
                this._logger.info("[_processHelm] templatePath: %s", templatePath);
                if (isLocalChart) {
                    if (helmChartName && helmChartName.length > 0) {
                        if (the_lodash_1.default.last(helmChartName) !== '/') {
                            helmChartName += '/';
                        }
                        if (templatePath.startsWith(helmChartName)) {
                            templatePath = templatePath.substring(helmChartName.length);
                        }
                    }
                }
                source = source.getSource('file', templatePath, source.originalSource, !isLocalChart);
            }
        }
        const config = this._manifestsLoader.rawYamlToObj(rawYaml);
        this._manifestsLoader.addManifest(source, config);
    }
    executeCommand(command) {
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("EXECUTING: %s", command);
            const spinner = (0, spinner_1.spinOperation)(`Executing ${command}`);
            try {
                const result = yield the_promise_1.MyPromise.construct((resolve, reject) => {
                    (0, child_process_1.exec)(command, (err, output) => {
                        // once the command has completed, the callback function is called
                        if (err) {
                            // log and return if we encounter an error
                            this._logger.error("ERROR: %s", output);
                            reject(err);
                            return;
                        }
                        // log the output received from the command
                        // this._logger.info("Output: %s", output)
                        resolve(output);
                    });
                });
                spinner.complete(`Succeeded: ${command}`);
                return result;
            }
            catch (reason) {
                spinner.fail(`Command Failed: ${command}`);
                throw reason;
            }
            return null;
        });
    }
}
exports.PreProcessorExecutor = PreProcessorExecutor;
function isDir(path) {
    const stats = (0, fs_1.statSync)(path);
    return stats.isDirectory();
}
//# sourceMappingURL=executor.js.map