"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LocalK8sRegistry = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const entity_meta_1 = require("@kubevious/entity-meta");
const k8s_1 = require("../types/k8s");
const client_side_filtering_1 = require("./client-side-filtering");
class LocalK8sRegistry {
    constructor(logger) {
        this._dict = {};
        this._logger = logger.sublogger('LocalK8sRegistry');
    }
    loadManifest(manifest) {
        const globalKey = (0, k8s_1.makeK8sKeyStr)(manifest.config);
        this._dict[globalKey] = manifest;
    }
    query(query) {
        // this._logger.info("[query] query: ", query);
        let results = the_lodash_1.default.values(this._dict);
        // this._logger.info("[query] 111 count: %s", results.length);
        if (!the_lodash_1.default.isUndefined(query.apiName)) {
            if (query.apiName.length === 0) {
                results = results.filter(x => !x.id.api);
            }
            else {
                results = results.filter(x => x.id.api === query.apiName);
            }
        }
        // this._logger.info("[query] 222 count: %s", results.length);
        if (query.version) {
            results = results.filter(x => x.id.version === query.version);
        }
        // this._logger.info("[query] 333 count: %s", results.length);
        if (query.kind) {
            results = results.filter(x => x.id.kind === query.kind);
        }
        // this._logger.info("[query] 444 count: %s", results.length);
        if (query.namespace) {
            results = results.filter(x => x.id.namespace === query.namespace);
        }
        // this._logger.info("[query] 555 count: %s", results.length);
        if (query.nameFilters && query.nameFilters.length > 0) {
            const nameDict = the_lodash_1.default.makeBoolDict(query.nameFilters);
            results = results.filter(x => x.id.name && nameDict[x.id.name]);
        }
        // this._logger.info("[query] 666 count: %s", results.length);
        const filtering = new client_side_filtering_1.ClientSideFiltering(results);
        filtering.applyLabelFilter(query.labelFilters);
        results = filtering.items;
        // this._logger.info("[query] result count: %s", results.length);
        return results;
    }
    debugOutputToDir(logger, relPath) {
        return __awaiter(this, void 0, void 0, function* () {
            for (const key of the_lodash_1.default.keys(this._dict)) {
                const filePath = `${relPath}/${(0, entity_meta_1.sanitizeDnPath)(key)}.json`;
                const manifest = this._dict[key];
                yield logger.outputFile(filePath, manifest.config);
            }
        });
    }
}
exports.LocalK8sRegistry = LocalK8sRegistry;
//# sourceMappingURL=local-k8s-registry.js.map