"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RemoteK8sRegistry = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const client_side_filtering_1 = require("./client-side-filtering");
const k8s_manifest_1 = require("../manifests/k8s-manifest");
class RemoteK8sRegistry {
    constructor(logger, k8sConnector, manifestPackage) {
        this._logger = logger.sublogger('RemoteK8sRegistry');
        this._k8sConnector = k8sConnector;
        this._client = k8sConnector.client;
        this._manifestPackage = manifestPackage;
    }
    query(query) {
        var _a, _b;
        this._logger.info("[query] ", query);
        let apiName = undefined;
        let version = undefined;
        if (!the_lodash_1.default.isUndefined(query.apiName)) {
            if (query.apiName.length === 0) {
                apiName = null;
            }
            else {
                apiName = query.apiName;
            }
        }
        else {
            throw new Error("apiName is not specified.");
        }
        version = query.version;
        this._logger.info("[query] apiName: %s", apiName);
        this._logger.info("[query] version: %s", version);
        if (!query.kind) {
            this._logger.info("[query] No Kind");
            return [];
        }
        const resourceClient = this._client.client(query.kind, apiName, version);
        if (!resourceClient) {
            this._logger.info("[query] Unknown Resource");
            return [];
        }
        let results = [];
        if (query.nameFilters && query.nameFilters.length > 0) {
            const namespace = (_a = query.namespace) !== null && _a !== void 0 ? _a : null;
            const nameDict = the_lodash_1.default.makeBoolDict(query.nameFilters);
            for (const name of the_lodash_1.default.keys(nameDict)) {
                const item = resourceClient.querySync(namespace, name);
                if (item) {
                    results.push(item);
                }
            }
            results = results.filter(x => { var _a, _b; return ((_a = x.metadata) === null || _a === void 0 ? void 0 : _a.name) && nameDict[(_b = x.metadata) === null || _b === void 0 ? void 0 : _b.name]; });
        }
        else {
            results = resourceClient.queryAllSync((_b = query.namespace) !== null && _b !== void 0 ? _b : undefined);
        }
        this._logger.info("[query] result count: %s", results.length);
        const manifests = results.map(x => this._makeManifest(x));
        // TODO: Try using label filter as an optimization inside resourceClient
        const filtering = new client_side_filtering_1.ClientSideFiltering(manifests);
        filtering.applyLabelFilter(query.labelFilters);
        return filtering.items;
    }
    _makeManifest(config) {
        const k8sObject = config;
        const source = this._manifestPackage.getSource("k8s", "live", null);
        const k8sManifest = new k8s_manifest_1.K8sManifest(k8sObject, source);
        return k8sManifest;
    }
}
exports.RemoteK8sRegistry = RemoteK8sRegistry;
//# sourceMappingURL=remote-k8s-registry.js.map