"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CacheProcessor = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const compiler_1 = require("@kubevious/kubik/dist/processors/compiler");
const sync_scope_builder_1 = require("../../query-spec/sync-scope-builder");
const scope_builder_1 = require("../../query-spec/scope-builder");
const rule_helpers_1 = require("../../helpers/rule-helpers");
const query_executor_scope_1 = require("../../query/query-executor-scope");
class CacheProcessor {
    constructor(src, executionContext) {
        this._src = src;
        this._logger = executionContext.logger.sublogger("CacheProcessor");
        this._executionContext = executionContext;
        this._runnable = null;
    }
    prepare() {
        const result = {
            success: false,
            messages: [],
        };
        return this._loadModule()
            .then((runnable) => {
            this._runnable = runnable;
        })
            .then(() => {
            this._validate();
            result.success = result.messages.length == 0;
        })
            .catch((reason) => {
            result.success = false;
            this._logger.info("[prepare] error: %s", reason === null || reason === void 0 ? void 0 : reason.message);
            // this._logger.info("[prepare] error: ", reason);
            this._addError(result.messages, reason.message);
            // this._logger.info("[prepare] %s", reason);
        })
            .then(() => result);
    }
    _loadModule() {
        const compilerValues = {
            _: the_lodash_1.default,
            namespace: null,
            cache: null,
            values: null,
            helpers: null,
        };
        for (const x of the_lodash_1.default.keys(scope_builder_1.TARGET_QUERY_BUILDER_DICT)) {
            compilerValues[x] = null;
        }
        const compiler = new compiler_1.Compiler(this._src, 'RULE_CACHE', compilerValues);
        return compiler.compile();
    }
    _validate() { }
    execute(namespace, values) {
        const result = {
            success: false,
            messages: [],
            namespace: namespace,
            cache: {}
        };
        this._logger.info("[execute] Namespace: %s", namespace);
        return Promise.resolve()
            .then(() => {
            const valueMap = {
                _: the_lodash_1.default,
                namespace: namespace,
                cache: result.cache,
                values: values,
                helpers: rule_helpers_1.RULE_HELPERS,
            };
            this._setupQueryBuilders(valueMap, namespace);
            return this._runnable.run(valueMap);
        })
            .then(() => {
            result.success = true;
        })
            .catch((reason) => {
            result.success = false;
            this._addError(result.messages, reason.message);
            // this._logger.info("[execute] %s", reason);
        })
            .then(() => result);
    }
    _setupQueryBuilders(valueMap, namespace) {
        const limiter = { namespace: namespace };
        const queryScope = (0, sync_scope_builder_1.buildQueryableScope)(this._executionContext, limiter);
        for (const key of the_lodash_1.default.keys(queryScope)) {
            valueMap[key] = queryScope[key];
        }
        {
            const queryScope = new query_executor_scope_1.QueryExecutorScope(this._executionContext, limiter);
            valueMap.many = (innerQuery) => queryScope.many(innerQuery);
            valueMap.single = (innerQuery) => queryScope.single(innerQuery);
            valueMap.count = (innerQuery) => queryScope.count(innerQuery);
        }
    }
    _addError(list, msg) {
        this._logger.info("[RULE ERROR] %s", msg);
        list.push(msg);
    }
}
exports.CacheProcessor = CacheProcessor;
//# sourceMappingURL=processor.js.map