"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TargetProcessor = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const compiler_1 = require("@kubevious/kubik/dist/processors/compiler");
const scope_builder_1 = require("../../query-spec/scope-builder");
const rule_helpers_1 = require("../../helpers/rule-helpers");
class TargetProcessor {
    constructor(src, executionContext) {
        this._queryTarget = {
            target: null
        };
        this._src = src;
        this._errorMessages = [];
        this._executionContext = executionContext;
        this._logger = executionContext.logger.sublogger("TargetProcessor");
    }
    prepare() {
        this._errorMessages = [];
        const result = {
            success: false,
            messages: this._errorMessages,
        };
        return this._loadModule()
            .then((runnable) => runnable.run())
            .then(() => {
            this._validate();
            result.success = (result.messages.length == 0);
        })
            .catch((reason) => {
            this._logger.info("[prepare] error: %s", reason === null || reason === void 0 ? void 0 : reason.message);
            this._logger.info("[prepare] error: ", reason);
            // this._logger.info("[prepare] error. Rule Source: ", this._src);
            result.success = false;
            this._addError(reason.message);
        })
            .then(() => result);
    }
    execute(applicationScope, values) {
        // const rootScope : CompilerScopeDict = {};
        // rootScope['values'] = values ?? {};
        const limiter = {
            namespace: applicationScope.namespace
        };
        return Promise.resolve()
            .then(() => {
            var _a;
            const queryTarget = this._queryTarget.target;
            if (!queryTarget) {
                return [];
            }
            const result = this._executionContext.queryExecutor.execute(queryTarget, limiter);
            return (_a = result.items) !== null && _a !== void 0 ? _a : [];
        });
    }
    _loadModule() {
        const rootScope = {
            _: the_lodash_1.default,
            _query: this._queryTarget,
            values: null,
            helpers: rule_helpers_1.RULE_HELPERS,
        };
        const rootScopeBuilder = {
            setup: (name, func) => {
                rootScope[name] = func;
            }
        };
        return Promise.resolve().then(() => {
            this._setupQueryBuilders(rootScopeBuilder);
            const src = `_query.target = ${this._src};`;
            const compiler = new compiler_1.Compiler(src, 'RULE_TARGET', rootScope);
            return compiler.compile();
        });
    }
    _setupQueryBuilders(rootScopeBuilder) {
        for (const key of the_lodash_1.default.keys(scope_builder_1.TARGET_QUERY_BUILDER_DICT)) {
            rootScopeBuilder.setup(key, scope_builder_1.TARGET_QUERY_BUILDER_DICT[key]);
        }
    }
    _validate() {
        if (!this._queryTarget.target) {
            this._addError('No target specified.');
            return;
        }
        this._validateQueryScope(this._queryTarget.target);
    }
    _validateQueryScope(query) {
        this._logger.info("[_validateQueryScope] kind: %s", query.kind);
        if (!query.kind) {
            this._addError('Unknown target specified.');
        }
    }
    _addError(msg) {
        // console.log("[TARGET-PROCESSOR] ERROR: ", msg)
        this._errorMessages.push(msg);
    }
}
exports.TargetProcessor = TargetProcessor;
//# sourceMappingURL=processor.js.map