"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationProcessor = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const compiler_1 = require("@kubevious/kubik/dist/processors/compiler");
const sync_scope_builder_1 = require("../../query-spec/sync-scope-builder");
const scope_builder_1 = require("../../query-spec/scope-builder");
const rule_helpers_1 = require("../../helpers/rule-helpers");
const query_executor_scope_1 = require("../../query/query-executor-scope");
class ValidationProcessor {
    constructor(src, executionContext) {
        this._src = src;
        this._executionContext = executionContext;
        this._runnable = null;
        this._logger = executionContext.logger.sublogger('ValidationProcessor');
    }
    prepare() {
        const result = {
            success: false,
            messages: [],
        };
        return this._loadModule()
            .then((runnable) => {
            this._runnable = runnable;
        })
            .then(() => {
            this._validate();
            result.success = result.messages.length == 0;
        })
            .catch((reason) => {
            result.success = false;
            this._addError(result.messages, reason.message);
        })
            .then(() => result);
    }
    _loadModule() {
        return __awaiter(this, void 0, void 0, function* () {
            const compilerValues = {
                _: the_lodash_1.default,
                item: null,
                config: null,
                globalCache: null,
                cache: null,
                values: null,
                error: null,
                warning: null,
                mark: null,
                helpers: null,
            };
            for (const x of the_lodash_1.default.keys(scope_builder_1.TARGET_QUERY_BUILDER_DICT)) {
                compilerValues[x] = null;
            }
            const compiler = new compiler_1.Compiler(this._src, 'RULE_VALIDATOR', compilerValues);
            return yield compiler.compile();
        });
    }
    _validate() { }
    execute(item, globalCache, cache, values) {
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[execute] item: %s", item.manifest.idKey);
            const result = {
                success: false,
                messages: [],
                validation: {
                    hasErrors: false,
                    hasWarnings: false,
                    errorMsgs: {},
                    warnMsgs: {},
                },
            };
            try {
                const valueMap = {
                    _: the_lodash_1.default,
                    item: item,
                    values: values,
                    config: item.config,
                    globalCache: globalCache,
                    cache: cache,
                    helpers: rule_helpers_1.RULE_HELPERS,
                    error: (msg) => {
                        result.validation.hasErrors = true;
                        if (msg) {
                            result.validation.errorMsgs[msg] = true;
                        }
                    },
                    warning: (msg) => {
                        result.validation.hasWarnings = true;
                        if (msg) {
                            result.validation.warnMsgs[msg] = true;
                        }
                    },
                    mark: (kind) => {
                        if (!result.validation.marks) {
                            result.validation.marks = {};
                        }
                        result.validation.marks[kind] = true;
                    },
                };
                this._setupQueryBuilders(valueMap, item);
                // console.log("HEADERS: ", _.keys(valueMap))
                yield this._runnable.run(valueMap);
                result.success = true;
            }
            catch (reason) {
                this._logger.info("[execute] error: ", reason);
                result.success = false;
                this._addError(result.messages, reason.message);
            }
            return result;
        });
    }
    _setupQueryBuilders(valueMap, item) {
        const limiter = { namespace: item.namespace };
        this._logger.debug("ITEM: %s::%s, LIMITER: ", item.kind, item.name, limiter);
        const syncQueryScope = (0, sync_scope_builder_1.buildQueryableScope)(this._executionContext, limiter);
        for (const key of the_lodash_1.default.keys(syncQueryScope)) {
            valueMap[key] = syncQueryScope[key];
        }
        {
            const queryScope = new query_executor_scope_1.QueryExecutorScope(this._executionContext, limiter);
            valueMap.many = (innerQuery) => queryScope.many(innerQuery);
            valueMap.single = (innerQuery) => queryScope.single(innerQuery);
            valueMap.count = (innerQuery) => queryScope.count(innerQuery);
        }
    }
    _addError(list, msg) {
        list.push(msg);
    }
}
exports.ValidationProcessor = ValidationProcessor;
//# sourceMappingURL=processor.js.map