import { ILogger } from 'the-logger';
import { CommonRule, RuleApplicationScope, RuleObject } from '../registry/types';
import { RuleCompiler } from '../compiler/rule-compiler';
import { RuleOverrideValues } from '../spec/rule-spec';
import { K8sManifest } from '../../manifests/k8s-manifest';
import { RuleResult } from '../../types/rules-result';
import { RulesRuntime } from './rules-runtime';
import { ManifestViolation } from './manifest-violation';
import { ScriptItem } from '../script-item';
export declare class RuleRuntime {
    private _logger;
    private _rulesRuntime;
    private _rule;
    private _executors;
    private _compiler;
    private _violations;
    private _passed;
    private _isSkipped;
    private _ruleCacheData;
    constructor(logger: ILogger, rule: CommonRule, rulesRuntime: RulesRuntime);
    get rule(): CommonRule;
    get ruleObject(): RuleObject;
    get manifest(): K8sManifest;
    get compiler(): RuleCompiler | undefined;
    get isCompiled(): boolean;
    get hasRuntimeErrors(): boolean;
    get ruleErrors(): import("../compiler/rule-compiler").RuleError[];
    get violations(): ManifestViolation[];
    get passed(): K8sManifest[];
    get ruleEngineReporter(): import("../reporting/rule-engine-reporter").RuleEngineReporter;
    init(): Promise<void>;
    private _prepareRule;
    setupApplication(application?: RuleApplicationScope, values?: RuleOverrideValues): void;
    execute(): Promise<void[]>;
    private _executeRule;
    exportResult(): RuleResult;
    processGlobalCache(values: RuleOverrideValues): Promise<CacheRunResult>;
    processLocalCache(item: ScriptItem, values: RuleOverrideValues): Promise<CacheRunResult>;
    private _exportPassedManifest;
}
export declare function makeValues(valuesArray: RuleOverrideValues[]): RuleOverrideValues;
export interface CacheRunResult {
    success: boolean;
    cache: Record<string, any>;
}
//# sourceMappingURL=rule-runtime.d.ts.map