import { ILogger } from 'the-logger';
import { CommonRule } from '../registry/types';
import { RuleRegistry } from '../registry/rule-registry';
import { RegistryQueryExecutor } from '../query-executor';
import { ExecutionContext } from './execution-context';
import { ManifestPackage } from '../../manifests/manifest-package';
import { RuleEngineReporter } from '../reporting/rule-engine-reporter';
import { RuleEngineResult } from '../../types/rules-result';
import { RuleRuntime } from './rule-runtime';
export interface RuleSkipOptions {
    skipRules: string[];
    onlyRules: string[];
    skipRuleCategories: string[];
    onlyRuleCategories: string[];
}
export declare class RulesRuntime {
    private _logger;
    private _ruleRegistry;
    private _rules;
    private _clusterRulesDict;
    private _skipRulesDict;
    private _onlyRulesDict;
    private _skipRuleCategoriesDict;
    private _onlyRuleCategoriesDict;
    private _manifestPackage;
    private _namespaces;
    private _targetExecutionContext;
    private _validatorExecutionContext;
    private _ruleEngineReporter;
    private _spinner?;
    constructor(logger: ILogger, ruleRegistry: RuleRegistry, manifestPackage: ManifestPackage, namespaces: string[], targetQueryExecutor: RegistryQueryExecutor, validatorQueryExecutor: RegistryQueryExecutor, skipOptions: RuleSkipOptions);
    get rules(): RuleRuntime[];
    get targetExecutionContext(): ExecutionContext;
    get validatorExecutionContext(): ExecutionContext;
    get ruleEngineReporter(): RuleEngineReporter;
    init(): Promise<void[]>;
    execute(): Promise<void>;
    exportResult(): RuleEngineResult;
    isRuleSkipped(rule: CommonRule): boolean;
    private _checkDependencies;
    private _checkRuleDependencies;
    private _checkRuleDependency;
    private _initClusterRules;
    private _initClusterRule;
    private _initNamespaceRules;
    private _initNamespaceRule;
    private _initRuleApplicators;
    private _initRuleApplicator;
    private _executeRule;
}
//# sourceMappingURL=rules-runtime.d.ts.map