"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseImage = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
function parseImage(fullImage) {
    var _a;
    if (!fullImage) {
        return {
            isInvalid: true,
            registry: '',
            repository: fullImage,
            namespace: '',
            name: fullImage,
            tag: 'latest',
        };
    }
    let parts = fullImage.split('/');
    if (parts.length === 0) {
        return {
            isInvalid: true,
            registry: '',
            repository: fullImage,
            namespace: '',
            name: fullImage,
            tag: 'latest',
        };
    }
    const tagInfo = parseTag(the_lodash_1.default.last(parts));
    parts = the_lodash_1.default.dropRight(parts);
    parts.push(tagInfo.name);
    let registry = 'docker.io';
    if (hasRegistry(parts)) {
        registry = the_lodash_1.default.head(parts);
        parts = the_lodash_1.default.drop(parts);
    }
    let namespace = '';
    if (parts.length >= 2) {
        namespace = the_lodash_1.default.dropRight(parts).join('/');
    }
    const repository = parts.join('/');
    const result = {
        registry: registry,
        repository: repository,
        namespace: namespace,
        name: (_a = the_lodash_1.default.last(parts)) !== null && _a !== void 0 ? _a : '',
        tag: tagInfo.tag
    };
    return result;
}
exports.parseImage = parseImage;
function parseTag(str) {
    const index = str.lastIndexOf(':');
    if (index === -1) {
        return {
            name: str,
            tag: 'latest'
        };
    }
    else {
        return {
            name: str.substring(0, index),
            tag: str.substring(index + 1),
        };
    }
}
function hasRegistry(parts) {
    if (parts.length >= 3) {
        return true;
    }
    return false;
}
//# sourceMappingURL=index.js.map