"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.LabelLookupDict = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
class LabelLookupDict {
    constructor() {
        this._labels = [];
        this._globalLookup = {};
    }
    add(item, labels) {
        labels = labels !== null && labels !== void 0 ? labels : {};
        const labelItem = {
            item: item,
            labels: labels,
            lookup: {}
        };
        this._labels.push(labelItem);
        for (const key of the_lodash_1.default.keys(labels)) {
            const lookupKey = makeLookupKey(key, labels[key]);
            labelItem.lookup[lookupKey] = true;
            if (!this._globalLookup[lookupKey]) {
                this._globalLookup[lookupKey] = [];
            }
            this._globalLookup[lookupKey].push(labelItem);
        }
    }
    resolveSelector(selector) {
        selector = selector !== null && selector !== void 0 ? selector : {};
        const selectorLookupKeys = [];
        for (const key of Object.keys(selector)) {
            const lookupKey = makeLookupKey(key, selector[key]);
            selectorLookupKeys.push(lookupKey);
        }
        const found = [];
        for (const labelItem of this._labels) {
            if (this._matchesDict(labelItem, selectorLookupKeys)) {
                found.push(labelItem.item);
            }
        }
        return found;
    }
    matchesSelector(selector) {
        return this.resolveSelector(selector).length > 0;
    }
    _matchesDict(labelItem, selectorLookupKeys) {
        for (const lookupKey of selectorLookupKeys) {
            if (!labelItem.lookup[lookupKey]) {
                return false;
            }
        }
        return true;
    }
}
exports.LabelLookupDict = LabelLookupDict;
function makeLookupKey(key, value) {
    return the_lodash_1.default.stableStringify({ key, value });
}
//# sourceMappingURL=dict.js.map