"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sTargetQuery = void 0;
const k8s_1 = require("../../../utils/k8s");
const base_1 = require("../base");
class K8sTargetQuery {
    constructor() {
        this._kind = base_1.TargetQueryKind.K8s;
        this._data = {
            namespace: null,
            isAllNamespaces: false,
            isClusterScope: false,
            nameFilters: [],
            labelFilters: [],
        };
    }
    get kind() {
        return this._kind;
    }
    ApiVersion(apiVersion) {
        const parsed = (0, k8s_1.parseApiVersion)(apiVersion);
        if (!parsed) {
            throw new Error(`Invalid apiVersion: ${apiVersion}`);
        }
        this._data.apiName = parsed.group;
        this._data.version = parsed.version;
        return this;
    }
    Api(apiName) {
        this._data.apiName = apiName;
        return this;
    }
    Version(version) {
        this._data.version = version;
        return this;
    }
    Kind(kind) {
        this._data.kind = kind;
        return this;
    }
    namespace(value) {
        this._data.namespace = value;
        return this;
    }
    isClusterScope(value) {
        this._data.isClusterScope = value !== null && value !== void 0 ? value : false;
        return this;
    }
    allNamespaces() {
        this._data.isAllNamespaces = true;
        return this;
    }
    name(value) {
        this._data.nameFilters.push(value);
        return this;
    }
    label(key, value) {
        const filter = {};
        filter[key] = value;
        return this.labels(filter);
    }
    labels(value) {
        this._data.labelFilters.push(value);
        return this;
    }
}
exports.K8sTargetQuery = K8sTargetQuery;
//# sourceMappingURL=k8s-target-query.js.map