"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildQueryableScope = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const query_executor_scope_1 = require("../query/query-executor-scope");
const scope_builder_1 = require("./scope-builder");
function buildQueryableScope(executionContext, limiter) {
    const syncQueryBuilder = {};
    for (const key of the_lodash_1.default.keys(scope_builder_1.TARGET_QUERY_BUILDER_DICT)) {
        const builder = scope_builder_1.TARGET_QUERY_BUILDER_DICT[key];
        const syncQuery = new SyncQueryBuilder(executionContext, builder);
        syncQueryBuilder[key] = syncQuery.wrap(limiter);
    }
    return syncQueryBuilder;
}
exports.buildQueryableScope = buildQueryableScope;
class SyncQueryBuilder {
    constructor(executionContext, queryBuilder) {
        this._executionContext = executionContext;
        this._queryBuilder = queryBuilder;
        this._logger = this._executionContext.logger.sublogger("SyncQueryBuilder");
    }
    wrap(limiter) {
        const queryExecutorScope = new query_executor_scope_1.QueryExecutorScope(this._executionContext, limiter);
        const wrapper = (...args) => {
            const queryTarget = this._queryBuilder.apply(null, args);
            queryTarget.many = () => {
                return queryExecutorScope.many(queryTarget);
            };
            queryTarget.single = () => {
                return queryExecutorScope.single(queryTarget);
            };
            queryTarget.count = () => {
                return queryExecutorScope.count(queryTarget);
            };
            return queryTarget;
        };
        return wrapper;
    }
}
//# sourceMappingURL=sync-scope-builder.js.map