"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sQueryExecutor = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const script_item_1 = require("../../script-item");
class K8sQueryExecutor {
    constructor(executionContext) {
        this._executionContext = executionContext;
        this._logger = executionContext.logger.sublogger("K8sQueryExecutor");
    }
    execute(query, limiter) {
        // this._logger.info("[execute] RUNNING QUERY....");
        var _a;
        const queryData = query._data;
        if (!queryData.kind) {
            // this._logger.info("[execute] Exiting. No Kind...");
            return {
                success: false,
                messages: ['Kind not set'],
            };
        }
        if (the_lodash_1.default.isUndefined(queryData.apiName)) {
            // this._logger.info("[execute] Exiting. No ApiName...");
            return {
                success: false,
                messages: ['apiName not set'],
            };
        }
        const k8sQueryFilter = {
            apiName: queryData.apiName,
            version: queryData.version,
            kind: queryData.kind,
            nameFilters: queryData.nameFilters,
            labelFilters: queryData.labelFilters,
        };
        const isClusterScope = queryData.isClusterScope;
        if (!isClusterScope) {
            if (!queryData.isAllNamespaces) {
                k8sQueryFilter.namespace = ((_a = queryData.namespace) !== null && _a !== void 0 ? _a : limiter.namespace) || undefined;
            }
        }
        // this._logger.info("[execute] Filter: ", k8sQueryFilter);
        const manifests = this._executionContext.registryQueryExecutor.query(k8sQueryFilter);
        const result = {
            success: true,
            items: manifests.map(x => new script_item_1.ScriptItem(x))
        };
        // this._logger.info("[execute]     RESULT COUNT: %s", result.items!.length);
        return result;
    }
}
exports.K8sQueryExecutor = K8sQueryExecutor;
//# sourceMappingURL=k8s-query-executor.js.map