"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryExecutor = void 0;
const base_1 = require("../query-spec/base");
const filter_query_executor_1 = require("./filter/filter-query-executor");
const first_query_executor_1 = require("./first/first-query-executor");
const k8s_query_executor_1 = require("./k8s/k8s-query-executor");
const manual_query_executor_1 = require("./manual/manual-query-executor");
const shortcut_query_executor_1 = require("./shortcut/shortcut-query-executor");
const transform_many_query_executor_1 = require("./transform-many/transform-many-query-executor");
const transform_query_executor_1 = require("./transform/transform-query-executor");
const union_query_executor_1 = require("./union/union-query-executor");
class QueryExecutor {
    constructor(executionContext) {
        this._resolvers = {};
        this._logger = executionContext.logger.sublogger("QueryExecutor");
        this._executionContext = executionContext;
        this._setup();
    }
    _setup() {
        this._resolvers[base_1.TargetQueryKind.Shortcut] = new shortcut_query_executor_1.ShortcutQueryExecutor(this._executionContext);
        this._resolvers[base_1.TargetQueryKind.K8s] = new k8s_query_executor_1.K8sQueryExecutor(this._executionContext);
        this._resolvers[base_1.TargetQueryKind.Union] = new union_query_executor_1.UnionQueryExecutor(this._executionContext);
        this._resolvers[base_1.TargetQueryKind.Transform] = new transform_query_executor_1.TransformQueryExecutor(this._executionContext);
        this._resolvers[base_1.TargetQueryKind.TransformMany] = new transform_many_query_executor_1.TransformManyQueryExecutor(this._executionContext);
        this._resolvers[base_1.TargetQueryKind.Filter] = new filter_query_executor_1.FilterQueryExecutor(this._executionContext);
        this._resolvers[base_1.TargetQueryKind.First] = new first_query_executor_1.FirstQueryExecutor(this._executionContext);
        this._resolvers[base_1.TargetQueryKind.Manual] = new manual_query_executor_1.ManualQueryExecutor(this._executionContext);
    }
    execute(query, limiter) {
        this._logger.debug("[execute] %s", query.kind);
        const resolver = this._resolvers[query.kind];
        if (!resolver) {
            this._logger.error("Internal Error. Unknown query kind: %s", query.kind);
            return {
                success: false,
                messages: [
                    `Internal Error. Unknown query kind: ${query.kind}`
                ]
            };
        }
        return resolver.execute(query, limiter);
    }
}
exports.QueryExecutor = QueryExecutor;
//# sourceMappingURL=query-executor.js.map