"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransformQueryExecutor = void 0;
const script_item_1 = require("../../script-item");
const k8s_manifest_1 = require("../../../manifests/k8s-manifest");
class TransformQueryExecutor {
    constructor(executionContext) {
        this._executionContext = executionContext;
        this._logger = executionContext.logger.sublogger("TransformQueryExecutor");
    }
    execute(query, limiter) {
        const result = {
            success: true,
            items: []
        };
        const innerResult = this._executionContext.queryExecutor.execute(query._inner, limiter);
        if (innerResult.items) {
            for (const item of innerResult.items) {
                if (query._func) {
                    const k8sObj = query._func(item);
                    const manifest = new k8s_manifest_1.K8sManifest(k8sObj, item.manifest.source);
                    result.items.push(new script_item_1.ScriptItem(manifest));
                }
            }
        }
        return result;
    }
}
exports.TransformQueryExecutor = TransformQueryExecutor;
//# sourceMappingURL=transform-query-executor.js.map