import { ILogger } from 'the-logger';
import { ApplicatorRule, ClusterRule, NamespaceRule, RuleObject } from './types';
import { RegistryQueryExecutor } from '../query-executor';
import { ManifestLoader } from '../../manifests/manifests-loader';
import { ManifestPackage } from '../../manifests/manifest-package';
export interface RuleRegistryLoadOptions {
    namespaces: string[];
    onlySelectedNamespaces: boolean;
    skipClusterScope: boolean;
    skipLibraries: boolean;
}
export declare class RuleRegistry {
    private _logger;
    private _clusterRules;
    private _rules;
    private _ruleApplicators;
    private _manifestPackage;
    private _manifestsLoader;
    constructor(logger: ILogger, manifestPackage: ManifestPackage, manifestsLoader: ManifestLoader);
    get clusterRules(): ClusterRule[];
    get rules(): NamespaceRule[];
    get ruleApplicators(): ApplicatorRule[];
    findClusterRule(name: string): RuleObject | null;
    loadLocally(registry: RegistryQueryExecutor, options: RuleRegistryLoadOptions): Promise<void>;
    loadRemotely(registry: RegistryQueryExecutor, options: RuleRegistryLoadOptions): Promise<void>;
    private _loadRegistry;
    private _loadClusterRules;
    private _loadClusterRule;
    private _loadNsRules;
    private _loadNsRule;
    private _loadApplicatorRules;
    private _loadApplicatorRule;
    private _loadLibraries;
    private _loadLibrary;
    private _loadLibraryRule;
}
//# sourceMappingURL=rule-registry.d.ts.map