"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RuleRegistry = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const the_promise_1 = require("the-promise");
const types_1 = require("./types");
const spinner_1 = require("../../screen/spinner");
const kubevious_1 = require("../../types/kubevious");
const input_source_1 = require("../../input/input-source");
const original_source_1 = require("../../input/original-source");
class RuleRegistry {
    constructor(logger, manifestPackage, manifestsLoader) {
        this._clusterRules = {};
        this._rules = {};
        this._ruleApplicators = {};
        this._logger = logger.sublogger('RuleRegistry');
        this._manifestPackage = manifestPackage; //new ManifestPackage(logger);
        this._manifestsLoader = manifestsLoader;
    }
    get clusterRules() {
        return the_lodash_1.default.values(this._clusterRules);
    }
    get rules() {
        return the_lodash_1.default.values(this._rules);
    }
    get ruleApplicators() {
        return the_lodash_1.default.values(this._ruleApplicators);
    }
    findClusterRule(name) {
        var _a;
        return (_a = this._clusterRules[name]) !== null && _a !== void 0 ? _a : null;
    }
    loadLocally(registry, options) {
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[loadLocally] options: ", options);
            const spinner = (0, spinner_1.spinOperation)("Populating local RulesLibrary...");
            yield this._loadRegistry(registry, options);
            spinner.complete("RulesLibrary locally populated.");
        });
    }
    loadRemotely(registry, options) {
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[loadRemotely] options: ", options);
            const spinner = (0, spinner_1.spinOperation)("Populating RulesLibrary From K8s...");
            yield this._loadRegistry(registry, options);
            spinner.complete("RulesLibrary populated from K8s.");
        });
    }
    _loadRegistry(registry, options) {
        return __awaiter(this, void 0, void 0, function* () {
            yield this._loadLibraries(registry, options);
            yield this._loadClusterRules(registry, options);
            yield this._loadNsRules(registry, options);
            yield this._loadApplicatorRules(registry, options);
        });
    }
    _loadClusterRules(registry, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (options.skipClusterScope) {
                return;
            }
            const spinner = (0, spinner_1.spinOperation)("Loading ClusterRules...", 2);
            const query = {
                apiName: kubevious_1.KUBEVIOUS_API_NAME,
                kind: kubevious_1.KubeviousKinds.ClusterRule,
                isAllNamespaces: true,
            };
            const results = registry.query(query);
            for (const manifest of results) {
                yield this._loadClusterRule(manifest);
            }
            spinner.complete("ClusterRules loaded.");
        });
    }
    _loadClusterRule(manifest) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
        return __awaiter(this, void 0, void 0, function* () {
            const config = manifest.config;
            const name = (_a = config.metadata) === null || _a === void 0 ? void 0 : _a.name;
            if (!name) {
                return;
            }
            this._logger.info("[_loadClusterRule] %s...", name);
            const spec = (_b = config.spec) !== null && _b !== void 0 ? _b : {};
            spec.disabled = (_c = spec.disabled) !== null && _c !== void 0 ? _c : false;
            spec.values = (_d = spec.values) !== null && _d !== void 0 ? _d : {};
            spec.application = (_e = spec.application) !== null && _e !== void 0 ? _e : {};
            spec.application.clustered = (_f = spec.application.clustered) !== null && _f !== void 0 ? _f : false;
            spec.application.useApplicator = (_g = spec.application.useApplicator) !== null && _g !== void 0 ? _g : false;
            spec.application.onlySelectedNamespaces = (_h = spec.application.onlySelectedNamespaces) !== null && _h !== void 0 ? _h : false;
            spec.application.namespaces = (_j = spec.application.namespaces) !== null && _j !== void 0 ? _j : [];
            const clustered = spec.application.clustered;
            this._clusterRules[name] = {
                isDisabled: spec.disabled,
                manifest: manifest,
                source: manifest.source.id,
                kind: types_1.RuleKind.ClusterRule,
                name: name,
                categories: (_k = spec.categories) !== null && _k !== void 0 ? _k : [],
                categoryDict: the_lodash_1.default.makeBoolDict((_l = spec.categories) !== null && _l !== void 0 ? _l : []),
                target: spec.target,
                globalCache: spec.globalCache,
                cache: spec.cache,
                script: spec.rule,
                values: spec.values,
                dependencies: (_m = spec.dependencies) !== null && _m !== void 0 ? _m : [],
                hasUnmedDependency: false,
                spec: spec,
                clustered: clustered,
                useApplicator: !clustered && spec.application.useApplicator,
                onlySelectedNamespaces: !clustered && spec.application.onlySelectedNamespaces,
                namespaces: clustered ? {} :
                    the_lodash_1.default.makeDict(spec.application.namespaces, x => x.name, x => { var _a; return ({ values: (_a = x.values) !== null && _a !== void 0 ? _a : {} }); })
            };
        });
    }
    _loadNsRules(registry, options) {
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[_loadNsRules] ", options);
            const spinner = (0, spinner_1.spinOperation)("Loading Rules...", 2);
            if (options.onlySelectedNamespaces) {
                for (const namespace of options.namespaces) {
                    spinner.update(`Loading Rules from ${namespace}...`);
                    const query = {
                        apiName: kubevious_1.KUBEVIOUS_API_NAME,
                        kind: kubevious_1.KubeviousKinds.Rule,
                        namespace: namespace,
                    };
                    this._logger.info("[_loadNsRules] Running namespace: %s query...", namespace);
                    const results = registry.query(query);
                    this._logger.info("[_loadNsRules] count: %s", results.length);
                    for (const result of results) {
                        yield this._loadNsRule(result);
                    }
                }
            }
            else {
                const query = {
                    apiName: kubevious_1.KUBEVIOUS_API_NAME,
                    kind: kubevious_1.KubeviousKinds.Rule,
                    isAllNamespaces: true,
                };
                this._logger.info("[_loadNsRules] Running global query...");
                const results = registry.query(query);
                this._logger.info("[_loadNsRules] count: %s", results.length);
                for (const result of results) {
                    yield this._loadNsRule(result);
                }
            }
            spinner.complete("Rules loaded.");
        });
    }
    _loadNsRule(manifest) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        return __awaiter(this, void 0, void 0, function* () {
            const config = manifest.config;
            const name = (_a = config.metadata) === null || _a === void 0 ? void 0 : _a.name;
            const namespace = (_c = (_b = config.metadata) === null || _b === void 0 ? void 0 : _b.namespace) !== null && _c !== void 0 ? _c : 'default';
            this._logger.info("[_loadNsRule] %s :: %s...", namespace, name);
            const spec = (_d = config.spec) !== null && _d !== void 0 ? _d : {};
            spec.disabled = (_e = spec.disabled) !== null && _e !== void 0 ? _e : false;
            spec.values = (_f = spec.values) !== null && _f !== void 0 ? _f : {};
            if (!name) {
                return;
            }
            this._rules[manifest.idKey] = {
                isDisabled: spec.disabled,
                manifest: manifest,
                source: manifest.source.id,
                kind: types_1.RuleKind.Rule,
                namespace: namespace,
                name: name,
                categories: (_g = spec.categories) !== null && _g !== void 0 ? _g : [],
                categoryDict: the_lodash_1.default.makeBoolDict((_h = spec.categories) !== null && _h !== void 0 ? _h : []),
                application: {
                    namespace: namespace
                },
                target: spec.target,
                globalCache: spec.globalCache,
                cache: spec.cache,
                script: spec.rule,
                values: spec.values,
                dependencies: (_j = spec.dependencies) !== null && _j !== void 0 ? _j : [],
                hasUnmedDependency: false,
                spec: spec
            };
        });
    }
    _loadApplicatorRules(registry, options) {
        return __awaiter(this, void 0, void 0, function* () {
            const spinner = (0, spinner_1.spinOperation)("Loading RuleApplicators...", 2);
            if (options.onlySelectedNamespaces) {
                for (const namespace of options.namespaces) {
                    spinner.update(`Loading RuleApplicators from ${namespace}...`);
                    const query = {
                        apiName: kubevious_1.KUBEVIOUS_API_NAME,
                        kind: kubevious_1.KubeviousKinds.RuleApplicator,
                        namespace: namespace
                    };
                    const results = registry.query(query);
                    for (const result of results) {
                        yield this._loadApplicatorRule(result);
                    }
                }
            }
            else {
                const query = {
                    apiName: kubevious_1.KUBEVIOUS_API_NAME,
                    kind: kubevious_1.KubeviousKinds.RuleApplicator,
                    isAllNamespaces: true,
                };
                const results = registry.query(query);
                for (const result of results) {
                    yield this._loadApplicatorRule(result);
                }
            }
            spinner.complete("RuleApplicators loaded");
        });
    }
    _loadApplicatorRule(manifest) {
        var _a, _b, _c, _d, _e, _f;
        return __awaiter(this, void 0, void 0, function* () {
            const config = manifest.config;
            const name = (_a = config.metadata) === null || _a === void 0 ? void 0 : _a.name;
            const namespace = (_c = (_b = config.metadata) === null || _b === void 0 ? void 0 : _b.namespace) !== null && _c !== void 0 ? _c : 'default';
            this._logger.info("[_loadApplicatorRule] %s :: %s...", namespace, name);
            const spec = (_d = config.spec) !== null && _d !== void 0 ? _d : {};
            spec.disabled = (_e = spec.disabled) !== null && _e !== void 0 ? _e : false;
            spec.values = (_f = spec.values) !== null && _f !== void 0 ? _f : {};
            if (!name) {
                return;
            }
            this._ruleApplicators[manifest.idKey] = {
                manifest: manifest,
                source: manifest.source.id,
                kind: types_1.RuleKind.RuleApplicator,
                namespace: namespace,
                name: name,
                application: {
                    namespace: namespace
                },
                values: spec.values,
                spec: spec
            };
        });
    }
    _loadLibraries(registry, options) {
        return __awaiter(this, void 0, void 0, function* () {
            if (options.skipLibraries) {
                return;
            }
            const spinner = (0, spinner_1.spinOperation)("Loading Libraries...", 2);
            const query = {
                apiName: kubevious_1.KUBEVIOUS_API_NAME,
                kind: kubevious_1.KubeviousKinds.Library,
                isAllNamespaces: true,
            };
            const results = registry.query(query);
            for (const manifest of results) {
                yield this._loadLibrary(manifest);
            }
            spinner.complete("Libraries loaded.");
        });
    }
    _loadLibrary(manifest) {
        var _a, _b, _c;
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[_loadLibrary] manifest: %s...", manifest.source.id.path);
            const config = manifest.config;
            const name = (_a = config.metadata) === null || _a === void 0 ? void 0 : _a.name;
            this._logger.info("[_loadLibrary] %s ...", name);
            const spec = (_b = config.spec) !== null && _b !== void 0 ? _b : {};
            const ruleRefs = (_c = spec.rules) !== null && _c !== void 0 ? _c : [];
            yield the_promise_1.MyPromise.execute(ruleRefs, ruleRef => {
                return this._loadLibraryRule(manifest, ruleRef);
            }, {
                concurrency: 10,
            });
        });
    }
    _loadLibraryRule(library, ruleRef) {
        return __awaiter(this, void 0, void 0, function* () {
            this._logger.info("[_loadLibraryRule] loading: %s...", ruleRef.path);
            const orignalSource = new original_source_1.OriginalSource(library.source.id.path);
            const inputSource = input_source_1.InputSource.makeFromPath(orignalSource, ruleRef.path);
            const ruleManifests = yield this._manifestsLoader.loadSingle(inputSource, library.source);
            if (ruleManifests.length === 0) {
                this._logger.error("[_loadLibraryRule] target rule not found: ", ruleRef);
            }
            for (const ruleManifest of ruleManifests) {
                yield this._loadClusterRule(ruleManifest);
            }
        });
    }
}
exports.RuleRegistry = RuleRegistry;
//# sourceMappingURL=rule-registry.js.map