"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.printSummaryCounter = exports.OTHER_ICONS = exports.SOURCE_ICONS = exports.OBJECT_ICONS = exports.STATUS_ICONS = exports.IconDefinition = exports.printProcessStatus = exports.printSubTitle = exports.printSectionTitle = exports.printWarnings = exports.printWarningLine = exports.printErrors = exports.printErrorLine = exports.printFailLine = exports.printInactivePassLine = exports.printPassLine = exports.printInfoLine = exports.print = exports.indentify = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const chalk_1 = __importDefault(require("chalk"));
const node_emoji_1 = __importDefault(require("node-emoji"));
function indentify(str, count) {
    const prefix = ' '.repeat(count !== null && count !== void 0 ? count : 0);
    let lines = str.split('\n');
    lines = lines.map(x => `${prefix}${x}`);
    return lines.join('\n');
}
exports.indentify = indentify;
function print(str, indent) {
    console.log(indentify(str !== null && str !== void 0 ? str : "", indent));
}
exports.print = print;
function printInfoLine(str, indent) {
    print(`${exports.STATUS_ICONS.info.get()} ${str}`, indent);
}
exports.printInfoLine = printInfoLine;
function printPassLine(str, indent) {
    print(`${exports.STATUS_ICONS.passed.get()} ${str}`, indent);
}
exports.printPassLine = printPassLine;
function printInactivePassLine(str, indent) {
    print(`${exports.STATUS_ICONS.passed.get(false)} ${str}`, indent);
}
exports.printInactivePassLine = printInactivePassLine;
function printFailLine(str, indent) {
    print(`${exports.STATUS_ICONS.failed.get()} ${str}`, indent);
}
exports.printFailLine = printFailLine;
function printErrorLine(str, indent) {
    print(`${exports.STATUS_ICONS.error.get()} ${str}`, indent);
}
exports.printErrorLine = printErrorLine;
function printErrors(lines, indent) {
    if (lines) {
        for (const x of lines) {
            printErrorLine(x, indent);
        }
    }
}
exports.printErrors = printErrors;
function printWarningLine(str, indent) {
    print(`${exports.STATUS_ICONS.warning.get()} ${str}`, indent);
}
exports.printWarningLine = printWarningLine;
function printWarnings(lines, indent) {
    if (lines) {
        for (const x of lines) {
            printWarningLine(x, indent);
        }
    }
}
exports.printWarnings = printWarnings;
function printSectionTitle(title, indent) {
    title = `-= ${title.toUpperCase()} =-`;
    title = chalk_1.default.underline(title);
    print(title, indent);
}
exports.printSectionTitle = printSectionTitle;
function printSubTitle(title, indent) {
    title = chalk_1.default.underline(title);
    print(title, indent);
}
exports.printSubTitle = printSubTitle;
function printProcessStatus(severity, taskName) {
    print();
    if (severity === 'pass') {
        print(`${exports.STATUS_ICONS.passed.get()} ${taskName} Succeeded.`);
    }
    else if (severity === 'warning') {
        print(`${exports.STATUS_ICONS.warning.get()} ${taskName} Succeeded with Warnings.`);
    }
    else if (severity === 'fail') {
        print(`${exports.STATUS_ICONS.failed.get()} ${taskName} Failed`);
    }
}
exports.printProcessStatus = printProcessStatus;
class IconDefinition {
    constructor(active, inactive) {
        this._active = active;
        this._inactive = inactive !== null && inactive !== void 0 ? inactive : active;
    }
    get(isActiveOrCount) {
        let isActive = true;
        if (the_lodash_1.default.isNumber(isActiveOrCount)) {
            isActive = isActiveOrCount > 0;
        }
        else {
            isActive = isActiveOrCount !== null && isActiveOrCount !== void 0 ? isActiveOrCount : true;
        }
        if (isActive) {
            return this._active;
        }
        else {
            return this._inactive;
        }
    }
}
exports.IconDefinition = IconDefinition;
exports.STATUS_ICONS = {
    passed: new IconDefinition(node_emoji_1.default.get(':white_check_mark:'), `${node_emoji_1.default.get(':ballot_box_with_check:')} `),
    failed: new IconDefinition(node_emoji_1.default.get(':x:'), `${node_emoji_1.default.get(':heavy_multiplication_x:')} `),
    error: new IconDefinition(node_emoji_1.default.get(':red_circle:'), node_emoji_1.default.get(':radio_button:')),
    warning: new IconDefinition(`${node_emoji_1.default.get(':warning:')} `, node_emoji_1.default.get(':grey_exclamation:')),
    question: new IconDefinition(`${node_emoji_1.default.get(':question:')} `, node_emoji_1.default.get(':grey_question:')),
    info: new IconDefinition(`${node_emoji_1.default.get(':information_source:')} `),
};
exports.OBJECT_ICONS = {
    source: new IconDefinition(node_emoji_1.default.get(':books:')),
    manifest: new IconDefinition(node_emoji_1.default.get(':page_facing_up:')),
    rule: new IconDefinition(node_emoji_1.default.get(':scroll:')),
    ruleLocation: new IconDefinition(node_emoji_1.default.get(':open_file_folder:')),
    ruleCategory: new IconDefinition(node_emoji_1.default.get(':label:')),
};
exports.SOURCE_ICONS = {
    file: new IconDefinition(node_emoji_1.default.get(':page_facing_up:')),
    web: new IconDefinition(node_emoji_1.default.get(':globe_with_meridians:')),
    stream: new IconDefinition(node_emoji_1.default.get(':aquarius:')),
    // k8s: new IconDefinition('☸️ '),
    k8s: new IconDefinition(`${node_emoji_1.default.get(':wheel_of_dharma:')} `),
    helm: new IconDefinition(node_emoji_1.default.get(':ship:')),
    kustomize: new IconDefinition(`${node_emoji_1.default.get(':wheel_of_dharma:')} `),
};
exports.OTHER_ICONS = {
    email: new IconDefinition(node_emoji_1.default.get(':e-mail:')),
    bug: new IconDefinition(node_emoji_1.default.get(':ladybug:')),
    slack: new IconDefinition(node_emoji_1.default.get(':speech_balloon:')),
    party: new IconDefinition(node_emoji_1.default.get(':tada:')),
};
function printSummaryCounter(icon, title, count) {
    print(`${icon.get(count)} ${title}: ${count}`, 8);
}
exports.printSummaryCounter = printSummaryCounter;
//# sourceMappingURL=index.js.map