"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.outputMessages = exports.produceSourceLine = exports.severityStatusIcon = exports.outputManifestResultSources = exports.outputManifestResult = exports.outputManifestInfo = exports.outputSourceInfo = exports.outputManifestPackageResultManifests = exports.outputManifestPackageResultSources = void 0;
const _1 = require(".");
function outputManifestPackageResultSources(packageResult, detailed, indent) {
    var _a;
    detailed = detailed !== null && detailed !== void 0 ? detailed : false;
    indent = indent !== null && indent !== void 0 ? indent : 0;
    (0, _1.printSectionTitle)('Sources', indent);
    const nestedIndent = (indent !== null && indent !== void 0 ? indent : 0) + 3;
    if (((_a = packageResult.rootSource.children) !== null && _a !== void 0 ? _a : []).length === 0) {
        (0, _1.printWarningLine)('No Sources provided', nestedIndent);
    }
    else {
        if (!detailed && (packageResult.rootSource.severity == 'pass')) {
            (0, _1.printPassLine)('No issues with sources.', nestedIndent);
        }
        else {
            outputSourceResult(packageResult.rootSource, detailed, nestedIndent);
        }
    }
    (0, _1.print)();
}
exports.outputManifestPackageResultSources = outputManifestPackageResultSources;
function outputManifestPackageResultManifests(packageResult, detailed, indent) {
    detailed = detailed !== null && detailed !== void 0 ? detailed : false;
    indent = indent !== null && indent !== void 0 ? indent : 0;
    const nestedIndent = (indent !== null && indent !== void 0 ? indent : 0) + 3;
    (0, _1.printSectionTitle)('Manifests', indent);
    if (packageResult.manifests.length === 0) {
        (0, _1.printWarningLine)('No Manifests found', nestedIndent);
        (0, _1.print)();
    }
    else {
        if (!detailed && (packageResult.severity == 'pass')) {
            (0, _1.printPassLine)('No issues with manifests.', nestedIndent);
        }
        else {
            for (const manifest of packageResult.manifests) {
                outputManifestResult(manifest, detailed, nestedIndent);
            }
        }
    }
    (0, _1.print)();
}
exports.outputManifestPackageResultManifests = outputManifestPackageResultManifests;
function outputSourceResult(sourceResult, detailed, indent) {
    var _a, _b;
    if (!detailed) {
        if (sourceResult.severity == 'pass') {
            return;
        }
    }
    if (sourceResult.kind !== 'root') {
        outputSourceInfo(sourceResult, indent);
        indent += 3;
    }
    outputMessages(sourceResult, indent);
    for (const childSource of (_a = sourceResult.children) !== null && _a !== void 0 ? _a : []) {
        outputSourceResult(childSource, detailed, indent);
    }
    if (detailed) {
        for (const manifest of (_b = sourceResult.manifests) !== null && _b !== void 0 ? _b : []) {
            outputManifestInfo(manifest, indent);
            outputMessages(manifest, indent + 3);
        }
    }
    (0, _1.print)();
}
function outputSourceInfo(sourceResult, indent, options) {
    const parts = [];
    // const hideSeverityIcon = options?.hideSeverityIcon ?? false;
    if (!(options === null || options === void 0 ? void 0 : options.hideSeverityIcon)) {
        parts.push(severityStatusIcon(sourceResult.severity).get());
    }
    parts.push(produceSourceLine(sourceResult));
    (0, _1.print)(parts.join(' '), indent);
}
exports.outputSourceInfo = outputSourceInfo;
function outputManifestInfo(manifest, indent, options) {
    var _a;
    options = options !== null && options !== void 0 ? options : {};
    const namingParts = [];
    if (manifest.namespace) {
        namingParts.push(`Namespace: ${manifest.namespace}`);
    }
    namingParts.push(`API: ${manifest.apiVersion}`);
    namingParts.push(`Kind: ${manifest.kind}`);
    namingParts.push(`Name: ${manifest.name}`);
    const line = namingParts.join(', ');
    const icon = (_a = options.icon) !== null && _a !== void 0 ? _a : severityStatusIcon(manifest.severity);
    (0, _1.print)(`${icon.get()} ${line}`, indent);
}
exports.outputManifestInfo = outputManifestInfo;
function outputManifestResult(manifestResult, detailed, indent, options) {
    if (!detailed) {
        if (manifestResult.severity === 'pass') {
            return;
        }
    }
    outputManifestInfo(manifestResult, indent, options);
    outputManifestResultSources(manifestResult, (indent !== null && indent !== void 0 ? indent : 0) + 3, { hideSeverityIcon: true });
    outputMessages(manifestResult, (indent !== null && indent !== void 0 ? indent : 0) + 3);
    (0, _1.print)();
}
exports.outputManifestResult = outputManifestResult;
function outputManifestResultSources(manifestResult, indent, options) {
    for (const source of manifestResult.sources) {
        outputSourceInfo(source, indent, options);
    }
}
exports.outputManifestResultSources = outputManifestResultSources;
function severityStatusIcon(severity) {
    if (severity === 'pass') {
        return _1.STATUS_ICONS.passed;
    }
    else if (severity === 'fail') {
        return _1.STATUS_ICONS.failed;
    }
    else if (severity === 'warning') {
        return _1.STATUS_ICONS.warning;
    }
    return _1.STATUS_ICONS.question;
}
exports.severityStatusIcon = severityStatusIcon;
function produceSourceLine(source) {
    const parts = [];
    if (source.kind === 'file') {
        parts.push(_1.SOURCE_ICONS.file.get());
    }
    else if (source.kind === 'web') {
        parts.push(_1.SOURCE_ICONS.web.get());
    }
    else if (source.kind === 'stream') {
        parts.push(_1.SOURCE_ICONS.stream.get());
    }
    else if (source.kind === 'k8s') {
        parts.push(_1.SOURCE_ICONS.k8s.get());
    }
    else if (source.kind === 'helm') {
        parts.push(_1.SOURCE_ICONS.helm.get());
    }
    else if (source.kind === 'kustomize') {
        parts.push(_1.SOURCE_ICONS.kustomize.get());
    }
    parts.push(`${source.kind.toUpperCase()}:`);
    parts.push(source.path);
    return parts.join(' ');
}
exports.produceSourceLine = produceSourceLine;
function outputMessages(obj, indent) {
    var _a;
    for (const msg of (_a = obj.messages) !== null && _a !== void 0 ? _a : []) {
        if (msg.severity === 'error') {
            (0, _1.printErrorLine)(msg.msg, indent);
        }
        else if (msg.severity === 'warning') {
            (0, _1.printWarningLine)(msg.msg, indent);
        }
    }
}
exports.outputMessages = outputMessages;
//# sourceMappingURL=manifest.js.map