"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isCRD = exports.getJsonSchemaResourceKey = exports.getApiResourceId = exports.parseApiVersion = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
function parseApiVersion(apiVersion) {
    const parts = apiVersion.split('/');
    if (parts.length === 1) {
        return {
            group: '',
            version: parts[0]
        };
    }
    if (parts.length === 2) {
        return {
            group: parts[0],
            version: parts[1]
        };
    }
    return null;
}
exports.parseApiVersion = parseApiVersion;
function getApiResourceId(k8sManifest) {
    if (!k8sManifest.kind) {
        return null;
    }
    const apiVersionParts = parseApiVersion(k8sManifest.apiVersion);
    if (!apiVersionParts) {
        return null;
    }
    return {
        group: apiVersionParts.group,
        version: apiVersionParts.version,
        kind: k8sManifest.kind
    };
}
exports.getApiResourceId = getApiResourceId;
function getJsonSchemaResourceKey(apiResource) {
    return the_lodash_1.default.stableStringify(apiResource);
}
exports.getJsonSchemaResourceKey = getJsonSchemaResourceKey;
function isCRD(id) {
    return (id.apiVersion === 'apiextensions.k8s.io/v1') && (id.kind === 'CustomResourceDefinition');
}
exports.isCRD = isCRD;
//# sourceMappingURL=k8s.js.map