"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeRelativePath = exports.getParentDir = exports.isAbsolutePath = exports.resolvePath = exports.isWebPath = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const path_1 = __importDefault(require("path"));
function isWebPath(fileOrPath) {
    return the_lodash_1.default.startsWith(fileOrPath, 'http://') || the_lodash_1.default.startsWith(fileOrPath, 'https://');
}
exports.isWebPath = isWebPath;
function resolvePath(path, parentDirOrPath) {
    if (parentDirOrPath && !isAbsolutePath(path)) {
        if (isWebPath(parentDirOrPath)) {
            if (!the_lodash_1.default.endsWith('/')) {
                parentDirOrPath = `${parentDirOrPath}/`;
            }
            path = `${parentDirOrPath}${path}`;
            return path;
        }
        else {
            path = path_1.default.resolve(parentDirOrPath, path);
            return path;
        }
    }
    if (!isWebPath(path)) {
        path = path_1.default.resolve(path);
    }
    return path;
}
exports.resolvePath = resolvePath;
function isAbsolutePath(fileOrPath) {
    return the_lodash_1.default.startsWith(fileOrPath, '/') || isWebPath(fileOrPath);
}
exports.isAbsolutePath = isAbsolutePath;
function getParentDir(fileOrUrl) {
    return path_1.default.dirname(fileOrUrl);
}
exports.getParentDir = getParentDir;
function makeRelativePath(fileOrUrl, parentDirOrUrl) {
    if (isWebPath(fileOrUrl)) {
        return fileOrUrl;
    }
    fileOrUrl = path_1.default.normalize(fileOrUrl);
    parentDirOrUrl = path_1.default.normalize(parentDirOrUrl);
    return path_1.default.relative(parentDirOrUrl, fileOrUrl);
}
exports.makeRelativePath = makeRelativePath;
//# sourceMappingURL=path.js.map