"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sanitizeDnPath = exports.makeDn = exports.parentDn = exports.parseDn = exports.parseRn = exports.splitDn = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
function splitDn(dn) {
    var parts = [];
    var ch = null;
    var token = "";
    var parsingKind = true;
    var parsingNaming = true;
    for (var i = 0; i < dn.length; i++) {
        var skipAdd = false;
        ch = dn.charAt(i);
        if (parsingKind) {
            if (ch == '-') {
                parsingKind = false;
            }
            else if (ch == '/') {
                skipAdd = true;
                parts.push(token);
                token = "";
            }
        }
        else {
            if (parsingNaming) {
                if (ch == ']') {
                    parsingNaming = false;
                }
            }
            else {
                if (ch == '[') {
                    parsingNaming = true;
                }
                else if (ch == '/') {
                    skipAdd = true;
                    parts.push(token);
                    token = "";
                }
            }
        }
        if (!skipAdd) {
            token += ch;
        }
    }
    if (token.length > 0) {
        parts.push(token);
    }
    return parts;
}
exports.splitDn = splitDn;
function parseRn(rn) {
    var index = rn.indexOf('-');
    if (index == -1) {
        return {
            kind: parseKind(rn),
            name: null
        };
    }
    return {
        kind: parseKind(rn.substr(0, index)),
        name: rn.substr(index + 2, rn.length - (index + 3))
    };
}
exports.parseRn = parseRn;
function parseKind(kind) {
    return kind;
}
function parseDn(dn) {
    var parts = splitDn(dn);
    return parts.map(function (x) { return parseRn(x); });
}
exports.parseDn = parseDn;
function parentDn(dn) {
    var parts = splitDn(dn);
    return makeDnFromParts(the_lodash_1.default.dropRight(parts));
}
exports.parentDn = parentDn;
function makeRn(infoOrKind) {
    if (the_lodash_1.default.isString(infoOrKind)) {
        return infoOrKind;
    }
    if (infoOrKind.name) {
        return "".concat(infoOrKind.kind, "-[").concat(infoOrKind.name, "]");
    }
    return infoOrKind.kind;
}
function makeDn(parts) {
    return makeDnFromParts(parts.map(function (x) { return makeRn(x); }));
}
exports.makeDn = makeDn;
function makeDnFromParts(parts) {
    return parts.join('/');
}
function sanitizeDnPath(dn) {
    var parts = splitDn(dn);
    var sanitizedParts = parts.map(function (x) { return sanitizeString(x); });
    return sanitizedParts.join('/');
}
exports.sanitizeDnPath = sanitizeDnPath;
function sanitizeString(str) {
    var SYMBOLS = [
        /\//g, /\\/g, /#/g, /%/g, /&/g, /\*/g, /'/g, /"/g,
        /{/g, /}/g, /</g, />'/g, /@/g,
        /:/g, /\+/g, /\|/g, /=/g, /\?/g, /!/g
    ];
    for (var _i = 0, SYMBOLS_1 = SYMBOLS; _i < SYMBOLS_1.length; _i++) {
        var ch = SYMBOLS_1[_i];
        str = str.replace(ch, '_');
    }
    return str;
}
//# sourceMappingURL=dn-utils.js.map