"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sApiResourceStatusLoader = void 0;
var K8sApiResourceStatusLoader = /** @class */ (function () {
    function K8sApiResourceStatusLoader() {
        this._apiDict = {};
    }
    K8sApiResourceStatusLoader.prototype.load = function (config) {
        var _a;
        this._apiDict = {};
        if (!config) {
            throw new Error("[K8sApiResourceStatusLoader] Missing ApiResourceStatus");
            return;
        }
        var apiResources = (_a = config.config) === null || _a === void 0 ? void 0 : _a.resources;
        if (!apiResources) {
            throw new Error("[K8sApiResourceStatusLoader] Empty ApiResourceStatus resources");
            return;
        }
        for (var _i = 0, apiResources_1 = apiResources; _i < apiResources_1.length; _i++) {
            var apiResource = apiResources_1[_i];
            if (!this._apiDict[apiResource.apiVersion]) {
                this._apiDict[apiResource.apiVersion] = {};
            }
            this._apiDict[apiResource.apiVersion][apiResource.kindName] = apiResource;
        }
    };
    K8sApiResourceStatusLoader.prototype.getByApiVersionAndKind = function (apiVersion, kind) {
        var kindsDict = this._apiDict[apiVersion];
        if (kindsDict) {
            var apiResource = kindsDict[kind];
            if (apiResource) {
                return apiResource;
            }
        }
        return null;
    };
    K8sApiResourceStatusLoader.prototype.getByApiAndVersionAndKind = function (api, version, kind) {
        var apiVersion = api ? "".concat(api, "/").concat(version) : version;
        return this.getByApiVersionAndKind(apiVersion, kind);
    };
    return K8sApiResourceStatusLoader;
}());
exports.K8sApiResourceStatusLoader = K8sApiResourceStatusLoader;
//# sourceMappingURL=k8s-api-resource-status-loader.js.map