"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NODE_LABELS = exports.DiagramLabelsDict = void 0;
var node_kind_1 = require("./entities/node-kind");
var DiagramLabelsDict = /** @class */ (function () {
    function DiagramLabelsDict() {
        this._kindResolver = {};
        this.setKind(node_kind_1.NodeKind.root, 'Root');
        /* K8s */
        this.setKind(node_kind_1.NodeKind.k8s, 'K8s');
        this.setKind(node_kind_1.NodeKind.cluster, 'Cluster');
        this.setKind(node_kind_1.NodeKind.api, 'Api');
        this.setKind(node_kind_1.NodeKind.version, 'Version');
        this.setKind(node_kind_1.NodeKind.kind, 'Kind');
        this.setKind(node_kind_1.NodeKind.resource, 'Resource');
        /* LOGIC */
        this.setKind(node_kind_1.NodeKind.logic, 'Logic');
        this.setKind(node_kind_1.NodeKind.ns, 'Namespace');
        this.setKind(node_kind_1.NodeKind.app, 'Application');
        this.setKind(node_kind_1.NodeKind.cont, 'Container');
        this.setKind(node_kind_1.NodeKind.initcont, 'Init Container');
        this.setKind(node_kind_1.NodeKind.vols, 'Volumes');
        this.setKind(node_kind_1.NodeKind.vol, 'Volume');
        this.setKind(node_kind_1.NodeKind.mounts, 'Mounts');
        this.setKind(node_kind_1.NodeKind.mount, 'Mount');
        this.setKind(node_kind_1.NodeKind.secret, 'Secret');
        this.setKind(node_kind_1.NodeKind.configmap, 'Config Map');
        this.setKind(node_kind_1.NodeKind.hpa, 'Horizontal Pod AutoScaler');
        this.setKind(node_kind_1.NodeKind.svcaccnt, 'Service Account');
        this.setKind(node_kind_1.NodeKind.rlbndg, 'Role Binding');
        this.setKind(node_kind_1.NodeKind.crlbndg, 'Cluster Role Binding');
        this.setKind(node_kind_1.NodeKind.rl, 'Role');
        this.setKind(node_kind_1.NodeKind.crl, 'Cluster Role');
        this.setKind(node_kind_1.NodeKind.pv, 'Persistent Volume');
        this.setKind(node_kind_1.NodeKind.pvc, 'Persistent Volume Claim');
        this.setKind(node_kind_1.NodeKind.psp, 'Pod Security Policy');
        this.setKind(node_kind_1.NodeKind.netpols, 'Network Policies');
        this.setKind(node_kind_1.NodeKind.netpol, 'Network Policy');
        this.setKind(node_kind_1.NodeKind.service, 'Service');
        this.setKind(node_kind_1.NodeKind.ingress, 'Ingress');
        this.setKind(node_kind_1.NodeKind.image, 'Image');
        this.setKind(node_kind_1.NodeKind.port, 'Port');
        this.setKind(node_kind_1.NodeKind.launcher, 'Launcher');
        this.setKind(node_kind_1.NodeKind.job, 'Job');
        this.setKind(node_kind_1.NodeKind.cronjob, 'Cron Job');
        this.setKind(node_kind_1.NodeKind.pod, 'Pod');
        this.setKind(node_kind_1.NodeKind.depl, 'Deployment');
        this.setKind(node_kind_1.NodeKind.ss, 'Stateful Set');
        this.setKind(node_kind_1.NodeKind.ds, 'Daemon Set');
        this.setKind(node_kind_1.NodeKind.replicaset, 'Replica Set');
        this.setKind(node_kind_1.NodeKind.rc, 'Replication Controller');
        this.setKind(node_kind_1.NodeKind.podtmpl, 'Pod Template');
        /* INFRA */
        this.setKind(node_kind_1.NodeKind.infra, 'Infra');
        this.setKind(node_kind_1.NodeKind.nodes, 'Nodes');
        this.setKind(node_kind_1.NodeKind.pool, 'Pool');
        this.setKind(node_kind_1.NodeKind.node, 'Node');
        this.setKind(node_kind_1.NodeKind.storage, 'Storage');
        this.setKind(node_kind_1.NodeKind.storclass, 'Storage Class');
        /* IMAGES */
        this.setKind(node_kind_1.NodeKind.images, 'Images');
        this.setKind(node_kind_1.NodeKind.repo, 'Repo');
        this.setKind(node_kind_1.NodeKind.tag, 'Tag');
        /* GATEWAY */
        this.setKind(node_kind_1.NodeKind.gateway, 'Gateway');
        this.setKind(node_kind_1.NodeKind.domain, 'Domain');
        this.setKind(node_kind_1.NodeKind.url, 'URL');
        /* PACKAGE */
        this.setKind(node_kind_1.NodeKind.pack, 'Package');
        this.setKind(node_kind_1.NodeKind.helm, 'Helm');
        /* RBAC */
        this.setKind(node_kind_1.NodeKind.rbac, 'RBAC');
        this.setKind(node_kind_1.NodeKind.user, 'User');
        this.setKind(node_kind_1.NodeKind.group, 'Group');
        /**** 3rd PARTY ****/
        /* Traefik */
        this.setKind(node_kind_1.NodeKind.traefik_ingress_route, 'Traefik Ingress Route');
        this.setKind(node_kind_1.NodeKind.traefik_middleware, 'Traefik Middleware');
        this.setKind(node_kind_1.NodeKind.traefik_service, 'Traefik Service');
        this.setKind(node_kind_1.NodeKind.traefik_tls_opts, 'Traefik TLS Options');
        /* NON-DIAGRAM :: SUMMARY */
        this.setKind(node_kind_1.NodeKind.summary, 'Summary');
        /* NON-DIAGRAM :: RULE-ENGINE */
        this.setKind(node_kind_1.NodeKind.rule_engine, 'Rule Engine');
        this.setKind(node_kind_1.NodeKind.rule, 'rule');
        this.setKind(node_kind_1.NodeKind.rule_items, 'rule_items');
        this.setKind(node_kind_1.NodeKind.rule_logs, 'rule_logs');
    }
    DiagramLabelsDict.prototype.setKind = function (key, value) {
        this._kindResolver[key] = value;
    };
    DiagramLabelsDict.prototype.get = function (kind) {
        var value = this._kindResolver[kind];
        if (value) {
            return value;
        }
        console.error("[DiagramLabels] Could not resolve value for: ", kind);
        // throw new Error("Could not resolve value for: " + kind);
        return kind.toString();
    };
    return DiagramLabelsDict;
}());
exports.DiagramLabelsDict = DiagramLabelsDict;
exports.NODE_LABELS = new DiagramLabelsDict();
//# sourceMappingURL=node-labels.js.map