"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTRAEFIK_MISSING_MIDDLEWARE = void 0;
var validator_id_1 = require("../../../../validator-id");
var categories_1 = require("../../../categories");
var texts_1 = require("../../texts");
function setupTRAEFIK_MISSING_MIDDLEWARE(builder) {
    builder
        .validator(validator_id_1.ValidatorID.TRAEFIK_MISSING_MIDDLEWARE)
        .category(categories_1.ValidatorCategory.Traefik)
        .title('Missing Traefik Middleware reference in IngressRoute')
        .description("\nTraefik Middlewares are used to customize the API Gateway behavior. Middlewares are referenced from IngressRoute.\n\nThis validator detects a condition when the Middleware referenced in the IngressRoute is not found.\n")
        .affected('IngressRoute')
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: IngressRoute\nmetadata:\n  name: whoami\nspec:\n  entryPoints:\n  - web\n  routes:\n  - kind: Rule\n    match: Host(`demo.kubevious.io`)\n    middlewares:\n    - name: samples-security@kubernetescrd   # Middleware not found in the namespace \"samples\"\n      namespace: samples\n    - name: redirect                         # Middleware not found in same namespace\n    services:\n    - kind: Service\n      name: whoami-svc\n      port: 80\n")
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: Middleware\nmetadata:\n  name: redirect\nspec:\n  redirectScheme:\n    permanent: true\n    scheme: https\n")
        .resolution("Check if the Middleware is present in the same namespace.")
        .resolution("Check if the Middleware is present in the namespace specified by the namespace field.")
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('Middleware', 'IngressRoute'))
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-ingressroute')
        .externalLink('https://doc.traefik.io/traefik/v2.0/middlewares/overview/');
}
exports.setupTRAEFIK_MISSING_MIDDLEWARE = setupTRAEFIK_MISSING_MIDDLEWARE;
//# sourceMappingURL=TRAEFIK_MISSING_MIDDLEWARE.js.map