"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTRAEFIK_MISSING_SERVICE = void 0;
var validator_id_1 = require("../../../../validator-id");
var categories_1 = require("../../../categories");
var texts_1 = require("../../texts");
function setupTRAEFIK_MISSING_SERVICE(builder) {
    builder
        .validator(validator_id_1.ValidatorID.TRAEFIK_MISSING_SERVICE)
        .category(categories_1.ValidatorCategory.Traefik)
        .title('Missing Traefik Service reference in IngressRoute or TraefikService')
        .description("IngressRoutes expose Kubernetes applications externally to the public.\nIngresses associate with Pods through references to Services.\n\nTraefikService is an abstraction on top of Kubernetes Services to enable advanced\nrouting such as weighted load balancing, mirroring and sticky sessions.\n\nThis validator detects a condition when IngressRoutes or TraefikServices are pointing\nto non-existing Services. It usually indicates a naming error in the IngressRoutes, TraefikServices or Services.\n")
        .affected('IngressRoute')
        .affected('TraefikService')
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: IngressRoute\nmetadata:\n    name: whoami\nspec:\n    entryPoints:\n    - web\n    routes:\n    - kind: Rule\n      match: Host(`demo.kubevious.io`)\n      services:\n      - kind: Service\n        name: foo               # K8s Service \"foo\" not found\n        port: 80\n      - kind: TraefikService\n        name: weighted          # TraefikService \"weighted\" not found\n        port: 80\n")
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n  name: bar                     # Different name in IngressRoute\n...\n")
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: TraefikService\nmetadata:\n    name: weighted              # Different name in IngressRoute\nspec:\n  weighted:\n    services:\n    - name: whoamiv1\n      port: 80\n      weight: 3\n    - name: whoamiv2            # Missing Service whoamiv2\n      port: 80\n      weight: 1\n")
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n    name: whoamiv1              \n...\n")
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n    name: whoamiv3              # Different name in TraefikService\n...\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('Service'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('Service', 'IngressRoute'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('Service', 'IngressRoute'))
        .resolution("\nMake necessary naming corrections on the IngressRoute, TraefikService or the Service.\n")
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-ingressroute')
        .externalLink('https://doc.traefik.io/traefik/routing/services/')
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-traefikservice')
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/service/');
}
exports.setupTRAEFIK_MISSING_SERVICE = setupTRAEFIK_MISSING_SERVICE;
//# sourceMappingURL=TRAEFIK_MISSING_SERVICE.js.map