"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTRAEFIK_MISSING_TLS_OPTIONS = void 0;
var validator_id_1 = require("../../../../validator-id");
var categories_1 = require("../../../categories");
var texts_1 = require("../../texts");
function setupTRAEFIK_MISSING_TLS_OPTIONS(builder) {
    builder
        .validator(validator_id_1.ValidatorID.TRAEFIK_MISSING_TLS_OPTIONS)
        .category(categories_1.ValidatorCategory.Traefik)
        .title('Missing Traefik TLSOptions reference in IngressRoute')
        .description("\nTraefik TLSOptions are used to configure Traefik Proxy TLS connection parameters. TLSOptions are referenced from IngressRoute.\n\nThis validator detects a condition when the TLSOptions referenced in the IngressRoute is not found.\n")
        .affected('IngressRoute')
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: IngressRoute\nmetadata:\n  name: whoami\nspec:\n  entryPoints:\n  - websecure\n  routes:\n  - kind: Rule\n    match: Host(`demo.kubevious.io`)\n    services:\n    - kind: Service\n      name: whoami-svc\n      port: 80\n    tls:\n      certResolver: le\n      domains:\n      - main: demo.kubevious.io\n        sans:\n        - demo.kubevious.io\n      options:\n        name: foo                               # TLSOptions not found in the namespace \"samples\"\n        namespace: samples\n")
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: TLSOption\nmetadata:\n  name: bar                                     # Different name in IngressRoute\n  namespace: samples\nspec:\n  cipherSuites:\n  - TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256\n  - TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256\n  - TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384\n  - TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305\n  - TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384\n  - TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305\n  - TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305\n  - TLS_AES_256_GCM_SHA384\n  - TLS_AES_128_GCM_SHA256\n  - TLS_CHACHA20_POLY1305_SHA256\n  - TLS_FALLBACK_SCSV\n  curvePreferences:\n  - CurveP521\n  - CurveP384\n  minVersion: VersionTLS12\n  sniStrict: true\n")
        .resolution("Check if the TLSOptions is present in the same namespace.")
        .resolution("Check if the TLSOptions is present in the namespace specified by the namespace field.")
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('TLSOptions', 'IngressRoute'))
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-ingressroute')
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-tlsoption')
        .externalLink('https://doc.traefik.io/traefik/https/tls/#tls-options');
}
exports.setupTRAEFIK_MISSING_TLS_OPTIONS = setupTRAEFIK_MISSING_TLS_OPTIONS;
//# sourceMappingURL=TRAEFIK_MISSING_TLS_OPTIONS.js.map