"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTRAEFIK_UNUSED_MIDDLEWARE = void 0;
var validator_id_1 = require("../../../../validator-id");
var categories_1 = require("../../../categories");
function setupTRAEFIK_UNUSED_MIDDLEWARE(builder) {
    builder
        .validator(validator_id_1.ValidatorID.TRAEFIK_UNUSED_MIDDLEWARE)
        .category(categories_1.ValidatorCategory.Traefik)
        .title('Unused Traefik Middleware')
        .description("\nTraefik Middlewares are used to customize the API Gateway behavior. Middlewares are referenced from IngressRoute.\n\nThis validator detects when a Middleware is not attached to IngressRoutes. \n\nThat can be an indication of a typo in the Middleware name, namespace or IngressRoutes reference.\n")
        .affected('Middleware')
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: Middleware\nmetadata:\n  name: redirect                       # IngressRoute references \"redirect-https\" instead\nspec:\n  redirectScheme:\n    permanent: true\n    scheme: https\n")
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: IngressRoute\nmetadata:\n  name: whoami\nspec:\n  entryPoints:\n  - web\n  routes:\n  - kind: Rule\n    match: Host(`demo.kubevious.io`)\n    middlewares:\n    - name: redirect-https             # Middleware not found in same namespace\n    services:\n    - kind: Service\n      name: whoami-svc\n      port: 80\n")
        .resolution("\nExamine IngressRoutes within the namespace and determine if the Middleware is supposed used in any of them.")
        .resolution("\nExamine global references in IngressRoutes and see if any of them should refer to this Middleware using the \"<namespace>-<middleware>@kubernetescrd\" pattern.\n")
        .resolution("\nIf the Middleware is indeed unused, it may need to be just removed.\n")
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-ingressroute')
        .externalLink('https://doc.traefik.io/traefik/v2.0/middlewares/overview/');
}
exports.setupTRAEFIK_UNUSED_MIDDLEWARE = setupTRAEFIK_UNUSED_MIDDLEWARE;
//# sourceMappingURL=TRAEFIK_UNUSED_MIDDLEWARE.js.map