"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTRAEFIK_UNUSED_SERVICE = void 0;
var validator_id_1 = require("../../../../validator-id");
var categories_1 = require("../../../categories");
function setupTRAEFIK_UNUSED_SERVICE(builder) {
    builder
        .validator(validator_id_1.ValidatorID.TRAEFIK_UNUSED_SERVICE)
        .category(categories_1.ValidatorCategory.Traefik)
        .title('Unused Traefik Service')
        .description("\nTraefikService is an abstraction on top of Kubernetes Services to enable advanced\nrouting such as weighted load balancing, mirroring and sticky sessions.\n\nThis validator detects when a TraefikService is not attached to IngressRoutes. \n\nThat can be an indication of a typo in the TraefikService name or IngressRoutes reference.\n")
        .affected('TraefikService')
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: TraefikService\nmetadata:\n    name: weighted              # Different name in IngressRoute\nspec:\n  weighted:\n    services:\n    - name: whoamiv1\n      port: 80\n      weight: 3\n    - name: whoamiv2\n      weight: 1\n")
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: IngressRoute\nmetadata:\n    name: whoami\nspec:\n    entryPoints:\n    - web\n    routes:\n    - kind: Rule\n      match: Host(`demo.kubevious.io`)\n      services:\n      - kind: TraefikService\n        name: weighted-svc      # TraefikService \"weighted\" not found\n        port: 80\n")
        .resolution("\nExamine IngressRoutes within the namespace and determine if the TraefikService is supposed used in any of them.\n")
        .resolution("\nIf the TraefikService is indeed unused, it may need to be just removed.\n")
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-ingressroute')
        .externalLink('https://doc.traefik.io/traefik/routing/services/')
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-traefikservice');
}
exports.setupTRAEFIK_UNUSED_SERVICE = setupTRAEFIK_UNUSED_SERVICE;
//# sourceMappingURL=TRAEFIK_UNUSED_SERVICE.js.map