"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupTRAEFIK_UNUSED_TLS_OPTIONS = void 0;
var validator_id_1 = require("../../../../validator-id");
var categories_1 = require("../../../categories");
function setupTRAEFIK_UNUSED_TLS_OPTIONS(builder) {
    builder
        .validator(validator_id_1.ValidatorID.TRAEFIK_UNUSED_TLS_OPTIONS)
        .category(categories_1.ValidatorCategory.Traefik)
        .title('Unused Traefik TLSOptions')
        .description("\nTraefik TLSOptions are used to configure Traefik Proxy TLS connection parameters. TLSOptions are referenced from IngressRoute.\n\nThis validator detects when a TLSOptions is not attached to IngressRoutes. \n\nThat can be an indication of a typo in the TLSOptions name, namespace or IngressRoutes reference.\n")
        .affected('TLSOptions')
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: TLSOption\nmetadata:\n  name: bar                                     # Different name in IngressRoute\n  namespace: samples\nspec:\n  cipherSuites:\n  - TLS_ECDHE_ECDSA_WITH_AES_128_CBC_SHA256\n  - TLS_ECDHE_ECDSA_WITH_AES_128_GCM_SHA256\n  - TLS_ECDHE_RSA_WITH_AES_256_GCM_SHA384\n  - TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305\n  - TLS_ECDHE_ECDSA_WITH_AES_256_GCM_SHA384\n  - TLS_ECDHE_RSA_WITH_CHACHA20_POLY1305\n  - TLS_ECDHE_ECDSA_WITH_CHACHA20_POLY1305\n  - TLS_AES_256_GCM_SHA384\n  - TLS_AES_128_GCM_SHA256\n  - TLS_CHACHA20_POLY1305_SHA256\n  - TLS_FALLBACK_SCSV\n  curvePreferences:\n  - CurveP521\n  - CurveP384\n  minVersion: VersionTLS12\n  sniStrict: true\n")
        .example("\napiVersion: traefik.containo.us/v1alpha1\nkind: IngressRoute\nmetadata:\n  name: whoami\nspec:\n  entryPoints:\n  - websecure\n  routes:\n  - kind: Rule\n    match: Host(`demo.kubevious.io`)\n    services:\n    - kind: Service\n      name: whoami-svc\n      port: 80\n    tls:\n      certResolver: le\n      options:\n        name: foo                               # TLSOptions not found in the namespace \"samples\"\n        namespace: samples\n")
        .resolution("\nExamine IngressRoutes within the namespace and determine if the TLSOptions is supposed used in any of them.")
        .resolution("\nExamine cross-namespace references in IngressRoutes and see if any of them should refer to this TLSOptions.\n")
        .resolution("\nIf the TLSOptions is indeed unused, it may need to be just removed.\n")
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-ingressroute')
        .externalLink('https://doc.traefik.io/traefik/routing/providers/kubernetes-crd/#kind-tlsoption')
        .externalLink('https://doc.traefik.io/traefik/https/tls/#tls-options');
}
exports.setupTRAEFIK_UNUSED_TLS_OPTIONS = setupTRAEFIK_UNUSED_TLS_OPTIONS;
//# sourceMappingURL=TRAEFIK_UNUSED_TLS_OPTIONS.js.map