"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_HPA_APP = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_HPA_APP(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_HPA_APP)
        .category(categories_1.ValidatorCategory.Container)
        .subCategory(categories_1.ValidatorSubCategory.Scale)
        .title('Unresolved Application reference in HorizontalPodAutoscaler')
        .description("The purpose of HorizontalPodAutoscaler is to automatically update \nnumber of replicas of scalable resources (such as a Deployment or StatefulSet)\nto match the current demand.\n\nThis validator detects a condition when a Deployment (or other scalable resource)\nused in the HorizontalPodAutoscaler is not found. \n")
        .affected('HorizontalPodAutoscaler')
        .example("\napiVersion: autoscaling/v1\nkind: HorizontalPodAutoscaler\nspec:\n  minReplicas: 2\n  maxReplicas: 5\n  scaleTargetRef:\n    kind: Deployment\n    name: web-frontend        # Missing Deployment\n    apiVersion: apps/v1\n")
        .example("\napiVersion: apps/v1\nkind: Deployment\nmetadata:\n  name: frontend\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('Deployment or StatefulSet'))
        .resolution("Check if the Deployment or StatefulSet is present in a different namespace.\n    Kubevious Search can be a very handy tool to find Deployments or StatefulSets across namespaces.\n    You cannot autoscale Deployments from a different namespaces.\n    In that case you would need to create a HorizontalPodAutoscaler in namespace where your workloads reside.")
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('Deployment or StatefulSet', 'scaleTargetRef spec'))
        .externalLink('https://kubernetes.io/docs/tasks/run-application/horizontal-pod-autoscale/');
}
exports.setupMISSING_HPA_APP = setupMISSING_HPA_APP;
//# sourceMappingURL=MISSING_HPA_APP.js.map