"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupPOD_STATUS_NOT_READY = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupPOD_STATUS_NOT_READY(builder) {
    builder
        .validator(validator_id_1.ValidatorID.POD_STATUS_NOT_READY)
        .category(categories_1.ValidatorCategory.Compute)
        .subCategory(categories_1.ValidatorSubCategory.Status)
        .title('Stage 4. Pod not ready')
        .description("During the launch, Pods go through a sequence of execution stages.\nAfter scheduling the Pod on the Node and preparing and launching all containers,\nKubernetes will check if the Pod is ready to serve requests.\n\nThis validator detects if the Pod is not ready to serve requests. \nPod can become not ready if the readinessProbe has failed.\nAlso, there can be a readinessGates defined in the PodSpec\nto check for other custom readiness conditions.\n")
        .affected('Pod')
        .example("\nkind: Pod\n...\nstatus:\n  conditions:\n    - type: Ready\n      status: \"False\"\n      lastProbeTime: null\n      lastTransitionTime: 2022-01-01T00:00:00Z    \n")
        .resolutionAndExample('Check Pod readinessProbe', "\nkind: Pod\n...\nspec:\n  containers:\n  - name: worker\n    ports:\n    - containerPort: 8080\n    readinessProbe:\n      tcpSocket:\n        port: 8080\n      initialDelaySeconds: 5\n      periodSeconds: 10\n")
        .resolutionAndExample('Check Pod readinessGates', "\nkind: Pod\n...\nspec:\n  readinessGates:\n    - conditionType: \"www.example.com/feature-1\"\nstatus:\n  conditions:\n    - type: Ready                              # a built in PodCondition\n      status: \"False\"\n      lastProbeTime: null\n      lastTransitionTime: 2022-01-01T00:00:00Z\n    - type: \"www.example.com/feature-1\"        # an extra PodCondition\n      status: \"False\"\n      lastProbeTime: null\n      lastTransitionTime: 2022-01-01T00:00:00Z\n")
        .externalLink('https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/')
        .externalLink('https://kubernetes.io/docs/tasks/configure-pod-container/configure-liveness-readiness-startup-probes/');
}
exports.setupPOD_STATUS_NOT_READY = setupPOD_STATUS_NOT_READY;
//# sourceMappingURL=POD_STATUS_NOT_READY.js.map