"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupUNOWNED_POD = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupUNOWNED_POD(builder) {
    builder
        .validator(validator_id_1.ValidatorID.UNOWNED_POD)
        .category(categories_1.ValidatorCategory.Compute)
        .subCategory(categories_1.ValidatorSubCategory.Controller)
        .title('Directly launching a Pod')
        .description("In Kubernetes Pod is considered a low level construct.\nDirectly instantiating Pods is not recommended.\nInstead there are higher level controllers available to launch and maintain Pods.\nConsider using Deployment, DaemonSet, StatefulSet, Job or CronJob instead.")
        .affected('Pod')
        .example("\napiVersion: v1\nkind: Pod\nmetadata:\n  name: frontend\nspec:\n  containers:\n    - name: nginx\n      image: nginx:1.21.6\n")
        .resolution('Use Deployment instead of Pods. ')
        .resolutionExample("\napiVersion: apps/v1\nkind: Deployment\nmetadata:\n  name: frontend\nspec:\n  replicas: 1\n  selector:\n    matchLabels:\n      tier: frontend\n  template:\n    metadata:\n      labels:\n        tier: frontend\n      spec:\n        containers:\n          - name: nginx\n            image: nginx:1.21.6\n")
        .externalLink('https://kubernetes.io/docs/concepts/workloads/controllers/deployment/')
        .externalLink('https://kubernetes.io/docs/concepts/workloads/controllers/statefulset/')
        .externalLink('https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/')
        .externalLink('https://kubernetes.io/docs/concepts/workloads/controllers/job/')
        .externalLink('https://kubernetes.io/docs/concepts/workloads/controllers/cronjob/');
}
exports.setupUNOWNED_POD = setupUNOWNED_POD;
//# sourceMappingURL=UNOWNED_POD.js.map