"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupUNOWNED_REPLICA_SET = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupUNOWNED_REPLICA_SET(builder) {
    /* UNOWNED_REPLICA_SET */
    builder
        .validator(validator_id_1.ValidatorID.UNOWNED_REPLICA_SET)
        .category(categories_1.ValidatorCategory.Compute)
        .subCategory(categories_1.ValidatorSubCategory.Controller)
        .title('Directly using ReplicaSet')
        .description("A ReplicaSet's purpose is to maintain a stable set of replica Pods running at any given time.\nHowever, a Deployment is a higher-level concept that manages ReplicaSets and provides\ndeclarative updates to Pods along with a lot of other useful features.\nTherefore, we recommend using Deployments instead of directly using ReplicaSets.")
        .affected('ReplicaSet')
        .example("\napiVersion: apps/v1\nkind: ReplicaSet\n  metadata:\n    name: frontend\n  spec:\n    replicas: 3\n    selector:\n      matchLabels:\n        tier: frontend\n    template:\n      metadata:\n        labels:\n          tier: frontend\n      spec:\n        containers:\n          - name: nginx\n            image: nginx:1.21.6\n")
        .resolution('Use Deployment instead of ReplicaSet. ')
        .resolutionExample("\napiVersion: apps/v1\nkind: Deployment\n  metadata:\n    name: frontend\n  spec:\n    replicas: 3\n    selector:\n      matchLabels:\n        tier: frontend\n    template:\n      metadata:\n        labels:\n          tier: frontend\n        spec:\n          containers:\n            - name: nginx\n              image: nginx:1.21.6\n")
        .externalLink('https://kubernetes.io/docs/concepts/workloads/controllers/replicaset/')
        .externalLink('https://kubernetes.io/docs/concepts/workloads/controllers/deployment/');
}
exports.setupUNOWNED_REPLICA_SET = setupUNOWNED_REPLICA_SET;
//# sourceMappingURL=UNOWNED_REPLICA_SET.js.map