"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupUNUSED_CONFIG_MAP = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupUNUSED_CONFIG_MAP(builder) {
    builder
        .validator(validator_id_1.ValidatorID.UNUSED_CONFIG_MAP)
        .category(categories_1.ValidatorCategory.Configuration)
        .title('Unused ConfigMap')
        .description("One of the most common uses of ConfigMap is to mount it to a container\nfile system or use it as environment variables.\n\nThis validator detects when a ConfigMap is not mounted to a volume and not used as \ncontainer environment variables. \n\nThat can be an indication of a typo in a ConfigMap name or ConfigMap references in\nvolume mount, projections, or environment variables.\n")
        .affected('ConfigMap')
        .example("\napiVersion: v1\nkind: ConfigMap\nmetadata:\n  name: config-foo                      # This ConfigMap is not used elsewhere\ndata:\n  my-key: my-value\n")
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      containers:\n        - name: my-container\n          env:\n            - name: MY_ENV_VAR\n              valueFrom:\n                configMapKeyRef:\n                  name: config-foo-1    # This ConfigMap is not present\n                  key: my-key\n          envFrom:\n            - configMapRef:\n                name: config-foo-2      # This ConfigMap is not present\n")
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      volumes:\n        - name: my-config-volume\n          configMap:\n            name: config-bar            # This ConfigMap is not present\n")
        .resolution("\nExamine applications within the namespace and determine if the ConfigMap is supposed to\nbe mounted to the file system or used as environment variables.")
        .resolution("\nIf the ConfigMap is supposed to be used in volume maps, either correct the ConfigMap name or\nthe reference name.\n")
        .resolution("\nIf the ConfigMap is indeed unused, it may need to be just removed.\n")
        .resolution("\nThere is a possible false positive trigger for this validator.\nA ConfigMap can be used by other third-party apps or using direct Kubernetes APIs.\nSuch a condition cannot be detected using in Kubevious, so in such a case,\nthis validator can be turned off or warning just ignored.\n")
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/config-and-storage-resources/volume/#projections')
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#environment-variables');
}
exports.setupUNUSED_CONFIG_MAP = setupUNUSED_CONFIG_MAP;
//# sourceMappingURL=UNUSED_CONFIG_MAP.js.map