"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupUNUSED_SECRET = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupUNUSED_SECRET(builder) {
    builder
        .validator(validator_id_1.ValidatorID.UNUSED_SECRET)
        .category(categories_1.ValidatorCategory.Configuration)
        .title('Unused Secret')
        .description("Secrets are used to store sensitive data. Secrets can be used in containers \nas environment variables or mounted as volumes. Secrets are also used in \nServiceAccounts to store the token when accessing Kubernetes API Server.\n\nThis validator detects when a Secret is not mounted to a volume, not used as \ncontainer environment variables and not used in any ServiceAccounts. \n\nThat can be an indication of a typo in a Secret name or Secret references in\nvolume mount, projections, environment variables or ServiceAccounts.\n")
        .affected('Secret')
        .example("\napiVersion: v1\nkind: Secret\nmetadata:\n  name: secret-foo                      # This Secret is not used elsewhere\ndata:\n  my-key: bXktdmFsdWU=\n")
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      containers:\n        - name: my-container\n          env:\n            - name: MY_ENV_VAR\n              valueFrom:\n                secretKeyRef:\n                  name: secret-foo-1    # This Secret is not present\n                  key: my-key\n          envFrom:\n            - secretRef:\n                name: secret-foo-2      # This Secret is not present\n")
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      volumes:\n        - name: my-secret-volume\n          secret:\n            name: secret-bar            # This Secret is not present\n")
        .resolution("\nExamine applications within the namespace and determine if the Secret is supposed to\nbe mounted to the file system, used as environment variables or used in ServiceAccounts.")
        .resolution("\nIf the Secret is supposed to be used in volume maps, either correct the Secret name or\nthe reference name.\n")
        .resolution("\nIf the Secret is indeed unused, it may need to be just removed.\n")
        .resolution("\nThere is a possible false positive trigger for this validator.\nA Secret can be used by other third-party apps or using direct Kubernetes APIs.\nSuch a condition cannot be detected using in Kubevious, so in such a case,\nthis validator can be turned off or warning just ignored.\n")
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/config-and-storage-resources/volume/#projections')
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#environment-variables')
        .externalLink('https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/');
}
exports.setupUNUSED_SECRET = setupUNUSED_SECRET;
//# sourceMappingURL=UNUSED_SECRET.js.map