"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupEMPTY_ENV_CONFIG_MAP = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupEMPTY_ENV_CONFIG_MAP(builder) {
    builder
        .validator(validator_id_1.ValidatorID.EMPTY_ENV_CONFIG_MAP)
        .category(categories_1.ValidatorCategory.Container)
        .subCategory(categories_1.ValidatorSubCategory.EnvironmentVariables)
        .title('Empty ConfigMap used in container environment variables')
        .description("You can use ConfigMaps as values for container environment variables.\nThis validator detects when a ConfigMap used as a source for environment variables is empty.\nBecause of that, no environment variables will be sources from the ConfigMap.\n")
        .affectedAllWorkloads()
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      containers:\n        - name: my-container\n          envFrom:\n            - configMapRef:\n              name: my-config-map # This ConfigMap is empty\n")
        .example("\nkind: ConfigMap\nmetadata:\n  name: my-config-map\ndata: {}                          # Empty data or no data at all\n")
        .resolution(texts_1.RESOLUTION_TEXT.populateEnvVarsData('ConfigMap'))
        .resolution(texts_1.RESOLUTION_TEXT.deleteEnvVarsSource('ConfigMap'))
        .resolutionExample("\nkind: ConfigMap\nmetadata:\n  name: my-config-map\ndata: \n  ENV_FOO: bar\n")
        .resolutionExample("$ kubectl delete configmap my-config-map -n <the-namespace>", 'shell')
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#environment-variables');
}
exports.setupEMPTY_ENV_CONFIG_MAP = setupEMPTY_ENV_CONFIG_MAP;
//# sourceMappingURL=EMPTY_ENV_CONFIG_MAP.js.map