"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_ENV_CONFIG_MAP = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_ENV_CONFIG_MAP(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_ENV_CONFIG_MAP)
        .category(categories_1.ValidatorCategory.Container)
        .subCategory(categories_1.ValidatorSubCategory.EnvironmentVariables)
        .title('Unresolved ConfigMap reference in container environment variables')
        .description("You can use ConfigMaps as values for container environment variables.\nThis validator detects a condition when a ConfigMap used as a source for \nenvironment variables in the container spec is not found.\nThat can happen if the ConfigMap\nwas deleted or renamed, or there was a typo in the envFrom.configMapKeyRef.\nNote that this check is skipped when the reference is marked as optional.")
        .affectedAllWorkloads()
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      containers:\n        - name: my-container\n          env:\n            - name: MY_ENV_VAR\n              valueFrom:\n                configMapKeyRef:\n                  name: my-config-map  # This ConfigMap is not present\n                  key: key-in-my-config-map\n                  optional: false\n          envFrom:\n            - configMapRef:\n                name: my-other-config-map # This ConfigMap is not present\n                optional: false\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('ConfigMap'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('ConfigMap', 'Pod'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('ConfigMap', 'container environment variables spec'))
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#environment-variables');
}
exports.setupMISSING_ENV_CONFIG_MAP = setupMISSING_ENV_CONFIG_MAP;
//# sourceMappingURL=MISSING_ENV_CONFIG_MAP.js.map