"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_ENV_CONFIG_MAP_KEY = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupMISSING_ENV_CONFIG_MAP_KEY(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_ENV_CONFIG_MAP_KEY)
        .category(categories_1.ValidatorCategory.Container)
        .subCategory(categories_1.ValidatorSubCategory.EnvironmentVariables)
        .title('Unresolved ConfigMap Key reference in container environment variables')
        .description("You can use ConfigMaps as values for container environment variables.\nThis validator detects a condition when a ConfigMap data key used as a source for \nenvironment variables in the container spec is not found.\nThat can happen if the ConfigMap data key\nwas deleted or renamed, or there was a typo in the envFrom.configMapKeyRef.\nNote that this check is skipped when the reference is marked as optional.")
        .affectedAllWorkloads()
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      containers:\n        - name: my-container\n          env:\n            - name: MY_ENV_VAR\n              valueFrom:\n                configMapKeyRef:\n                  name: my-config-map\n                  key: bar               # Key bar not present in the configMap\n                  optional: false\n")
        .example("\nkind: ConfigMap\nmetadata:\n  name: my-config-map\ndata: \n  foo: bar\n")
        .resolution('Check the data section of the ConfigMap. Ensure that the key referenced in the valueFrom is present.')
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#environment-variables');
}
exports.setupMISSING_ENV_CONFIG_MAP_KEY = setupMISSING_ENV_CONFIG_MAP_KEY;
//# sourceMappingURL=MISSING_ENV_CONFIG_MAP_KEY.js.map