"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_ENV_SECRET = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_ENV_SECRET(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_ENV_SECRET)
        .category(categories_1.ValidatorCategory.Container)
        .subCategory(categories_1.ValidatorSubCategory.EnvironmentVariables)
        .title('Unresolved Secret reference in container environment variables')
        .description("You can use Secrets as values for container environment variables.\nThis validator detects a condition when a Secret used as a source for \nenvironment variables in the container spec is not found.\nThat can happen if the Secret\nwas deleted or renamed, or there was a typo in the envFrom.secretRef.\nNote that this check is skipped when the reference is marked as optional.")
        .affectedAllWorkloads()
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      containers:\n        - name: my-container\n          env:\n            - name: MY_ENV_VAR\n              valueFrom:\n                secretKeyRef:\n                  name: my-secret  # This Secret is not present\n                  key: key-in-my-secret\n                  optional: false\n          envFrom:\n            - secretRef:\n                name: my-other-secret # This Secret is not present\n                optional: false\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('Secret'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('Secret', 'Pod'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('Secret', 'container environment variables spec'))
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#environment-variables');
}
exports.setupMISSING_ENV_SECRET = setupMISSING_ENV_SECRET;
//# sourceMappingURL=MISSING_ENV_SECRET.js.map