"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_VOLUME_MOUNT_CONFIG_MAP = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_VOLUME_MOUNT_CONFIG_MAP(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_VOLUME_MOUNT_CONFIG_MAP)
        .category(categories_1.ValidatorCategory.Container)
        .subCategory(categories_1.ValidatorSubCategory.VolumeMount)
        .title('Unresolved ConfigMap reference in container volume mount')
        .description("You can mount ConfigMaps to Pods as volumes.\nThis validator detects a condition when a ConfigMap mounted as a\nvolume in PodTemplateSpec is not found. That can happen if the ConfigMap\nwas deleted or renamed, or there was a typo in the volume mount spec.\nNote that this check is skipped for volume mounts marked as optional.")
        .affectedAllWorkloads()
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      volumes:\n        - name: my-config-volume\n          configMap:\n            name: my-config-map # This ConfigMap is not present\n            optional: false\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('ConfigMap'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('ConfigMap', 'Pod'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('ConfigMap', 'volume spec'))
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/config-and-storage-resources/volume/#projections');
}
exports.setupMISSING_VOLUME_MOUNT_CONFIG_MAP = setupMISSING_VOLUME_MOUNT_CONFIG_MAP;
//# sourceMappingURL=MISSING_VOLUME_MOUNT_CONFIG_MAP.js.map