"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_VOLUME_MOUNT_SECRET = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_VOLUME_MOUNT_SECRET(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_VOLUME_MOUNT_SECRET)
        .category(categories_1.ValidatorCategory.Container)
        .subCategory(categories_1.ValidatorSubCategory.VolumeMount)
        .title('Unresolved Secret reference in container volume mount')
        .description("You can mount Secrets to Pods as volumes.\nThis validator detects a condition when a Secret mounted as a\nvolume in PodTemplateSpec is not found. That can happen if the Secret\nwas deleted or renamed, or there was a typo in the volume mount spec.\nNote that this check is skipped for volume mounts marked as optional.")
        .affectedAllWorkloads()
        .example("\nkind: Deployment\nspec:\n  template:\n  spec:\n    volumes:\n      - name: my-secret-volume\n        secret:\n          secretName: my-secret # This Secret is not present\n          optional: false\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('Secret'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('Secret', 'Pod'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('Secret', 'volume spec'))
        .externalLink('https://kubernetes.io/docs/reference/kubernetes-api/config-and-storage-resources/volume/#projections');
}
exports.setupMISSING_VOLUME_MOUNT_SECRET = setupMISSING_VOLUME_MOUNT_SECRET;
//# sourceMappingURL=MISSING_VOLUME_MOUNT_SECRET.js.map