"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupINGRESS_NOT_MOUNT_TO_APPS = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupINGRESS_NOT_MOUNT_TO_APPS(builder) {
    builder
        .validator(validator_id_1.ValidatorID.INGRESS_NOT_MOUNT_TO_APPS)
        .category(categories_1.ValidatorCategory.Networking)
        .title('No Application exposed by Ingress')
        .description("Ingresses expose Kubernetes applications externally to the public.\nIngresses associate with Pods through references to Services.\n\nThis validator detects a condition when Ingresses are not exposing any application.\nIt can happen if the Ingress rules spec is empty, Services are unresolved, or \nthe Services referenced in the Ingress do not reference an application.\n")
        .affected('Ingress')
        .example("\napiVersion: networking.k8s.io/v1\nkind: Ingress\nmetadata:\n  name: my-ingress\nspec:\n  rules:\n  - http:\n      paths:\n      - path: /\n        pathType: Prefix\n        backend:\n          service:\n            name: my-service\n            port:\n              number: 80\n")
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n  name: my-service\nspec:\n  type: ClusterIP\n  selector:\n    app: non-existing-app-label  # There are no apps with such label\n...\n")
        .resolution("\nIdentify which Service the Ingress should refer to.")
        .resolution("\nInspect Services definitions and ensure that corresponding applications\nreferenced in the label selector are present.\n")
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/ingress/')
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/service/')
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/connect-applications-service/');
}
exports.setupINGRESS_NOT_MOUNT_TO_APPS = setupINGRESS_NOT_MOUNT_TO_APPS;
//# sourceMappingURL=INGRESS_NOT_MOUNT_TO_APPS.js.map