"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_INGRESS_SERVICE = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_INGRESS_SERVICE(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_INGRESS_SERVICE)
        .category(categories_1.ValidatorCategory.Networking)
        .title('Unresolved Service reference in Ingress')
        .description("Ingresses expose Kubernetes applications externally to the public.\nIngresses associate with Pods through references to Services.\n\nThis validator detects a condition when Ingresses are pointing to non-existing Services.\nIt usually indicates a naming error in the Ingress or Service.\n")
        .affected('Ingress')
        .example("\napiVersion: networking.k8s.io/v1\nkind: Ingress\nmetadata:\n  name: my-ingress\nspec:\n  rules:\n  - http:\n      paths:\n      - path: /\n        pathType: Prefix\n        backend:\n          service:\n            name: foo-service    # Service not found\n            port:\n              number: 80\n")
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n  name: bar-service              # Different name in Ingress\n...\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('Service'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('Service', 'Ingress'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('Service', 'Ingress'))
        .resolution("\nMake necessary naming corrections on the Ingress or the Service.\n")
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/ingress/')
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/service/');
}
exports.setupMISSING_INGRESS_SERVICE = setupMISSING_INGRESS_SERVICE;
//# sourceMappingURL=MISSING_INGRESS_SERVICE.js.map