"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_INGRESS_SERVICE_PORT = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupMISSING_INGRESS_SERVICE_PORT(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_INGRESS_SERVICE_PORT)
        .category(categories_1.ValidatorCategory.Networking)
        .title('Unresolved Service Port reference in Ingress')
        .description("Ingresses expose Kubernetes applications externally to the public.\nIngresses associate with Pods through references to Services.\n\nThis validator detects a condition when Ingresses are pointing to non-existing Port of the Service.\n")
        .affected('Ingress')
        .example("\napiVersion: networking.k8s.io/v1\nkind: Ingress\nmetadata:\n  name: my-ingress\nspec:\n  rules:\n  - http:\n      paths:\n      - path: /\n        pathType: Prefix\n        backend:\n          service:\n            name: foo-service\n            port:\n              number: 80    # Port 80 not present in the Service\n")
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n  name: foo-service             \nspec:\n  ports:\n  - port: 9000              # Different port used in Ingress\n    protocol: TCP\n    targetPort: http  \n...\n")
        .resolution('Inspect both Service and Ingress manifests')
        .resolution("\nMake necessary corrections on port specifications of the Ingress or the Service.\n")
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/ingress/')
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/service/');
}
exports.setupMISSING_INGRESS_SERVICE_PORT = setupMISSING_INGRESS_SERVICE_PORT;
//# sourceMappingURL=MISSING_INGRESS_SERVICE_PORT.js.map