"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_SERVICE_APP = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupMISSING_SERVICE_APP(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_SERVICE_APP)
        .category(categories_1.ValidatorCategory.Networking)
        .title('Unresolved Application reference in Service')
        .description("Services connect Kubernetes applications.\nLabel selectors are used to associating Pods with Services.\n\nThis validator detects a condition when no application is associated with a Service.\nIt usually indicates a naming error in workload or Service labels.\n")
        .affected('Service')
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n  name: my-app-service\nspec:\n  type: ClusterIP\n  selector:\n    foo: bar                # label-value not found\n")
        .example("\napiVersion: apps/v1\nkind: Deployment\nmetadata:\n  name: my-app\n  labels:\n    foo: not-bar            # different in the Service\n")
        .resolution("\nIdentify which application should the Service refer to.")
        .resolution("\nMake correction to the labels on the workload or the Service.\n")
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/service/')
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/connect-applications-service/');
}
exports.setupMISSING_SERVICE_APP = setupMISSING_SERVICE_APP;
//# sourceMappingURL=MISSING_SERVICE_APP.js.map