"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupSERVICE_MISSING_PORT = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupSERVICE_MISSING_PORT(builder) {
    builder
        .validator(validator_id_1.ValidatorID.SERVICE_MISSING_PORT)
        .category(categories_1.ValidatorCategory.Networking)
        .title('Service port not found in Application')
        .description("Services connect Kubernetes applications.\nLabel selectors are used to associate Pods with Services.\n\nThis validator detects a condition when no application is associated with a Service.\nIt usually indicates a naming error in workload or Service labels.\n")
        .affected('Service')
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n  name: my-app-service\nspec:\n  type: ClusterIP\n  selector:\n    foo: bar  \n  ports:\n    - name: web\n      port: 80\n      protocol: TCP\n      targetPort: 3000     # pointing to port 3000 but app exposes port 4000\n")
        .example("\napiVersion: apps/v1\nkind: Deployment\nmetadata:\n  name: my-app\n  labels:\n    foo: bar\nspec:\n  containers:\n  - name: worker\n    image: nginx\n    ports:\n    - containerPort: 4000  # exposing port 4000 but Service points to 3000\n")
        .resolution("\nIdentify which port is exposed in the app and make correction to the Service targetPort.\n")
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/service/')
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/connect-applications-service/');
}
exports.setupSERVICE_MISSING_PORT = setupSERVICE_MISSING_PORT;
//# sourceMappingURL=SERVICE_MISSING_PORT.js.map