"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupSERVICE_MULTIPLE_APPS = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupSERVICE_MULTIPLE_APPS(builder) {
    builder
        .validator(validator_id_1.ValidatorID.SERVICE_MULTIPLE_APPS)
        .category(categories_1.ValidatorCategory.Networking)
        .title('Multiple Applications mapped to a single Service')
        .description("Services connect Kubernetes applications.\nLabel selectors are used to associating Pods with Services.\n\nThis validator detects a condition when there are more than one applications\nassociated with a Service.\nIt usually indicates that label selector is loosely defined resulting in multiple\napps referred by a Service.\n")
        .affected('Service')
        .example("\napiVersion: v1\nkind: Service\nmetadata:\n  name: billing-service\nspec:\n  type: ClusterIP\n  selector:\n    component: backend          # Is the app: billing missing?\n")
        .example("\napiVersion: apps/v1\nkind: Deployment\nmetadata:\n  name: billing-app\n  labels:\n    component: backend\n    app: billing\n")
        .example("\napiVersion: apps/v1\nkind: Deployment\nmetadata:\n  name: checkout-app\n  labels:\n    component: backend\n    app: checkout\n")
        .resolution("\nIdentify which application should the Service refer to.")
        .resolution("\nAdd necessary labels to the Service selector.\n")
        .resolution("\nThere is a possible false positive trigger for this validator.\nSometimes a single application is launched using multiple Deployments. \nFor example, a redis-master and redis-slave nodes are deployed using\nindividual Deployments, yet a single Service points to all redis nodes,\nregardless of whether they are masters or slaves.\n")
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/service/')
        .externalLink('https://kubernetes.io/docs/concepts/services-networking/connect-applications-service/');
}
exports.setupSERVICE_MULTIPLE_APPS = setupSERVICE_MULTIPLE_APPS;
//# sourceMappingURL=SERVICE_MULTIPLE_APPS.js.map