"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_BINDING_TO_SERVICE_ACCOUNT = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_BINDING_TO_SERVICE_ACCOUNT(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_BINDING_TO_SERVICE_ACCOUNT)
        .category(categories_1.ValidatorCategory.RBAC)
        .title('Unresolved ServiceAccount reference in Binding')
        .description("RoleBinding grants Roles permissions to ServiceAccounts or Users.\n\nThis validator detects when a ServiceAccount used in RoleBinding is not found.\n")
        .affected('RoleBinding')
        .affected('ClusterRoleBinding')
        .example("\napiVersion: rbac.authorization.k8s.io/v1\nkind: RoleBinding\nmetadata:\n  name: read-pods\nsubjects:\n- kind: ServiceAccount\n  name: backend                            # Service Account not found\nroleRef:\n  kind: Role\n  name: pod-reader\n  apiGroup: rbac.authorization.k8s.io\n")
        .example("\napiVersion: v1\nkind: ServiceAccount\nmetadata:\n  name: saas-backend                        # Different name\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('ServiceAccount'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('ServiceAccount', 'RoleBinding'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('ServiceAccount', 'RoleBinding'))
        .externalLink('https://kubernetes.io/docs/reference/access-authn-authz/rbac/#referring-to-subjects');
}
exports.setupMISSING_BINDING_TO_SERVICE_ACCOUNT = setupMISSING_BINDING_TO_SERVICE_ACCOUNT;
//# sourceMappingURL=MISSING_BINDING_TO_SERVICE_ACCOUNT.js.map