"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_ROLE = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_ROLE(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_ROLE)
        .category(categories_1.ValidatorCategory.RBAC)
        .title('Unresolved Role reference in RoleBinding')
        .description("RoleBinding grants Role permissions to Users or ServiceAccounts.\n\nThis validator detects when a Role used in RoleBinding is not found.\n")
        .affected('RoleBinding')
        .affected('ClusterRoleBinding')
        .example("\napiVersion: rbac.authorization.k8s.io/v1\nkind: RoleBinding\nmetadata:\n  name: read-pods\nsubjects:\n- kind: ServiceAccount\n  name: backend\nroleRef:\n  kind: Role\n  name: pod-reader                            # Role not found\n  apiGroup: rbac.authorization.k8s.io\n")
        .example("\napiVersion: rbac.authorization.k8s.io/v1\nkind: Role\nmetadata:\n  name: podreader                             # Name different\nrules:\n- apiGroups: [\"\"]\n  resources: [\"pods\"]\n  verbs: [\"get\", \"watch\", \"list\"]\n")
        .resolution("Check if the ClusterRole is present.")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('Role'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('Role', 'RoleBinding'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('Role', 'RoleBinding'))
        .externalLink('https://kubernetes.io/docs/reference/access-authn-authz/rbac/');
}
exports.setupMISSING_ROLE = setupMISSING_ROLE;
//# sourceMappingURL=MISSING_ROLE.js.map