"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupUNUSED_ROLE = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupUNUSED_ROLE(builder) {
    builder
        .validator(validator_id_1.ValidatorID.UNUSED_ROLE)
        .category(categories_1.ValidatorCategory.RBAC)
        .title('Unused Role')
        .description("RoleBinding grants Role permissions to Users or ServiceAccounts.\n\nThis validator detects Roles that are not associated with\nany application workloads.\n")
        .affected("Role")
        .affected("ClusterRole")
        .example("\napiVersion: rbac.authorization.k8s.io/v1\nkind: Role\nmetadata:\n  name: podreader                             \nrules:\n- apiGroups: [\"\"]\n  resources: [\"pods\"]\n  verbs: [\"get\", \"watch\", \"list\"]\n")
        .example("\napiVersion: rbac.authorization.k8s.io/v1\nkind: RoleBinding\nmetadata:\n  name: read-pods\nsubjects:\n- kind: ServiceAccount\n  name: backend\nroleRef:\n  kind: Role\n  name: pod-reader                            # Different Rule used\n  apiGroup: rbac.authorization.k8s.io\n")
        .resolution("\nExamine RoleBindings and check if the Role is correctly referenced.")
        .resolution("\nMake necessary naming corrections in RoleBinding Role references.\n")
        .resolution("\nExamine applications within the namespace and determine if ServiceAccount in\nRoleBinding is supposed to be used in those workloads.")
        .resolution("\nIf the Role is indeed unused, it may need to be just removed.\n")
        .externalLink('https://kubernetes.io/docs/reference/access-authn-authz/rbac/#referring-to-subjects');
}
exports.setupUNUSED_ROLE = setupUNUSED_ROLE;
//# sourceMappingURL=UNUSED_ROLE.js.map