"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupUNUSED_SERVICE_ACCOUNT = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupUNUSED_SERVICE_ACCOUNT(builder) {
    builder
        .validator(validator_id_1.ValidatorID.UNUSED_SERVICE_ACCOUNT)
        .category(categories_1.ValidatorCategory.RBAC)
        .title('Unused ServiceAccount')
        .description("ServiceAccounts grant Kubernetes API permissions to workloads. \n\nThis validator detects ServiceAccounts that are not associated with any workloads.\nThis check is ignored for \"default\" ServiceAccounts.\n")
        .affected('ServiceAccount')
        .example("\napiVersion: v1\nkind: ServiceAccount\nmetadata:\n  name: robot                            # Unused Service Account\n")
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      serviceAccountName: build-robot    # Was this a typo?\n...\n")
        .resolution("\nExamine applications within the namespace and determine if the ServiceAccount is supposed to\nbe used in workloads.")
        .resolution("\nIf the ServiceAccount is supposed to be used, either correct the ServiceAccount name or\nthe reference in the workload.\n")
        .resolution("\nIf the ServiceAccount is indeed unused, it may need to be just removed.\n")
        .externalLink('https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/');
}
exports.setupUNUSED_SERVICE_ACCOUNT = setupUNUSED_SERVICE_ACCOUNT;
//# sourceMappingURL=UNUSED_SERVICE_ACCOUNT.js.map