"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_PSP = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_PSP(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_PSP)
        .category(categories_1.ValidatorCategory.Security)
        .title('Unresolved PodSecurityPolicy reference in Binding')
        .description("PodSecurityPolicies enable fine-grained authorization of pod creation and updates.\n\nThis validator detects when a PodSecurityPolicy used in the Roles is not found.\n")
        .affected('Role')
        .affected('ClusterRole')
        .example("\napiVersion: rbac.authorization.k8s.io/v1\nkind: ClusterRole\nmetadata:\n  name: <role name>\nrules:\n- apiGroups: ['policy']\n  resources: ['podsecuritypolicies']\n  verbs:     ['use']\n  resourceNames:\n    - policy-foo             # policy-foo not found\n")
        .example("\napiVersion: policy/v1beta1\nkind: PodSecurityPolicy\nmetadata:\n  name: policy-bar           # Maybe use policy-bar instead?\nspec:\n  privileged: false\n  seLinux:\n    rule: RunAsAny\n  supplementalGroups:\n    rule: RunAsAny\n  runAsUser:\n    rule: RunAsAny\n  fsGroup:\n    rule: RunAsAny\n  volumes:\n  - '*'\n")
        .resolution("Check if the PodSecurityPolicy is present.")
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('PodSecurityPolicy', 'Role'))
        .externalLink('https://kubernetes.io/docs/concepts/policy/pod-security-policy/');
}
exports.setupMISSING_PSP = setupMISSING_PSP;
//# sourceMappingURL=MISSING_PSP.js.map