"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_PV = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupMISSING_PV(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_PV)
        .category(categories_1.ValidatorCategory.Storage)
        .title('Unresolved PersistentVolume reference in the volume claim')
        .description("An existing PersistentVolume can be bound to PersistentVolumeClaim using volumeName property.\n\nThis validator detects a condition when a PersistentVolume referenced in\nPersistentVolumeClaim is not found.\n")
        .affected('PersistentVolumeClaim')
        .example("\napiVersion: v1\nkind: PersistentVolumeClaim\nspec:\n  resources:\n    requests:\n      storage: 8Gi\n  volumeMode: Filesystem\n  volumeName: pvc-00000000-0000-0000-0000-000000000000   # PV not found \n  accessModes:\n    - ReadWriteOnce\n  storageClassName: gp2\n")
        .resolution('Check if the PersistentVolume exists.')
        .resolution('Make correction in PersistentVolumeClaim.')
        .resolution("\nIt is possible that the PersistentVolume was deleted and cannot be recovered.\nIn such a case, the volumeName property should be removed from the PersistentVolumeClaim,\nallowing the control plane to create a new PV.")
        .externalLink('https://kubernetes.io/docs/concepts/storage/persistent-volumes/')
        .externalLink('https://kubernetes.io/docs/concepts/storage/persistent-volumes/#reserving-a-persistentvolume')
        .externalLink('https://kubernetes.io/docs/concepts/storage/persistent-volumes/#binding');
}
exports.setupMISSING_PV = setupMISSING_PV;
//# sourceMappingURL=MISSING_PV.js.map