"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupMISSING_PVC = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
var texts_1 = require("../texts");
function setupMISSING_PVC(builder) {
    builder
        .validator(validator_id_1.ValidatorID.MISSING_PVC)
        .category(categories_1.ValidatorCategory.Storage)
        .title('Unresolved PersistentVolumeClaim reference in container')
        .description("PersistentVolumeClaims allow mounting permanent storage volumes to workloads.\n\nThis validator detects a condition when a PersistentVolumeClaim referenced\nfrom the workload is not found.\n")
        .affectedAllWorkloads()
        .example("\nkind: Deployment\nspec:\n  template:\n    spec:\n      volumes:\n        - name: data\n          persistentVolumeClaim:\n            claimName: test-minio    # Missing PersistentVolumeClaim \n...\n")
        .example("\napiVersion: v1\nkind: PersistentVolumeClaim\nmetadata:\n  name: my-minio                     # Different name\nspec:\n  storageClassName: ssd\n  accessModes:\n    - ReadWriteOnce\n  resources:\n    requests:\n      storage: 3Gi\n")
        .resolution(texts_1.RESOLUTION_TEXT.checkPresentInSameNamespace('PersistentVolumeClaim'))
        .resolution(texts_1.RESOLUTION_TEXT.checkInDifferentNamespace('PersistentVolumeClaim', 'workload'))
        .resolution(texts_1.RESOLUTION_TEXT.typoNameReference('PersistentVolumeClaim', 'workload volume spec'))
        .resolution('Correct the persistentVolumeClaim in the workload volume spec.')
        .externalLink('https://kubernetes.io/docs/tasks/configure-pod-container/configure-persistent-volume-storage/')
        .externalLink('https://kubernetes.io/docs/concepts/storage/persistent-volumes/');
}
exports.setupMISSING_PVC = setupMISSING_PVC;
//# sourceMappingURL=MISSING_PVC.js.map