"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupUNUSED_PV = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupUNUSED_PV(builder) {
    builder
        .validator(validator_id_1.ValidatorID.UNUSED_PV)
        .category(categories_1.ValidatorCategory.Storage)
        .title('PersistentVolume not attached')
        .description("\nThis validator detects a condition when a PersistentVolume is not used or\nreferenced from PersistentVolumeClaim.\n")
        .affectedAllWorkloads()
        .example("\napiVersion: v1\nkind: PersistentVolume\nmetadata:\nname: pvc-00000000-0000-0000-0000-000000000000     # This PV is not used\n...\n")
        .resolution('Check if the workloads and PVCs were removed, and if this persistent volume should be deleted.')
        .resolutionAndExample('If the volume should be in use, it can be bound the PersistentVolumeClaim', "\napiVersion: v1\nkind: PersistentVolumeClaim\nspec:\n  resources:\n    requests:\n      storage: 8Gi\n  volumeMode: Filesystem\n  volumeName: pvc-00000000-0000-0000-0000-000000000000   # Reference here \n  accessModes:\n    - ReadWriteOnce\n  storageClassName: gp2\n")
        .externalLink('https://kubernetes.io/docs/tasks/configure-pod-container/configure-persistent-volume-storage/')
        .externalLink('https://kubernetes.io/docs/concepts/storage/persistent-volumes/');
}
exports.setupUNUSED_PV = setupUNUSED_PV;
//# sourceMappingURL=UNUSED_PV.js.map