"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupUNUSED_PVC = void 0;
var validator_id_1 = require("../../../validator-id");
var categories_1 = require("../../categories");
function setupUNUSED_PVC(builder) {
    builder
        .validator(validator_id_1.ValidatorID.UNUSED_PVC)
        .category(categories_1.ValidatorCategory.Storage)
        .title('PersistentVolumeClaim not attached')
        .description("PersistentVolumeClaims allow mounting permanent storage volumes to workloads.\n\nThis validator detects a condition when a PersistentVolumeClaim is not used or\nreferenced from workloads.\n")
        .affectedAllWorkloads()
        .example("\napiVersion: v1\nkind: PersistentVolumeClaim\nmetadata:\n  name: my-minio                     # This PVC is not used\n...\n")
        .resolution('Check if the workloads were removed, and the PVC should also be deleted.')
        .resolutionAndExample('Check if there was a typo in the workload volume spec.', "kind: Deployment\nspec:\n  template:\n    spec:\n      volumes:\n        - name: data\n          persistentVolumeClaim:\n            claimName: test-minio    # Fix the claimName\n...\n")
        .externalLink('https://kubernetes.io/docs/tasks/configure-pod-container/configure-persistent-volume-storage/')
        .externalLink('https://kubernetes.io/docs/concepts/storage/persistent-volumes/');
}
exports.setupUNUSED_PVC = setupUNUSED_PVC;
//# sourceMappingURL=UNUSED_PVC.js.map