"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Compiler = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var the_promise_1 = require("the-promise");
var unit_converter_1 = require("./unit-converter");
var PARAMS_TO_HIDE = {
    exports: true,
    require: true,
    module: true,
    __filename: true,
    __dirname: true,
    Promise: true,
};
for (var _i = 0, _a = the_lodash_1.default.keys(global); _i < _a.length; _i++) {
    var x = _a[_i];
    if (!PARAMS_TO_HIDE[x]) {
        PARAMS_TO_HIDE[x] = true;
    }
}
var Compiler = /** @class */ (function () {
    function Compiler(src, name, values) {
        this._src = src;
        this._name = name;
        this._values = {
            unit: new unit_converter_1.UnitConverter(),
        };
        if (values) {
            this._values = the_lodash_1.default.defaults(this._values, values);
        }
        this._verbose = false;
    }
    Compiler.prototype.enableVerboseOutput = function () {
        this._verbose = true;
    };
    Compiler.prototype.compile = function () {
        var _this = this;
        return the_promise_1.MyPromise.construct(function (resolve, reject) {
            try {
                var allParamNames = [];
                allParamNames = the_lodash_1.default.concat(allParamNames, the_lodash_1.default.keys(PARAMS_TO_HIDE));
                for (var _i = 0, _a = the_lodash_1.default.keys(_this._values); _i < _a.length; _i++) {
                    var key = _a[_i];
                    allParamNames.push(key);
                }
                var finalSrc = 'module.exports = function(' +
                    allParamNames.join(', ') +
                    ') {\n' +
                    "    'use strict';\n" +
                    _this._src +
                    '\n};';
                var Module = module.constructor;
                var m = new Module();
                if (_this._verbose) {
                    console.log('>>>>>>> SCRIPT BEGIN >>>>>>>>');
                    console.log(finalSrc);
                    console.log('<<<<<<<< SCRIPT END <<<<<<<<<');
                }
                m._compile(finalSrc, _this._name);
                var runnable = new RunnableScript(m, _this._values);
                resolve(runnable);
            }
            catch (reason) {
                // console.log("*** ERROR: ");
                // console.log(reason);
                reject(reason);
            }
        });
    };
    return Compiler;
}());
exports.Compiler = Compiler;
var RunnableScript = /** @class */ (function () {
    function RunnableScript(m, values) {
        this._m = m;
        this._values = values;
    }
    RunnableScript.prototype.run = function (valuesMap) {
        var _this = this;
        valuesMap = valuesMap || {};
        return the_promise_1.MyPromise.construct(function (resolve, reject) {
            try {
                var result = null;
                var paramValues = [];
                paramValues = the_lodash_1.default.concat(paramValues, the_lodash_1.default.keys(PARAMS_TO_HIDE).map(function (x) { return undefined; }));
                for (var _i = 0, _a = the_lodash_1.default.keys(_this._values); _i < _a.length; _i++) {
                    var key = _a[_i];
                    if (key in valuesMap) {
                        paramValues.push(valuesMap[key]);
                    }
                    else {
                        paramValues.push(_this._values[key]);
                    }
                }
                // console.log(paramValues)
                result = _this._m.exports.apply(null, paramValues);
                resolve(result);
            }
            catch (reason) {
                // console.log("*** ERROR: ");
                // console.log(reason);
                reject(reason);
            }
        });
    };
    return RunnableScript;
}());
//# sourceMappingURL=compiler.js.map