"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryFetcher = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var script_item_1 = require("../script-item");
var types_1 = require("../../spec/target/types");
var evaluator_1 = require("./evaluator");
var name_helpers_1 = require("../name-helpers");
var dist_1 = require("@kubevious/entity-meta/dist");
var QueryFetcher = /** @class */ (function () {
    function QueryFetcher(executionState, scope) {
        this._result = {
            success: false,
            items: [],
            messages: [],
        };
        this._executorNodes = [];
        this._finalItems = {};
        this._executionState = executionState;
        this._scope = scope;
    }
    QueryFetcher.prototype.execute = function () {
        try {
            this._acceptChainItems([new script_item_1.ScriptItem(dist_1.NodeKind.root, this._executionState.state)], this._scope);
            this._executorNodeR();
            this._result.items = the_lodash_1.default.values(this._finalItems);
            this._result.success = this._result.messages.length == 0;
        }
        catch (reason) {
            this._result.success = false;
            this._addError((reason === null || reason === void 0 ? void 0 : reason.message) || "Unknown error happened");
            console.error("QUERY FETCHER ERROR: ", reason);
        }
        return this._result;
    };
    QueryFetcher.prototype._acceptChainItems = function (items, scope) {
        // console.log("[_acceptChainItems] :: count: " + items.length);
        for (var _i = 0, _a = scope._chain; _i < _a.length; _i++) {
            var x = _a[_i];
            this._executorNodes.push({
                prevs: items,
                targetSelector: x,
            });
        }
    };
    QueryFetcher.prototype._executorNodeR = function () {
        // console.log("[_executorNodeR] count: " + this._executorNodes.length);
        if (this._executorNodes.length == 0) {
            return;
        }
        var executorNode = the_lodash_1.default.head(this._executorNodes);
        this._executorNodes.splice(0, 1);
        this._executorNode(executorNode);
        this._executorNodeR();
    };
    QueryFetcher.prototype._executorNode = function (executorNode) {
        // console.log("[_executorNode] LOGIC ITEM: ");
        // executorNode.targetSelector.debugOutput();
        var targetSelector = executorNode.targetSelector;
        for (var _i = 0, _a = executorNode.prevs; _i < _a.length; _i++) {
            var x = _a[_i];
            var allItems = this._executeTargetSelector(targetSelector, x);
            // console.log("[_executorNode] allItems: " + allItems.length);
            var items = this._filterItems(targetSelector, x, allItems);
            // console.log("[_executorNode] items: " + items.length);
            if (items && (items.length > 0)) {
                if (executorNode.targetSelector._scope._chain.length == 0) {
                    this._acceptFinalItems(items);
                }
                else {
                    this._acceptChainItems(items, executorNode.targetSelector._scope);
                }
            }
        }
    };
    QueryFetcher.prototype._executeTargetSelector = function (targetSelector, prev) {
        // console.log("[_executeTargetSelector] :: " + targetSelector.constructor.name);
        var _this = this;
        var result = undefined;
        if (this.isMySelector(targetSelector)) // TODO: Check why we do that...
         {
            result = this._executeLogicItem(targetSelector, prev);
        }
        // console.log("[_executeTargetSelector] result: ", result);
        if (!result) {
            return [];
        }
        return result.map(function (x) { return new script_item_1.ScriptItem(x, _this._executionState.state); });
    };
    QueryFetcher.prototype.isMySelector = function (targetSelector) {
        return (targetSelector.constructor.name == 'LogicItem' ||
            targetSelector.constructor.name == 'QueryableLogicItem');
    };
    QueryFetcher.prototype._executeLogicItem = function (targetSelector, prev) {
        // console.log("[_executeLogicItem] :: " + targetSelector._params.kind + " :: " + targetSelector._location);
        switch (targetSelector._location) {
            case types_1.LogicLocationType.descendant:
                {
                    var results = prev.descendants(targetSelector._params.kind);
                    return results.map(function (x) { return x._dn; });
                }
                break;
            case types_1.LogicLocationType.child:
                {
                    var results = prev.children(targetSelector._params.kind);
                    return results.map(function (x) { return x._dn; });
                }
                break;
            case types_1.LogicLocationType.parent:
                {
                    var parent_1 = prev.parent;
                    if (parent_1) {
                        if (targetSelector._params.kind) {
                            var kindType = (0, name_helpers_1.mapLogicItemName)(targetSelector._params.kind);
                            if (parent_1.kind !== kindType) {
                                return [];
                            }
                        }
                        return [parent_1._dn];
                    }
                }
                break;
            case types_1.LogicLocationType.ancestor:
                {
                    if (targetSelector._params.kind) {
                        var ancestors = prev.ancestors(targetSelector._params.kind);
                        return ancestors.map(function (x) { return x._dn; });
                    }
                }
                break;
            case types_1.LogicLocationType.link:
                {
                    var results = prev.links(targetSelector._params.link);
                    return results.map(function (x) { return x._dn; });
                }
                break;
        }
        return [];
    };
    QueryFetcher.prototype._filterItems = function (targetSelector, prev, items) {
        var _this = this;
        if (!this.isMySelector(targetSelector)) { // TODO: Check why we do that...
            return [];
        }
        return items.filter(function (item) {
            var shouldInclude = _this._filterLogicItem(targetSelector, prev, item);
            return shouldInclude;
        });
    };
    QueryFetcher.prototype._filterLogicItem = function (targetSelector, prev, item) {
        var _this = this;
        var filters = [
            function () { return _this._filterLogicItemByName(targetSelector, prev, item); },
            function () { return _this._filterLogicItemByLabel(targetSelector, prev, item); },
            function () { return _this._filterLogicItemByAnnotation(targetSelector, prev, item); },
            function () {
                return _this._filterLogicItemByCustomFilter(targetSelector, prev, item);
            },
        ];
        for (var _i = 0, filters_1 = filters; _i < filters_1.length; _i++) {
            var filter = filters_1[_i];
            if (!filter()) {
                return false;
            }
        }
        return true;
    };
    QueryFetcher.prototype._filterLogicItemByName = function (targetSelector, prev, item) {
        var evaluator = new evaluator_1.Evaluator(targetSelector, prev, item, targetSelector._nameFilters);
        return evaluator.doesAnyMatch(function (value) {
            if (item.name != value) {
                return false;
            }
            return true;
        });
    };
    QueryFetcher.prototype._filterLogicItemByLabel = function (targetSelector, prev, item) {
        var evaluator = new evaluator_1.Evaluator(targetSelector, prev, item, targetSelector._labelFilters);
        return evaluator.doesAnyMatch(function (dict) {
            for (var _i = 0, _a = the_lodash_1.default.keys(dict); _i < _a.length; _i++) {
                var key = _a[_i];
                if (item.labels[key] != dict[key]) {
                    return false;
                }
            }
            return true;
        });
    };
    QueryFetcher.prototype._filterLogicItemByAnnotation = function (targetSelector, prev, item) {
        var evaluator = new evaluator_1.Evaluator(targetSelector, prev, item, targetSelector._annotationFilters);
        return evaluator.doesAnyMatch(function (dict) {
            for (var _i = 0, _a = the_lodash_1.default.keys(dict); _i < _a.length; _i++) {
                var key = _a[_i];
                if (item.annotations[key] != dict[key]) {
                    return false;
                }
            }
            return true;
        });
    };
    QueryFetcher.prototype._filterLogicItemByCustomFilter = function (targetSelector, prev, item) {
        var evaluator = new evaluator_1.Evaluator(targetSelector, prev, item, targetSelector._customFilters);
        return evaluator.doesAnyMatch(function (x) { return x; });
    };
    QueryFetcher.prototype._acceptFinalItems = function (items) {
        // console.log("[_acceptFinalItems] :: count: " + items.length);
        // console.log(items);
        for (var _i = 0, _a = items; _i < _a.length; _i++) {
            var item = _a[_i];
            this._finalItems[item._dn] = {
                dn: item._dn,
                kind: 'logic',
            };
        }
    };
    QueryFetcher.prototype._addError = function (msg) {
        this._result.messages.push(msg);
    };
    return QueryFetcher;
}());
exports.QueryFetcher = QueryFetcher;
//# sourceMappingURL=fetcher.js.map