"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScriptItem = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var entity_meta_1 = require("@kubevious/entity-meta");
var name_helpers_1 = require("./name-helpers");
var ScriptItem = /** @class */ (function () {
    function ScriptItem(dn, state) {
        this._dn = dn;
        this._state = state;
        if (!this._dn) {
            throw new Error('Missing DN');
        }
        if (!this._state) {
            throw new Error('Missing RegistryAccessor');
        }
        var dnParts = (0, entity_meta_1.parseDn)(dn);
        var lastDnPart = the_lodash_1.default.last(dnParts);
        if (lastDnPart) {
            this._kind = lastDnPart.kind;
        }
        else {
            this._kind = null;
        }
    }
    Object.defineProperty(ScriptItem.prototype, "parent", {
        get: function () {
            var parentDn = (0, entity_meta_1.parentDn)(this._dn);
            if (!parentDn) {
                return null;
            }
            return new ScriptItem(parentDn, this._state);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ScriptItem.prototype, "kind", {
        get: function () {
            return this._kind;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ScriptItem.prototype, "node", {
        get: function () {
            var node = this._state.getNode(this._dn);
            if (!node) {
                return null;
            }
            return node;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ScriptItem.prototype, "name", {
        get: function () {
            var node = this.node;
            if (!node) {
                return null;
            }
            return node.name;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ScriptItem.prototype, "props", {
        get: function () {
            return this.getProperties(entity_meta_1.PropsId.properties);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ScriptItem.prototype, "config", {
        get: function () {
            return this.getProperties(entity_meta_1.PropsId.config);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ScriptItem.prototype, "labels", {
        get: function () {
            return this.getProperties(entity_meta_1.PropsId.labels);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ScriptItem.prototype, "annotations", {
        get: function () {
            return this.getProperties(entity_meta_1.PropsId.annotations);
        },
        enumerable: false,
        configurable: true
    });
    ScriptItem.prototype.children = function (kind) {
        var _this = this;
        var kindType = (0, name_helpers_1.mapLogicItemName)(kind);
        var childrenDns = this._state.childrenByKind(this._dn, kindType);
        return childrenDns.map(function (x) { return new ScriptItem(x, _this._state); });
    };
    ScriptItem.prototype.hasChildren = function (kind) {
        var items = this.children(kind);
        return (items.length > 0);
    };
    ScriptItem.prototype.descendants = function (kind) {
        var _this = this;
        var kindType = (0, name_helpers_1.mapLogicItemName)(kind);
        var descendantDns = this._state.scopeByKind(this._dn, kindType);
        return descendantDns.map(function (x) { return new ScriptItem(x, _this._state); });
    };
    ScriptItem.prototype.hasDescendants = function (kind) {
        var items = this.descendants(kind);
        return (items.length > 0);
    };
    ScriptItem.prototype.ancestors = function (kind) {
        var kindType = (0, name_helpers_1.mapLogicItemName)(kind);
        var current = this.parent;
        var ancestors = [];
        while (current) {
            if (current.kind === kindType) {
                ancestors.push(current);
            }
            current = current.parent;
        }
        return ancestors;
    };
    ScriptItem.prototype.links = function (linkOrNone) {
        var _this = this;
        var propsValue = this.getProperties(entity_meta_1.PropsId.targetLinks);
        if (propsValue) {
            var linksProps = propsValue;
            if (linkOrNone) {
                var linkItems = linksProps[linkOrNone];
                if (linkItems) {
                    var dns = linkItems.map(function (x) { return x.dn; });
                    return dns.map(function (x) { return new ScriptItem(x, _this._state); });
                }
            }
            else {
                var linkItems = the_lodash_1.default.flatten(the_lodash_1.default.values(linksProps));
                var dns = linkItems.map(function (x) { return x.dn; });
                return dns.map(function (x) { return new ScriptItem(x, _this._state); });
            }
        }
        return [];
    };
    ScriptItem.prototype.hasLinks = function (linkOrNone) {
        var items = this.links(linkOrNone);
        return (items.length > 0);
    };
    ScriptItem.prototype.getProperties = function (id) {
        var props = this._state.getProperties(this._dn, id);
        if (!props.config) {
            return {};
        }
        return props.config;
    };
    return ScriptItem;
}());
exports.ScriptItem = ScriptItem;
//# sourceMappingURL=script-item.js.map