"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationProcessor = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var compiler_1 = require("../compiler");
var script_item_1 = require("../script-item");
var types_1 = require("../../spec/target/root/types");
var scope_builder_1 = require("./scope-builder");
var ValidationProcessor = /** @class */ (function () {
    function ValidationProcessor(src, executionState, scopeBuilderExecutor) {
        this._src = src;
        this._executionState = executionState;
        this._runnable = null;
        this._scopeBuilderExecutor = scopeBuilderExecutor !== null && scopeBuilderExecutor !== void 0 ? scopeBuilderExecutor : scope_builder_1.makeValidatorRootScope;
    }
    ValidationProcessor.prototype.prepare = function () {
        var _this = this;
        var result = {
            success: false,
            messages: [],
        };
        return this._loadModule()
            .then(function (runnable) {
            _this._runnable = runnable;
        })
            .then(function () {
            _this._validate();
            result.success = result.messages.length == 0;
        })
            .catch(function (reason) {
            result.success = false;
            _this._addError(result.messages, reason.message);
        })
            .then(function () { return result; });
    };
    ValidationProcessor.prototype._loadModule = function () {
        var _this = this;
        return Promise.resolve().then(function () {
            var compilerValues = {
                item: null,
                config: null,
                error: null,
                warning: null,
                mark: null,
            };
            for (var _i = 0, _a = the_lodash_1.default.keys(types_1.TopLevelQuery); _i < _a.length; _i++) {
                var x = _a[_i];
                compilerValues[x] = null;
            }
            var compiler = new compiler_1.Compiler(_this._src, 'RULE_VALIDATOR', compilerValues);
            return compiler.compile();
        });
    };
    ValidationProcessor.prototype._validate = function () { };
    ValidationProcessor.prototype.execute = function (dn, state) {
        var _this = this;
        var result = {
            success: false,
            messages: [],
            validation: {
                hasErrors: false,
                hasWarnings: false,
                errorMsgs: {},
                warnMsgs: {},
            },
        };
        return Promise.resolve()
            .then(function () {
            var item = new script_item_1.ScriptItem(dn, state);
            var valueMap = {
                item: item,
                config: item.config,
                error: function (msg) {
                    result.validation.hasErrors = true;
                    if (msg) {
                        result.validation.errorMsgs[msg] = true;
                    }
                },
                warning: function (msg) {
                    result.validation.hasWarnings = true;
                    if (msg) {
                        result.validation.warnMsgs[msg] = true;
                    }
                },
                mark: function (kind) {
                    if (!result.validation.marks) {
                        result.validation.marks = {};
                    }
                    result.validation.marks[kind] = true;
                },
            };
            _this._setupQueryBuilders(valueMap, item);
            // console.log("HEADERS: ", _.keys(valueMap))
            return _this._runnable.run(valueMap);
        })
            .then(function () {
            result.success = true;
        })
            .catch(function (reason) {
            result.success = false;
            _this._addError(result.messages, reason.message);
        })
            .then(function () { return result; });
    };
    ValidationProcessor.prototype._setupQueryBuilders = function (valueMap, item) {
        var rootScopeBuilder = {
            setup: function (name, func) {
                valueMap[name] = func;
            }
        };
        this._scopeBuilderExecutor(rootScopeBuilder, item, this._executionState);
    };
    ValidationProcessor.prototype._addError = function (list, msg) {
        list.push(msg);
    };
    return ValidationProcessor;
}());
exports.ValidationProcessor = ValidationProcessor;
//# sourceMappingURL=processor.js.map