"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LogicItem = void 0;
var debug_1 = require("../utils/debug");
var scope_1 = require("./scope");
var LogicItem = /** @class */ (function () {
    function LogicItem(location, params) {
        this._scope = new scope_1.Scope();
        this._nameFilters = [];
        this._labelFilters = [];
        this._annotationFilters = [];
        this._customFilters = [];
        this._location = location;
        this._params = params;
    }
    LogicItem.prototype.name = function (value) {
        this._nameFilters.push(value);
        return this;
    };
    LogicItem.prototype.label = function (key, value) {
        var filter = {};
        filter[key] = value;
        return this.labels(filter);
    };
    LogicItem.prototype.labels = function (value) {
        this._labelFilters.push(value);
        return this;
    };
    LogicItem.prototype.annotation = function (key, value) {
        var filter = {};
        filter[key] = value;
        return this.annotations(filter);
    };
    LogicItem.prototype.annotations = function (value) {
        this._annotationFilters.push(value);
        return this;
    };
    LogicItem.prototype.filter = function (value) {
        this._customFilters.push(value);
        return this;
    };
    LogicItem.prototype.descendant = function (kind) {
        return this._scope.descendant(kind);
    };
    LogicItem.prototype.child = function (kind) {
        return this._scope.child(kind);
    };
    LogicItem.prototype.parent = function (kindOrNone) {
        return this._scope.parent(kindOrNone);
    };
    LogicItem.prototype.ancestor = function (kind) {
        return this._scope.ancestor(kind);
    };
    LogicItem.prototype.link = function (linkOrNone) {
        return this._scope.link(linkOrNone);
    };
    LogicItem.prototype.debugOutput = function (indent) {
        if (!indent) {
            indent = 0;
        }
        var header = '  '.repeat(indent);
        console.log(header + '* LogicItem :: ' + this._location + ', Params: ', this._params);
        if (this._nameFilters.length > 0) {
            for (var _i = 0, _a = this._nameFilters; _i < _a.length; _i++) {
                var filter = _a[_i];
                console.log(header + '    - Name: ' + (0, debug_1.stringify)(filter));
            }
        }
        if (this._labelFilters.length > 0) {
            for (var _b = 0, _c = this._labelFilters; _b < _c.length; _b++) {
                var filter = _c[_b];
                console.log(header + '    - Label: ' + (0, debug_1.stringify)(filter));
            }
        }
        if (this._annotationFilters.length > 0) {
            for (var _d = 0, _e = this._annotationFilters; _d < _e.length; _d++) {
                var filter = _e[_d];
                console.log(header + '    - Annotation: ' + (0, debug_1.stringify)(filter));
            }
        }
        if (this._customFilters.length > 0) {
            for (var _f = 0, _g = this._customFilters; _f < _g.length; _f++) {
                var filter = _g[_f];
                console.log(header + '    - CustomFilter: ' + (0, debug_1.stringify)(filter));
            }
        }
        this._scope.debugOutput(indent + 1);
    };
    return LogicItem;
}());
exports.LogicItem = LogicItem;
//# sourceMappingURL=logic-item.js.map