"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sTarget = exports.K8sTargetBuilder = void 0;
var entity_meta_1 = require("@kubevious/entity-meta");
var K8sTargetBuilder = /** @class */ (function () {
    function K8sTargetBuilder(scope, executionState, builderContext) {
        this._data = {
            isApiVersion: true,
            nameFilters: [],
            labelFilters: [],
        };
        this._scope = scope;
        this._executionState = executionState;
        this._builderContext = builderContext;
        scope.registerFinalizer(this._finalize.bind(this));
    }
    K8sTargetBuilder.prototype.ApiVersion = function (apiVersion) {
        this._data.isApiVersion = true;
        this._data.apiVersion = apiVersion;
        return this;
    };
    K8sTargetBuilder.prototype.Api = function (apiOrNone) {
        this._data.isApiVersion = false;
        this._data.apiOrNone = apiOrNone;
        return this;
    };
    K8sTargetBuilder.prototype.Version = function (version) {
        this._data.version = version;
        return this;
    };
    K8sTargetBuilder.prototype.Kind = function (kind) {
        this._data.kind = kind;
        return this;
    };
    K8sTargetBuilder.prototype.namespace = function (value) {
        this._data.namespace = value;
        return this;
    };
    K8sTargetBuilder.prototype.allNamespaces = function () {
        this._data.isAllNamespaces = true;
        return this;
    };
    K8sTargetBuilder.prototype.name = function (value) {
        this._data.nameFilters.push(value);
        return this;
    };
    K8sTargetBuilder.prototype.label = function (key, value) {
        var filter = {};
        filter[key] = value;
        return this.labels(filter);
    };
    K8sTargetBuilder.prototype.labels = function (value) {
        this._data.labelFilters.push(value);
        return this;
    };
    K8sTargetBuilder.prototype._finalize = function () {
        // console.log("_finalize:", this._data);
        var _a, _b;
        if (!this._executionState) {
            return;
        }
        if (!this._data.kind) {
            return;
        }
        var apiVersion = this._data.isApiVersion ? this._data.apiVersion :
            (this._data.apiOrNone ? "".concat(this._data.apiOrNone, "/").concat(this._data.version) : this._data.version);
        if (!apiVersion) {
            console.log("No apiVersion");
            return;
        }
        var apiResource = this._executionState.k8sApiResources.getByApiVersionAndKind(apiVersion, this._data.kind);
        if (!apiResource) {
            console.log("No ApiResource");
            return;
        }
        var currentScope = this._scope.child(entity_meta_1.NodeKind.k8s);
        if (apiResource.isNamespaced) {
            currentScope = currentScope.child(entity_meta_1.NodeKind.ns);
            if (!this._data.isAllNamespaces) {
                var namespace = (_a = this._data.namespace) !== null && _a !== void 0 ? _a : (_b = this._builderContext) === null || _b === void 0 ? void 0 : _b.namespace;
                if (namespace) {
                    currentScope = currentScope.name(namespace);
                }
            }
        }
        else {
            currentScope = currentScope.child(entity_meta_1.NodeKind.cluster);
        }
        if (apiResource.apiName) {
            currentScope = currentScope.child(entity_meta_1.NodeKind.api);
            currentScope = currentScope.name(apiResource.apiName);
        }
        currentScope = currentScope.child(entity_meta_1.NodeKind.version);
        currentScope = currentScope.name(apiResource.version);
        currentScope = currentScope.child(entity_meta_1.NodeKind.kind);
        currentScope = currentScope.name(apiResource.kindName);
        currentScope = currentScope.child(entity_meta_1.NodeKind.resource);
        for (var _i = 0, _c = this._data.nameFilters; _i < _c.length; _i++) {
            var name_1 = _c[_i];
            currentScope = currentScope.name(name_1);
        }
        for (var _d = 0, _e = this._data.labelFilters; _d < _e.length; _d++) {
            var labels = _e[_d];
            currentScope = currentScope.labels(labels);
        }
    };
    return K8sTargetBuilder;
}());
exports.K8sTargetBuilder = K8sTargetBuilder;
var K8sTarget = /** @class */ (function () {
    function K8sTarget(scope, executionState) {
        this._scope = scope;
        this._executionState = executionState;
    }
    K8sTarget.prototype.ApiVersion = function (apiVersion) {
        var builder = this._makeTargetBuilder();
        builder.ApiVersion(apiVersion);
        return builder;
    };
    K8sTarget.prototype.Api = function (apiOrNone) {
        var builder = this._makeTargetBuilder();
        builder.Api(apiOrNone);
        return builder;
    };
    K8sTarget.prototype._makeTargetBuilder = function () {
        return new K8sTargetBuilder(this._scope, this._executionState, {});
    };
    return K8sTarget;
}());
exports.K8sTarget = K8sTarget;
//# sourceMappingURL=k8s-target.js.map