"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Scope = void 0;
var logic_item_1 = require("./logic-item");
var types_1 = require("./types");
var Scope = /** @class */ (function () {
    function Scope() {
        this._chain = [];
        this._finalizers = [];
    }
    Scope.prototype.descendant = function (kind) {
        return this._add(types_1.LogicLocationType.descendant, { kind: kind });
    };
    Scope.prototype.child = function (kind) {
        return this._add(types_1.LogicLocationType.child, { kind: kind });
    };
    Scope.prototype.parent = function (kindOrNone) {
        return this._add(types_1.LogicLocationType.parent, { kind: kindOrNone });
    };
    Scope.prototype.ancestor = function (kind) {
        return this._add(types_1.LogicLocationType.ancestor, { kind: kind });
    };
    Scope.prototype.link = function (linkOrNone) {
        return this._add(types_1.LogicLocationType.link, { link: linkOrNone });
    };
    Scope.prototype.registerFinalizer = function (finalizer) {
        this._finalizers.push(finalizer);
    };
    Scope.prototype.finalize = function () {
        for (var _i = 0, _a = this._finalizers; _i < _a.length; _i++) {
            var finalizer = _a[_i];
            finalizer();
        }
    };
    Scope.prototype._add = function (location, params) {
        var item = new logic_item_1.LogicItem(location, params);
        return this._addToChain(item);
    };
    Scope.prototype._addToChain = function (item) {
        // console.log(">>>>> ADD TO CHAIN:");
        // item.debugOutput(2);
        this._chain.push(item);
        return item;
    };
    Scope.prototype.debugOutput = function (indent) {
        for (var _i = 0, _a = this._chain; _i < _a.length; _i++) {
            var child = _a[_i];
            child.debugOutput(indent);
        }
    };
    return Scope;
}());
exports.Scope = Scope;
//# sourceMappingURL=scope.js.map