"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegistryBundleState = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var registry_bundle_node_1 = require("./registry-bundle-node");
var ROOT_NAME = 'root';
var RegistryBundleState = /** @class */ (function () {
    function RegistryBundleState(registryState) {
        this._nodeMap = {};
        this._nodeConfigs = {};
        this._registryState = registryState;
        this._buildNodes();
        this._finalize();
    }
    Object.defineProperty(RegistryBundleState.prototype, "date", {
        get: function () {
            return this._registryState.date;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RegistryBundleState.prototype, "registryState", {
        get: function () {
            return this._registryState;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RegistryBundleState.prototype, "nodeItems", {
        get: function () {
            return the_lodash_1.default.values(this._nodeMap);
        },
        enumerable: false,
        configurable: true
    });
    RegistryBundleState.prototype.getCount = function () {
        return the_lodash_1.default.keys(this._nodeMap).length;
    };
    RegistryBundleState.prototype.getNodeItem = function (dn) {
        var node = this._nodeMap[dn];
        if (!node) {
            return null;
        }
        return node;
    };
    RegistryBundleState.prototype.getNode = function (dn) {
        var config = this._nodeConfigs[dn];
        if (!config) {
            return null;
        }
        return config;
    };
    RegistryBundleState.prototype.getChildren = function (parentDn) {
        var result = [];
        var childDns = this.registryState.getChildrenDns(parentDn);
        for (var _i = 0, childDns_1 = childDns; _i < childDns_1.length; _i++) {
            var childDn = childDns_1[_i];
            var childNode = this._nodeConfigs[childDn];
            if (childNode) {
                result.push(childNode);
            }
        }
        return result;
    };
    RegistryBundleState.prototype._buildNodes = function () {
        for (var _i = 0, _a = this._registryState.getNodes(); _i < _a.length; _i++) {
            var node = _a[_i];
            this._nodeMap[node.dn] = new registry_bundle_node_1.RegistryBundleNode(this, node);
        }
    };
    RegistryBundleState.prototype._finalize = function () {
        for (var _i = 0, _a = the_lodash_1.default.values(this._nodeMap); _i < _a.length; _i++) {
            var node = _a[_i];
            var childDns = this.registryState.getChildrenDns(node.dn);
            var nodeConfig = __assign(__assign({}, node.registryNode.config), { markers: node.registryNode.markers, selfAlertCount: node.selfAlertCount, alertCount: node.alertCount, childrenCount: childDns.length });
            this._nodeConfigs[node.dn] = nodeConfig;
        }
        this._traverseNodes(function (dn, node) {
            var alerts = node.selfAlerts;
            for (var _i = 0, alerts_1 = alerts; _i < alerts_1.length; _i++) {
                var alert_1 = alerts_1[_i];
                node.selfAlertCount[alert_1.severity] += 1;
                node.alertCount[alert_1.severity] += 1;
            }
            if (alerts.length > 0) {
                node.hierarchyAlerts[dn] = alerts;
            }
        });
        this._traverseTreeBottomsUp(function (dn, node, parentDn, parentNode) {
            if (!parentDn) {
                return;
            }
            var srcDict = node.hierarchyAlerts;
            var destDict = parentNode.hierarchyAlerts;
            for (var _i = 0, _a = the_lodash_1.default.keys(srcDict); _i < _a.length; _i++) {
                var x = _a[_i];
                destDict[x] = srcDict[x];
            }
            parentNode.alertCount.error += node.alertCount.error;
            parentNode.alertCount.warn += node.alertCount.warn;
        });
    };
    RegistryBundleState.prototype._traverseTreeBottomsUp = function (cb) {
        var _this = this;
        var traverseNode = function (dn, parentDn, parentNode) {
            var node = _this._nodeMap[dn];
            if (!node) {
                return;
            }
            var childrenDns = _this._registryState.getChildrenDns(dn);
            for (var _i = 0, childrenDns_1 = childrenDns; _i < childrenDns_1.length; _i++) {
                var childDn = childrenDns_1[_i];
                traverseNode(childDn, dn, node);
            }
            cb(dn, node, parentDn, parentNode);
        };
        traverseNode(ROOT_NAME, null, null);
    };
    RegistryBundleState.prototype._traverseNodes = function (cb) {
        for (var _i = 0, _a = the_lodash_1.default.keys(this._nodeMap); _i < _a.length; _i++) {
            var dn = _a[_i];
            var node = this._nodeMap[dn];
            if (node) {
                cb(dn, node);
            }
        }
    };
    return RegistryBundleState;
}());
exports.RegistryBundleState = RegistryBundleState;
//# sourceMappingURL=registry-bundle-state.js.map