import { ILogger } from 'the-logger';
import { NodeKind, PropsId } from '@kubevious/entity-meta';
import { RegistryStateNode } from './registry-state-node';
import { RegistryBundleState } from './registry-bundle-state';
import { Alert } from './types/alert';
import { SnapshotNodeConfig, SnapshotPropsConfig } from './types/configs';
import { SnapshotInfo, SnapshotItemInfo } from './types/snapshot';
import { RegistryAccessor, ItemProperties } from './registry-accessor';
export declare class RegistryState implements RegistryAccessor {
    private _date;
    private _nodeMap;
    private _childrenMap;
    private _propertiesMap;
    private _alertsMap;
    private _kindMap;
    private _stateBundle?;
    constructor(snapshotInfo: SnapshotInfo);
    get date(): Date;
    getCount(): number;
    getAllProperties(dn: string): ItemProperties;
    getProperties(dn: string, id: PropsId): SnapshotPropsConfig;
    getAlerts(dn: string): Alert[];
    getNodes(): RegistryStateNode[];
    getNodeDns(): string[];
    getNode(dn: string): SnapshotNodeConfig | null;
    findByKind(kind: NodeKind): Record<string, RegistryStateNode>;
    findByDn(dn: string): RegistryStateNode | null;
    countByKind(kind: NodeKind): number;
    childrenByKind(parentDn: string, kind: NodeKind): string[];
    scopeByKind(ancestorDn: string, kind: NodeKind): string[];
    countScopeByKind(ancestorDn: string, kind: NodeKind): number;
    scopeFlat(ancestorDn: string): RegistryStateNode[];
    getChildrenDns(dn: string): string[];
    addNewItem(item: SnapshotItemInfo): void;
    extractSnapshotInfo(): SnapshotInfo;
    private _transform;
    private _addTreeNode;
    private _registerChild;
    private _getProperties;
    private _getAlerts;
    private _fetchProperties;
    private _fetchAlerts;
    raiseAlert(dn: string, alertInfo: Alert): void;
    raiseMarker(dn: string, name: string): void;
    postProcessAlerts(cb: (dn: string, alerts: Alert[]) => void): void;
    buildBundle(): RegistryBundleState;
    debugOutputToDir(logger: ILogger, relPath: string): Promise<void>;
}
//# sourceMappingURL=registry-state.d.ts.map