/// <reference types="node" />
import { ILogger } from 'the-logger';
import { Method as AxiosMethod } from 'axios';
import { AgentOptions as HttpsAgentOptions } from 'https';
import { ApiGroupInfo } from "./types";
import { ResourceAccessor } from './resource-accessor';
import { ClusterInfo } from './cluster-info-fetcher';
import { KubernetesOpenApiClient } from './open-api/open-api-client';
import { ApiResourceKey } from './utils';
export interface KubernetesClientConfig {
    httpAgent?: HttpsAgentOptions;
    server?: string;
    token?: string;
}
export type ClusterInfoWatchCallback = (isPresent: boolean, apiGroup: ApiGroupInfo, client?: ResourceAccessor) => any;
export declare class KubernetesClient {
    private _logger;
    private _config;
    private _isClosed;
    private _clusterInfo;
    private _enabledApiGroups;
    private _preferredApiVersions;
    private _resources;
    private _clusterInfoWatches;
    private _clusterInfoRefreshDelay;
    private _clusterInfoRefreshTimer;
    private _openApi;
    constructor(logger: ILogger, config: KubernetesClientConfig);
    get logger(): ILogger;
    get clusterInfo(): ClusterInfo;
    get openAPI(): KubernetesOpenApiClient;
    get ApiGroups(): ApiGroupInfo[];
    get ReplicaSet(): ResourceAccessor | null;
    get Deployment(): ResourceAccessor | null;
    get StatefulSet(): ResourceAccessor | null;
    get DaemonSet(): ResourceAccessor | null;
    get CustomResourceDefinition(): ResourceAccessor | null;
    get PriorityClass(): ResourceAccessor | null;
    get Node(): ResourceAccessor | null;
    get Pod(): ResourceAccessor | null;
    get Namespace(): ResourceAccessor | null;
    get ServiceAccount(): ResourceAccessor | null;
    get ClusterRole(): ResourceAccessor | null;
    get ClusterRoleBinding(): ResourceAccessor | null;
    get Role(): ResourceAccessor | null;
    get RoleBinding(): ResourceAccessor | null;
    get Service(): ResourceAccessor | null;
    get Secret(): ResourceAccessor | null;
    get ConfigMap(): ResourceAccessor | null;
    get LimitRange(): ResourceAccessor | null;
    get Ingress(): ResourceAccessor | null;
    get HorizontalPodAutoscaler(): ResourceAccessor | null;
    get Job(): ResourceAccessor | null;
    get CronJob(): ResourceAccessor | null;
    init(): Promise<KubernetesClient>;
    close(): void;
    watchClusterApi(cb: ClusterInfoWatchCallback, delay?: number): {
        close: () => void;
    };
    private _setupClusterInfoRefreshTimer;
    private _stopClusterInfoRefreshTimer;
    private _refreshClusterResources;
    private _setupClusterResources;
    private _fetchClusterInfo;
    private _groupVersions;
    private _preferredApiResourceInfos;
    private _applyClusterInfo;
    private _notifyApi;
    client(kindName: string, apiName?: string | null, version?: string): ResourceAccessor | null;
    request<T = any>(method: AxiosMethod, url: string, params?: Record<string, any>, body?: Record<string, any> | null, useStream?: boolean): Promise<T>;
    requestSync<T = any>(method: AxiosMethod, url: string, params?: Record<string, any>, body?: Record<string, any> | null): T;
    private _makeAxiosOptions;
    private _handleAxiosResponse;
    private _handleAxiosError;
}
export interface ApiResourceInfo {
    key: ApiResourceKey;
    group: ApiGroupInfo;
}
//# sourceMappingURL=client.d.ts.map