"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KubernetesClient = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var the_promise_1 = require("the-promise");
var uuid_1 = require("uuid");
var axios_1 = __importDefault(require("axios"));
var https_1 = require("https");
var types_1 = require("./types");
var resource_accessor_1 = require("./resource-accessor");
var cluster_info_fetcher_1 = require("./cluster-info-fetcher");
var cluster_info_watch_1 = require("./cluster-info-watch");
var open_api_client_1 = require("./open-api/open-api-client");
var utils_1 = require("./utils");
var syncingabout_1 = __importDefault(require("./vendor/syncingabout"));
var RPCSyncClient = null;
var KubernetesClient = /** @class */ (function () {
    function KubernetesClient(logger, config) {
        this._isClosed = false;
        this._clusterInfo = {
            rootApiVersion: "",
            apiGroups: [],
            enabledApiGroups: {},
            preferredVersions: {}
        };
        this._enabledApiGroups = {};
        this._preferredApiVersions = {};
        this._resources = {};
        this._clusterInfoWatches = {};
        this._clusterInfoRefreshTimer = null;
        this._groupVersions = {};
        this._preferredApiResourceInfos = {};
        this._logger = logger;
        this._config = config;
        this._logger.info('[construct] ');
        this._logger.silly('[construct] ', this._config);
        this._openApi = new open_api_client_1.KubernetesOpenApiClient(this);
    }
    Object.defineProperty(KubernetesClient.prototype, "logger", {
        get: function () {
            return this._logger;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "clusterInfo", {
        get: function () {
            return this._clusterInfo;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "openAPI", {
        get: function () {
            return this._openApi;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "ApiGroups", {
        get: function () {
            return the_lodash_1.default.values(this._enabledApiGroups);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "ReplicaSet", {
        get: function () {
            return this.client('ReplicaSet', 'apps');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Deployment", {
        get: function () {
            return this.client('Deployment', 'apps');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "StatefulSet", {
        get: function () {
            return this.client('StatefulSet', 'apps');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "DaemonSet", {
        get: function () {
            return this.client('DaemonSet', 'apps');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "CustomResourceDefinition", {
        get: function () {
            return this.client('CustomResourceDefinition', 'apiextensions.k8s.io');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "PriorityClass", {
        get: function () {
            return this.client('PriorityClass', 'scheduling.k8s.io');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Node", {
        get: function () {
            return this.client('Node');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Pod", {
        get: function () {
            return this.client('Pod');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Namespace", {
        get: function () {
            return this.client('Namespace');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "ServiceAccount", {
        get: function () {
            return this.client('ServiceAccount');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "ClusterRole", {
        get: function () {
            return this.client('ClusterRole', 'rbac.authorization.k8s.io');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "ClusterRoleBinding", {
        get: function () {
            return this.client('ClusterRoleBinding', 'rbac.authorization.k8s.io');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Role", {
        get: function () {
            return this.client('ClusterRole', 'rbac.authorization.k8s.io');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "RoleBinding", {
        get: function () {
            return this.client('ClusterRoleBinding', 'rbac.authorization.k8s.io');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Service", {
        get: function () {
            return this.client('Service');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Secret", {
        get: function () {
            return this.client('Secret');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "ConfigMap", {
        get: function () {
            return this.client('ConfigMap');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "LimitRange", {
        get: function () {
            return this.client('LimitRange');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Ingress", {
        get: function () {
            return this.client('Ingress', 'networking.k8s.io') || this.client('Ingress', 'extensions');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "HorizontalPodAutoscaler", {
        get: function () {
            return this.client('HorizontalPodAutoscaler', 'autoscaling');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "Job", {
        get: function () {
            return this.client('Job', 'batch');
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(KubernetesClient.prototype, "CronJob", {
        get: function () {
            return this.client('CronJob');
        },
        enumerable: false,
        configurable: true
    });
    KubernetesClient.prototype.init = function () {
        var _this = this;
        return this._setupClusterResources()
            .then(function () { return _this; });
    };
    KubernetesClient.prototype.close = function () {
        this.logger.info("[close]");
        this._isClosed = true;
        this._clusterInfoWatches = {};
        this._stopClusterInfoRefreshTimer();
        for (var _i = 0, _a = the_lodash_1.default.values(this._resources); _i < _a.length; _i++) {
            var resource = _a[_i];
            resource.close();
        }
        this._resources = {};
    };
    KubernetesClient.prototype.watchClusterApi = function (cb, delay) {
        var _this = this;
        this.logger.info("[watchClusterApi] ");
        var id = (0, uuid_1.v4)();
        var watch = new cluster_info_watch_1.ClusterInfoWatch(this._logger, this, cb);
        this._clusterInfoWatches[id] = watch;
        Promise.resolve(null)
            .then(function () {
            var apis = the_lodash_1.default.values(_this._enabledApiGroups).map(function (x) { return ({
                api: x,
                client: _this.client(x.kindName, x.apiName)
            }); });
            return the_promise_1.MyPromise.serial(apis, function (x) {
                return watch.notifyApi(true, x.api, x.client);
            });
        });
        this._clusterInfoRefreshDelay = delay;
        this._setupClusterInfoRefreshTimer();
        return {
            close: function () {
                delete _this._clusterInfoWatches[id];
                if (the_lodash_1.default.keys(_this._clusterInfoWatches).length == 0) {
                    _this._stopClusterInfoRefreshTimer();
                }
            }
        };
    };
    KubernetesClient.prototype._setupClusterInfoRefreshTimer = function () {
        var _this = this;
        if (this._isClosed) {
            return;
        }
        if (this._clusterInfoRefreshTimer) {
            return;
        }
        if (the_lodash_1.default.keys(this._clusterInfoWatches).length == 0) {
            return;
        }
        var delay = this._clusterInfoRefreshDelay || 60 * 60 * 1000;
        this.logger.info("[_setupClusterInfoRefreshTimer] setTimeout. delay: %s", delay);
        this._clusterInfoRefreshTimer = setTimeout(function () {
            Promise.resolve(null)
                .then(function () { return _this._refreshClusterResources(); })
                .then(function () {
                _this._clusterInfoRefreshTimer = null;
                _this._setupClusterInfoRefreshTimer();
            })
                .catch(function (reason) {
                _this.logger.error("[_setupClusterInfoRefreshTimer] ERROR: ", reason);
            })
                .then(function () { return null; });
        }, delay);
    };
    KubernetesClient.prototype._stopClusterInfoRefreshTimer = function () {
        this.logger.info("[_stopClusterInfoRefreshTimer]");
        if (this._clusterInfoRefreshTimer) {
            clearTimeout(this._clusterInfoRefreshTimer);
            this._clusterInfoRefreshTimer = null;
        }
    };
    KubernetesClient.prototype._refreshClusterResources = function () {
        return this._setupClusterResources()
            .then(function () {
        });
    };
    KubernetesClient.prototype._setupClusterResources = function () {
        var _this = this;
        return this._fetchClusterInfo()
            .then(function (clusterInfo) {
            return _this._applyClusterInfo(clusterInfo);
        });
    };
    KubernetesClient.prototype._fetchClusterInfo = function () {
        var fetcher = new cluster_info_fetcher_1.ClusterInfoFetcher(this.logger, this);
        return fetcher.perform();
    };
    KubernetesClient.prototype._applyClusterInfo = function (clusterInfo) {
        var _this = this;
        var groupVersions = {};
        var preferredApiResourceInfos = {};
        for (var _i = 0, _a = the_lodash_1.default.values(clusterInfo.enabledApiGroups); _i < _a.length; _i++) {
            var api = _a[_i];
            for (var _b = 0, _c = api.allVersions; _b < _c.length; _b++) {
                var version = _c[_b];
                var key = {
                    api: api.apiName,
                    version: version,
                    kind: api.kindName
                };
                var resourceInfo = {
                    key: key,
                    group: api
                };
                if (!groupVersions[api.id]) {
                    groupVersions[api.id] = {};
                }
                groupVersions[api.id][version] = resourceInfo;
            }
            {
                var key = {
                    api: api.apiName,
                    version: api.version,
                    kind: api.kindName
                };
                preferredApiResourceInfos[api.id] = {
                    key: key,
                    group: api
                };
            }
        }
        // this.logger.error("[_applyClusterInfo] >>>>>>>> groupVersions: ", groupVersions);
        // this.logger.error("[_applyClusterInfo] >>>>>>>> preferredVersions: ", preferredApiResourceInfos);
        var toBeDeletedNotification = [];
        var toBeCreatedNotification = [];
        for (var _d = 0, _e = the_lodash_1.default.keys(preferredApiResourceInfos); _d < _e.length; _d++) {
            var apiId_1 = _e[_d];
            var newApi = preferredApiResourceInfos[apiId_1];
            var currApi = this._preferredApiResourceInfos[apiId_1];
            if (!currApi) {
                toBeCreatedNotification.push({ api: newApi.group });
            }
            else {
                if (currApi.key.version !== newApi.key.version) {
                    toBeDeletedNotification.push(currApi.group);
                    toBeCreatedNotification.push({ api: newApi.group });
                }
            }
        }
        for (var _f = 0, _g = the_lodash_1.default.keys(this._preferredApiResourceInfos); _f < _g.length; _f++) {
            var apiId_2 = _g[_f];
            var currApi = this._preferredApiResourceInfos[apiId_2];
            var newApi = preferredApiResourceInfos[apiId_2];
            if (!newApi) {
                toBeDeletedNotification.push(currApi.group);
            }
        }
        this._clusterInfo = clusterInfo;
        this._preferredApiVersions = clusterInfo.preferredVersions;
        this._enabledApiGroups = clusterInfo.enabledApiGroups;
        this._groupVersions = groupVersions;
        this._preferredApiResourceInfos = preferredApiResourceInfos;
        for (var _h = 0, toBeDeletedNotification_1 = toBeDeletedNotification; _h < toBeDeletedNotification_1.length; _h++) {
            var apiGroup = toBeDeletedNotification_1[_h];
            var apiVersionsInfo = this._groupVersions[apiGroup.id];
            for (var _j = 0, _k = the_lodash_1.default.values(apiVersionsInfo); _j < _k.length; _j++) {
                var apiVersionInfo = _k[_j];
                var accessorKey = (0, utils_1.apiVersionId)(apiVersionInfo.key);
                if (this._resources[accessorKey]) {
                    this._resources[accessorKey].close();
                    delete this._resources[accessorKey];
                }
            }
        }
        for (var _l = 0, toBeCreatedNotification_1 = toBeCreatedNotification; _l < toBeCreatedNotification_1.length; _l++) {
            var api = toBeCreatedNotification_1[_l];
            api.client = this.client(api.api.kindName, api.api.apiName, api.api.version);
        }
        return Promise.resolve()
            .then(function () {
            return the_promise_1.MyPromise.serial(toBeDeletedNotification, function (x) {
                _this._notifyApi(false, x);
            });
        })
            .then(function () {
            return the_promise_1.MyPromise.serial(toBeCreatedNotification, function (x) {
                _this._notifyApi(true, x.api, x.client);
            });
        });
    };
    KubernetesClient.prototype._notifyApi = function (isPresent, apiGroup, client) {
        return the_promise_1.MyPromise.serial(the_lodash_1.default.values(this._clusterInfoWatches), function (x) {
            return x.notifyApi(isPresent, apiGroup, client);
        });
    };
    KubernetesClient.prototype.client = function (kindName, apiName, version) {
        var _a;
        var apiKey = (0, utils_1.apiId)(kindName, apiName !== null && apiName !== void 0 ? apiName : null);
        var apiGroupInfo = (_a = this._clusterInfo) === null || _a === void 0 ? void 0 : _a.enabledApiGroups[apiKey];
        if (!apiGroupInfo) {
            return null;
        }
        if (!version) {
            version = apiGroupInfo.version;
        }
        var apiVersionInfo = this._groupVersions[apiKey];
        if (!apiVersionInfo) {
            return null;
        }
        var specificVersionInfo = apiVersionInfo[version];
        if (!specificVersionInfo) {
            return null;
        }
        var accessorKey = (0, utils_1.apiVersionId)(specificVersionInfo.key);
        if (!this._resources[accessorKey]) {
            this._resources[accessorKey] = new resource_accessor_1.ResourceAccessor(this, apiGroupInfo.apiName, apiGroupInfo.version, apiGroupInfo.pluralName, apiGroupInfo.kindName);
        }
        // this.logger.info("[client] GET CLIENT: ", specificVersionInfo.key)
        return this._resources[accessorKey];
    };
    KubernetesClient.prototype.request = function (method, url, params, body, useStream) {
        var _this = this;
        this._logger.debug('[request] %s => %s...', method, url);
        this.logger.debug("[request] -> %s", url);
        var options = this._makeAxiosOptions(method, url, params, body, useStream);
        var axiosRequest = {
            method: options.method,
            baseURL: options.baseURL,
            url: options.url,
            headers: options.headers,
            httpsAgent: options.httpsAgentOptions ? new https_1.Agent(options.httpsAgentOptions) : undefined,
            params: options.params,
            data: options.data,
            responseType: options.responseType,
        };
        this._logger.silly('[request] Begin', options);
        return Promise.resolve()
            .then(function () { return (0, axios_1.default)(axiosRequest); })
            .then(function (result) {
            _this._logger.silly('[request] RAW RESULT:', result);
            if (useStream) {
                return result;
            }
            return _this._handleAxiosResponse(result);
        })
            .catch(function (reason) {
            return _this._handleAxiosError(reason, options);
        });
    };
    KubernetesClient.prototype.requestSync = function (method, url, params, body) {
        this._logger.debug('[requestSync] %s => %s...', method, url);
        this.logger.debug("[requestSync] -> %s", url);
        var options = this._makeAxiosOptions(method, url, params, body, false);
        this._logger.silly('[requestSync] Begin', options);
        if (!RPCSyncClient) {
            RPCSyncClient = (0, syncingabout_1.default)('./client-sync/method.js');
        }
        var result = RPCSyncClient(options);
        this._logger.silly('[requestSync] RAW RESULT:', result);
        if (result.success) {
            return this._handleAxiosResponse(result.response);
        }
        else {
            return this._handleAxiosError(result.reason, options);
        }
    };
    KubernetesClient.prototype._makeAxiosOptions = function (method, url, params, body, useStream) {
        var httpAgentParams = this._config.httpAgent || {};
        var options = {
            method: method,
            baseURL: this._config.server,
            url: url,
            headers: {},
            httpsAgentOptions: httpAgentParams
        };
        if (this._config.token) {
            options.headers['Authorization'] = "Bearer ".concat(this._config.token);
        }
        if (params) {
            options.params = params;
        }
        if (body) {
            options.data = body;
        }
        if (useStream) {
            options.responseType = 'stream';
        }
        return options;
    };
    KubernetesClient.prototype._handleAxiosResponse = function (result) {
        this._logger.silly('[request] RAW RESULT:', result);
        var resultData = result.data;
        if (!resultData) {
            throw new Error("No result");
        }
        if (resultData.kind == "Status") {
            if (resultData.status == "Failure") {
                throw new types_1.KubernetesError(resultData.message, resultData.code);
            }
        }
        return resultData;
    };
    KubernetesClient.prototype._handleAxiosError = function (reason, options) {
        var response = reason.response;
        var status = 0;
        var errorMessage = '';
        if (response) {
            status = response.status;
            errorMessage = response.statusText;
            this._logger.warn('[request] Failed. Method: %s. StatusCode: %s-%s. ', options.method, status, errorMessage);
        }
        else {
            errorMessage = reason.message;
            this._logger.warn('[request] Failed. Method: %s. Connection Error: ', options.method, reason);
        }
        if (options.method === 'GET') {
            if (status == 404) {
                return null;
            }
        }
        if (options.method == 'DELETE') {
            if (status == 404) {
                return reason;
            }
        }
        if (response) {
            if (response.data) {
                if (response.data.kind == "Status") {
                    if (response.data.status == "Failure") {
                        throw new types_1.KubernetesError(reason.response.data.message, reason.response.data.code);
                    }
                }
            }
        }
        throw {
            status: status,
            message: errorMessage,
            method: options.method,
            baseURL: options.baseURL,
            url: options.url
        };
    };
    return KubernetesClient;
}());
exports.KubernetesClient = KubernetesClient;
//# sourceMappingURL=client.js.map