"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sOpenApiSpecToJsonSchemaConverter = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var open_api_v3_document_parser_1 = require("./open-api-v3-document-parser");
var open_api_v2_document_parser_1 = require("./open-api-v2-document-parser");
var K8sOpenApiSpecToJsonSchemaConverter = /** @class */ (function () {
    function K8sOpenApiSpecToJsonSchemaConverter(logger, openApiData) {
        this._k8sApiData = {
            resources: {},
            definitions: {}
        };
        this._logger = logger;
        this._openApiData = openApiData;
    }
    K8sOpenApiSpecToJsonSchemaConverter.prototype.convert = function () {
        this._k8sApiData.definitions = {};
        if (this._openApiData.openApiV3Data) {
            this._convertOpenApiV3();
        }
        if (this._openApiData.openApiV2Data) {
            this._convertOpenApiV2(this._openApiData.openApiV2Data);
        }
        // this._logger.info("ALL RESOURCES: ", this._k8sApiData.resources);
        // this._logger.info("ALL TYPES: ", _.keys(this._k8sApiData.definitions));
        return this._k8sApiData;
    };
    K8sOpenApiSpecToJsonSchemaConverter.prototype._convertOpenApiV3 = function () {
        for (var _i = 0, _a = the_lodash_1.default.keys(this._openApiData.openApiV3Data); _i < _a.length; _i++) {
            var apiName = _a[_i];
            var document_1 = this._openApiData.openApiV3Data[apiName];
            this._convertOpenApiV3Document(document_1);
        }
    };
    K8sOpenApiSpecToJsonSchemaConverter.prototype._convertOpenApiV3Document = function (document) {
        var documentParser = new open_api_v3_document_parser_1.OpenApiV3DocumentParser(this._logger, this._k8sApiData, document);
        documentParser.convert();
    };
    K8sOpenApiSpecToJsonSchemaConverter.prototype._convertOpenApiV2 = function (document) {
        var documentParser = new open_api_v2_document_parser_1.OpenApiV2DocumentParser(this._logger, this._k8sApiData, document);
        documentParser.convert();
    };
    return K8sOpenApiSpecToJsonSchemaConverter;
}());
exports.K8sOpenApiSpecToJsonSchemaConverter = K8sOpenApiSpecToJsonSchemaConverter;
//# sourceMappingURL=k8s-open-api-spec-to-json-schema-converter.js.map