"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.KubernetesOpenApiClient = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var the_promise_1 = require("the-promise");
var KubernetesOpenApiClient = /** @class */ (function () {
    function KubernetesOpenApiClient(client) {
        this._client = client;
    }
    KubernetesOpenApiClient.prototype.queryClusterVersionInfo = function () {
        return this._client.request('GET', '/version')
            .then(function (result) {
            var version = {
                major: parseInt(result.major),
                minor: parseInt(result.minor),
                gitVersion: result.gitVersion,
                gitCommit: result.gitCommit,
                gitTreeState: result.gitTreeState,
                buildDate: new Date(result.buildDate),
                goVersion: result.goVersion,
                compiler: result.compiler,
                platform: result.platform,
            };
            return version;
        });
    };
    KubernetesOpenApiClient.prototype.queryClusterVersion = function () {
        return this.queryClusterVersionInfo().then(function (x) { return x.gitVersion; });
    };
    KubernetesOpenApiClient.prototype.queryV3RootPaths = function () {
        return this._client.request('GET', '/openapi/v3');
    };
    KubernetesOpenApiClient.prototype.queryV3AllPaths = function () {
        var _this = this;
        var pathData = {};
        return this.queryV3RootPaths()
            .then(function (result) {
            return the_promise_1.MyPromise.execute(the_lodash_1.default.keys(result.paths), function (pathName) {
                return _this._client.request('GET', result.paths[pathName].serverRelativeURL)
                    .then(function (pathResult) {
                    pathData[pathName] = pathResult;
                });
            }, {
                concurrency: 10
            });
        })
            .then(function () { return pathData; });
    };
    KubernetesOpenApiClient.prototype.queryV2Root = function () {
        return this._client.request('GET', '/openapi/v2');
    };
    KubernetesOpenApiClient.prototype.queryApiSpecs = function (options) {
        var _this = this;
        options = options || {};
        if (options.forceApiV2 && options.forceApiV3) {
            throw new Error("Cannot use forceApiV2 and forceApiV3 at the same time.");
        }
        return this.queryClusterVersion()
            .then(function (version) {
            if (options.forceApiV3) {
                return _this._queryApiSpecsV3(version);
            }
            if (options.forceApiV2) {
                return _this._queryApiSpecsV2(version);
            }
            return _this.queryV3RootPaths()
                .then(function () {
                return _this._queryApiSpecsV3(version);
            })
                .catch(function () {
                return _this._queryApiSpecsV2(version);
            });
        });
    };
    KubernetesOpenApiClient.prototype._queryApiSpecsV3 = function (k8sVersion) {
        return this.queryV3AllPaths()
            .then(function (result) {
            var spec = {
                k8sVersion: k8sVersion,
                openApiVersion: '3.0',
                openApiV3Data: result
            };
            return spec;
        });
    };
    KubernetesOpenApiClient.prototype._queryApiSpecsV2 = function (k8sVersion) {
        return this.queryV2Root()
            .then(function (result) {
            var spec = {
                k8sVersion: k8sVersion,
                openApiVersion: '2.0',
                openApiV2Data: result
            };
            return spec;
        });
    };
    return KubernetesOpenApiClient;
}());
exports.KubernetesOpenApiClient = KubernetesOpenApiClient;
//# sourceMappingURL=open-api-client.js.map