import { AxiosRequestConfig } from 'axios';
import { ILogger } from 'the-logger';
import { KubernetesClient } from './client';
import { ConnectCallback, DisconnectCallback, ResourceWatch, WatchCallback } from './resource-watch';
import { KubernetesObject } from './types';
export interface ResourceScope {
    request(method: AxiosRequestConfig['method'], url: string, params?: Record<string, any>, body?: Record<string, any> | null, useStream?: boolean): Promise<any>;
}
export declare class ResourceAccessor {
    private _logger;
    private _parent;
    private _apiName;
    private _version;
    private _kindName;
    private _pluralName;
    private _watches;
    constructor(parent: KubernetesClient, apiName: string | null, version: string, pluralName: string, kindName: string);
    get logger(): ILogger;
    get apiName(): string | null;
    get kindName(): string;
    close(): void;
    queryAll(namespace?: string, labelFilter?: any): Promise<KubernetesObject[]>;
    queryAllSync(namespace?: string, labelFilter?: any): KubernetesObject[];
    private _formatQueryAllResult;
    watchAll(namespace: string | null, cb: WatchCallback, connectCb: ConnectCallback, disconnectCb: DisconnectCallback): ResourceWatch;
    query(namespace: string | null, name: string): Promise<KubernetesObject | null>;
    querySync(namespace: string | null, name: string): KubernetesObject | null;
    create(namespace: string | null, body: any): Promise<any>;
    delete(namespace: string, name: string): Promise<any>;
    update(namespace: string, name: string, body: any): Promise<any>;
    private _getRequest;
    private _makeGetParams;
    private _getRequestSync;
    private _postRequest;
    private _deleteRequest;
    private _putRequest;
    private _setupBody;
    _joinUrls(uriParts: string[]): string;
    _makeUriParts(namespace?: string | null): string[];
}
//# sourceMappingURL=resource-accessor.d.ts.map