"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeltaAction = exports.ResourceWatch = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var the_promise_1 = require("the-promise");
var ndjson = __importStar(require("ndjson"));
var ResourceWatch = /** @class */ (function () {
    function ResourceWatch(logger, resourceAccessor, namespace, cb, connectCb, disconnectCb, closeCb, scope) {
        this._snapshot = {};
        this._newSnapshot = {};
        this._recovering = false;
        this._isScheduled = false;
        this._scheduleTimeout = 100;
        this._isStopped = false;
        this._stream = null;
        this._isDisconnected = true;
        this._waitCloseResolveCb = [];
        this._runWatchTimer = null;
        this._recoveryTimer = null;
        this._logger = logger;
        this._resourceAccessor = resourceAccessor;
        this._namespace = namespace;
        this._cb = cb;
        this._connectCb = connectCb;
        this._disconnectCb = disconnectCb;
        this._closeCb = closeCb;
        this._scope = scope;
        this._name = "".concat(this._resourceAccessor.apiName, "::").concat(this._resourceAccessor.kindName);
    }
    Object.defineProperty(ResourceWatch.prototype, "logger", {
        get: function () {
            return this._logger;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ResourceWatch.prototype, "name", {
        get: function () {
            return this._name;
        },
        enumerable: false,
        configurable: true
    });
    ResourceWatch.prototype.start = function () {
        this._logger.info('[start] API: %s. Start.', this.name);
        // this._scope.watches[this._id] = this;
        this._runWatch();
    };
    ResourceWatch.prototype.stop = function () {
        this._logger.info('[stop] API: %s. Stop.', this.name);
        this._isStopped = true;
        this._stopRecoveryTimer();
        this._stopRunWatchTimer();
        this._closeStream();
        this._closeCb();
    };
    ResourceWatch.prototype.close = function () {
        return this.stop();
    };
    ResourceWatch.prototype.waitClose = function () {
        var _this = this;
        this._logger.info('[waitClose] API: %s. Waiting...', this.name);
        return the_promise_1.MyPromise.construct(function (resolve, reject) {
            if (_this._isDisconnected) {
                resolve();
            }
            else {
                _this._waitCloseResolveCb.push(function () {
                    _this._logger.info('[waitClose] API: %s. Finished.', _this.name);
                    resolve();
                });
            }
        });
    };
    ResourceWatch.prototype._closeStream = function () {
        if (this._stream) {
            this._logger.info('[_closeStream] API: %s. Destroying...', this.name);
            this._stream.destroy();
            this._stream = null;
            this._onDisconnect({});
        }
        else {
            this._logger.info('[_closeStream] API: %s.No stream', this.name);
        }
    };
    ResourceWatch.prototype._runWatch = function () {
        var _this = this;
        this._stopRunWatchTimer();
        this._isScheduled = false;
        var uriParts = this._resourceAccessor._makeUriParts(this._namespace);
        var url = this._resourceAccessor._joinUrls(uriParts);
        var params = {
            watch: true
        };
        this._isDisconnected = false;
        this._scope.request('GET', url, params, null, true)
            .then(function (result) {
            if (!result) {
                _this._logger.error('[_runWatch] API: %s. Empty Result. Disconnecting.', _this.name);
                _this._onDisconnect({
                    status: 500,
                    message: 'API returned empty result'
                });
                return;
            }
            _this._recovering = true;
            _this._newSnapshot = {};
            _this._scheduleRecoveryTimer(1000);
            _this._stream = result.data;
            _this._logger.info('[_runWatch] API: %s. Connected', _this.name);
            if (_this._connectCb) {
                _this._connectCb(_this._resourceAccessor);
            }
            _this._scheduleTimeout = 0;
            _this._stream
                .pipe(ndjson.parse())
                .on('data', function (data) {
                var item = data;
                if (!data.object) {
                    _this._logger.error('[_runWatch] API: %s. Missing Data:', _this.name, data);
                    return;
                }
                _this._handleChange(item.type, item.object);
            })
                .on('close', function () {
                _this._logger.info('[_runWatch] API: %s. STREAM :: close...', _this.name);
            })
                .on('drain', function () {
                _this._logger.info('[_runWatch] API: %s. STREAM :: drain...', _this.name);
            })
                .on('finish', function () {
                _this._logger.info('[_runWatch] API: %s. STREAM :: finish...', _this.name);
            })
                .on('end', function () {
                _this._logger.info('[_runWatch] API: %s. STREAM :: end...', _this.name);
                _this._onDisconnect({});
            })
                .on('error', function () {
                _this._logger.error('[_runWatch] API: %s. STREAM :: error...', _this.name);
                _this._onDisconnect({});
            });
            if (_this._isStopped) {
                _this._closeStream();
            }
        })
            .catch(function (reason) {
            var data = {};
            var isKnownError = false;
            if (reason.status) {
                _this.logger.error("[_runWatch] API: %s. Error Code: %s", _this.name, reason.status);
                data.status = reason.status;
                isKnownError = true;
            }
            if (reason.message) {
                _this.logger.error("[_runWatch] API: %s. Error Message: %s", _this.name, reason.message);
                data.message = reason.message;
                isKnownError = true;
            }
            if (!isKnownError) {
                _this.logger.error("[_runWatch] API: %s. Error: ", _this.name, reason);
            }
            _this._onDisconnect(data);
        });
    };
    ResourceWatch.prototype._handleChange = function (action, data) {
        this._logger.silly('[_handleChange] %s. %s :: %s...', this.name, action, data.metadata.name);
        if (this._recovering) {
            this._applyToSnapshot(this._newSnapshot, action, data);
            if (action == DeltaAction.Added) {
                this._scheduleRecoveryTimer(100);
            }
            else {
                this._handleRecovery();
            }
        }
        else {
            this._applyToSnapshot(this._snapshot, action, data);
            this._cb(action, data);
        }
    };
    ResourceWatch.prototype._applyToSnapshot = function (snapshot, action, data) {
        if (action == DeltaAction.Added || action == DeltaAction.Modified) {
            snapshot[data.metadata.name] = data;
            return;
        }
        if (action == DeltaAction.Deleted) {
            delete snapshot[data.metadata.name];
            return;
        }
        throw new Error("Unknown action: " + action);
    };
    ResourceWatch.prototype._onDisconnect = function (data) {
        this.logger.info('[_onDisconnect] ', data);
        if (this._isDisconnected) {
            return;
        }
        this._isDisconnected = true;
        if (this._stream) {
            this._stream.socket.destroy();
        }
        this._stream = null;
        if (this._disconnectCb) {
            this._disconnectCb(this._resourceAccessor, data);
        }
        this._tryReconnect();
        if (this._isStopped) {
            var cbs = this._waitCloseResolveCb;
            this._waitCloseResolveCb = [];
            for (var _i = 0, cbs_1 = cbs; _i < cbs_1.length; _i++) {
                var cb = cbs_1[_i];
                cb();
            }
        }
    };
    ResourceWatch.prototype._tryReconnect = function () {
        if (this._isStopped) {
            return;
        }
        this._logger.info('[_tryReconnect] API: %s. Reconnect.', this.name);
        this._scheduleRunWatch();
    };
    ResourceWatch.prototype._scheduleRunWatch = function () {
        var _this = this;
        if (this._isScheduled) {
            return;
        }
        this._isScheduled = true;
        if (this._scheduleTimeout < 100) {
            this._scheduleTimeout = 100;
        }
        else {
            this._scheduleTimeout = this._scheduleTimeout * 2;
        }
        this._scheduleTimeout = Math.min(this._scheduleTimeout, 1 * 60 * 1000);
        this._logger.silly('[_scheduleRunWatch] API: %s. timeout: %s...', this.name, this._scheduleTimeout);
        this._runWatchTimer = setTimeout(function () {
            _this._runWatch();
        }, this._scheduleTimeout);
    };
    ResourceWatch.prototype._scheduleRecoveryTimer = function (duration) {
        if (!this._recovering) {
            return;
        }
        this._logger.silly('[_scheduleRecoveryTimer] API: %s. timeout: %s...', this.name, duration);
        this._stopRecoveryTimer();
        this._recoveryTimer = setTimeout(this._handleRecovery.bind(this), duration);
    };
    ResourceWatch.prototype._handleRecovery = function () {
        this._logger.info('[_handleRecovery] API: %s...', this.name);
        this._stopRecoveryTimer();
        this._logger.silly('[_handleRecovery] API: %s. Snapshot: ', this.name, this._snapshot);
        this._logger.silly('[_handleRecovery] API: %s. NewSnapshot: ', this.name, this._newSnapshot);
        var delta = this._produceDelta(this._snapshot, this._newSnapshot);
        this._logger.silly('[_handleRecovery] API: %s. delta: ', this.name, delta);
        for (var _i = 0, delta_1 = delta; _i < delta_1.length; _i++) {
            var x = delta_1[_i];
            this._applyToSnapshot(this._snapshot, x.action, x.data);
            this._cb(x.action, x.data);
        }
        var finalDelta = this._produceDelta(this._snapshot, this._newSnapshot);
        if (finalDelta.length > 0) {
            this._logger.info('[_handleRecovery] API: %s. FINAL delta. should be zero: ', this.name, finalDelta);
            throw new Error("Final Delta After Recover Should Be Empty!");
        }
        this._recovering = false;
        this._newSnapshot = {};
        this._logger.info('[_handleRecovery] API: %s. Recovery completed.', this.name);
    };
    ResourceWatch.prototype._stopRunWatchTimer = function () {
        if (this._runWatchTimer) {
            clearTimeout(this._runWatchTimer);
            this._runWatchTimer = null;
        }
    };
    ResourceWatch.prototype._stopRecoveryTimer = function () {
        if (this._recoveryTimer) {
            clearTimeout(this._recoveryTimer);
            this._recoveryTimer = null;
        }
    };
    ResourceWatch.prototype._produceDelta = function (current, desired) {
        var delta = [];
        for (var _i = 0, _a = the_lodash_1.default.keys(current); _i < _a.length; _i++) {
            var x = _a[_i];
            if (x in desired) {
                if (!the_lodash_1.default.fastDeepEqual(current[x], desired[x])) {
                    delta.push({
                        action: DeltaAction.Modified,
                        data: the_lodash_1.default.cloneDeep(desired[x])
                    });
                }
            }
            else {
                delta.push({
                    action: DeltaAction.Deleted,
                    data: the_lodash_1.default.cloneDeep(current[x])
                });
            }
        }
        for (var _b = 0, _c = the_lodash_1.default.keys(desired); _b < _c.length; _b++) {
            var x = _c[_b];
            if (!(x in current)) {
                delta.push({
                    action: DeltaAction.Added,
                    data: the_lodash_1.default.cloneDeep(desired[x])
                });
            }
        }
        return delta;
    };
    return ResourceWatch;
}());
exports.ResourceWatch = ResourceWatch;
var DeltaAction;
(function (DeltaAction) {
    DeltaAction["Added"] = "ADDED";
    DeltaAction["Modified"] = "MODIFIED";
    DeltaAction["Deleted"] = "DELETED";
})(DeltaAction = exports.DeltaAction || (exports.DeltaAction = {}));
//# sourceMappingURL=resource-watch.js.map