"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var worker_threads_1 = require("worker_threads");
/**
 * @param {string} workerPath
 * @return {(...args: any) => any}
 */
function build(workerPath) {
    var taskPath = __dirname + '/task.js';
    // console.error("|-  MY PATH: ", __filename);
    // console.error("|- TaskPath: ", taskPath);
    var w = new worker_threads_1.Worker(taskPath, {
        workerData: workerPath,
    });
    w.on('error', function (err) {
        console.error("|- K8s-CLIENT WORKER ERROR: ", err);
        throw err;
    });
    // w.on('exit', (code) => {
    //   console.error("|- K8s-CLIENT WORKER EXIT: ", code);
    // })
    w.unref();
    var activeCount = 0;
    return function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        if (activeCount === 0) {
            w.ref();
            ++activeCount;
        }
        try {
            var shared = new SharedArrayBuffer(4);
            var int32 = new Int32Array(shared);
            var _a = new worker_threads_1.MessageChannel(), localPort = _a.port1, workerPort = _a.port2;
            w.postMessage({ port: workerPort, shared: shared, args: args }, [workerPort]);
            Atomics.wait(int32, 0, 0);
            var m = (0, worker_threads_1.receiveMessageOnPort)(localPort);
            if (m === undefined) {
                throw new Error("[SyncAbout] did not get async reply in time");
            }
            var message = m.message;
            if ('return' in message) {
                return message.return;
            }
            throw message.error;
        }
        finally {
            --activeCount;
            if (activeCount === 0) {
                w.unref();
            }
        }
    };
}
exports.default = build;
//# sourceMappingURL=index.js.map