"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.HeapPriorityQueue = exports.MaxHeap = exports.MinHeap = exports.GenericHeap = void 0;
var GenericHeap = /** @class */ (function () {
    function GenericHeap(comparer, items) {
        this._heap = [];
        this._comparer = comparer;
        for (var _i = 0, _a = items !== null && items !== void 0 ? items : []; _i < _a.length; _i++) {
            var item = _a[_i];
            this.insert(item);
        }
    }
    Object.defineProperty(GenericHeap.prototype, "isEmpty", {
        get: function () {
            return this._heap.length == 0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GenericHeap.prototype, "size", {
        get: function () {
            return this._heap.length;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(GenericHeap.prototype, "length", {
        get: function () {
            return this._heap.length;
        },
        enumerable: false,
        configurable: true
    });
    GenericHeap.prototype.peek = function () {
        return this._heap.length === 0 ? null : this._heap[0];
    };
    Object.defineProperty(GenericHeap.prototype, "rawHeap", {
        get: function () {
            return this._heap;
        },
        enumerable: false,
        configurable: true
    });
    GenericHeap.prototype.insert = function (item) {
        this._heap.push(item);
        var i = this._heap.length - 1;
        while (i > 0) {
            var p = this._parent(i);
            if (this._comparer(this._heap[p], this._heap[i]))
                break;
            var tmp = this._heap[i];
            this._heap[i] = this._heap[p];
            this._heap[p] = tmp;
            i = p;
        }
    };
    GenericHeap.prototype.pop = function () {
        if (this._heap.length == 0)
            return null;
        this._swap(0, this._heap.length - 1);
        var item = this._heap.pop();
        var current = 0;
        while (this._hasLeft(current)) {
            var smallerChild = this._left(current);
            if (this._hasRight(current) && this._comparer(this._heap[this._right(current)], this._heap[this._left(current)]))
                smallerChild = this._right(current);
            if (!this._comparer(this._heap[smallerChild], this._heap[current]))
                break;
            this._swap(current, smallerChild);
            current = smallerChild;
        }
        return item;
    };
    GenericHeap.prototype.print = function () {
        console.log(">>> -= HEAP =-");
        console.log(">>> COUNT: ".concat(this.length));
        for (var _i = 0, _a = this._heap; _i < _a.length; _i++) {
            var x = _a[_i];
            console.log("|- ".concat(x));
        }
        console.log(">>> --------------------");
    };
    /*****/
    GenericHeap.prototype._parent = function (index) {
        return Math.floor((index - 1) / 2);
    };
    GenericHeap.prototype._left = function (index) {
        return 2 * index + 1;
    };
    GenericHeap.prototype._right = function (index) {
        return 2 * index + 2;
    };
    GenericHeap.prototype._hasLeft = function (index) {
        return this._left(index) < this._heap.length;
    };
    GenericHeap.prototype._hasRight = function (index) {
        return this._right(index) < this._heap.length;
    };
    GenericHeap.prototype._swap = function (a, b) {
        var tmp = this._heap[a];
        this._heap[a] = this._heap[b];
        this._heap[b] = tmp;
    };
    return GenericHeap;
}());
exports.GenericHeap = GenericHeap;
var MinHeap = /** @class */ (function (_super) {
    __extends(MinHeap, _super);
    function MinHeap(items) {
        return _super.call(this, function (a, b) { return a < b; }, items) || this;
    }
    return MinHeap;
}(GenericHeap));
exports.MinHeap = MinHeap;
var MaxHeap = /** @class */ (function (_super) {
    __extends(MaxHeap, _super);
    function MaxHeap(items) {
        return _super.call(this, function (a, b) { return a > b; }, items) || this;
    }
    return MaxHeap;
}(GenericHeap));
exports.MaxHeap = MaxHeap;
var HeapPriorityQueue = /** @class */ (function (_super) {
    __extends(HeapPriorityQueue, _super);
    function HeapPriorityQueue(items) {
        return _super.call(this, function (a, b) { return a.priority < b.priority; }, items) || this;
    }
    HeapPriorityQueue.prototype.populate = function (items, priorityFunc) {
        for (var _i = 0, items_1 = items; _i < items_1.length; _i++) {
            var x = items_1[_i];
            this.insert({ value: x, priority: priorityFunc(x) });
        }
    };
    return HeapPriorityQueue;
}(GenericHeap));
exports.HeapPriorityQueue = HeapPriorityQueue;
//# sourceMappingURL=heap.js.map