"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PriorityQueue = void 0;
var PriorityQueue = /** @class */ (function () {
    function PriorityQueue() {
        this._heap = [];
    }
    Object.defineProperty(PriorityQueue.prototype, "isEmpty", {
        get: function () {
            return this._heap.length == 0;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PriorityQueue.prototype, "size", {
        get: function () {
            return this._heap.length;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PriorityQueue.prototype, "length", {
        get: function () {
            return this._heap.length;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(PriorityQueue.prototype, "rawHeap", {
        get: function () {
            return this._heap;
        },
        enumerable: false,
        configurable: true
    });
    PriorityQueue.prototype.peek = function () {
        return this._heap.length === 0 ? null : this._heap[0].value;
    };
    PriorityQueue.prototype.insert = function (item, priority) {
        this._heap.push({ priority: priority, value: item });
        var i = this._heap.length - 1;
        while (i > 0) {
            var p = this._parent(i);
            if (this._heap[p].priority < this._heap[i].priority)
                break;
            var tmp = this._heap[i];
            this._heap[i] = this._heap[p];
            this._heap[p] = tmp;
            i = p;
        }
    };
    PriorityQueue.prototype.populate = function (items, priorityFunc) {
        for (var _i = 0, items_1 = items; _i < items_1.length; _i++) {
            var x = items_1[_i];
            this.insert(x, priorityFunc(x));
        }
    };
    PriorityQueue.prototype.pop = function () {
        if (this._heap.length == 0)
            return null;
        this._swap(0, this._heap.length - 1);
        var item = this._heap.pop();
        var current = 0;
        while (this._hasLeft(current)) {
            var smallerChild = this._left(current);
            if (this._hasRight(current) && this._heap[this._right(current)].priority < this._heap[this._left(current)].priority)
                smallerChild = this._right(current);
            if (this._heap[smallerChild].priority > this._heap[current].priority)
                break;
            this._swap(current, smallerChild);
            current = smallerChild;
        }
        return item.value;
    };
    PriorityQueue.prototype.print = function () {
        console.log(">>> -= PRIORITY QUEUE =-");
        console.log(">>> COUNT: ".concat(this.length));
        for (var _i = 0, _a = this._heap; _i < _a.length; _i++) {
            var x = _a[_i];
            console.log("|   [".concat(x.priority, "] -> ").concat(x.value));
        }
        console.log(">>> --------------------");
    };
    /*****/
    PriorityQueue.prototype._parent = function (index) {
        return Math.floor((index - 1) / 2);
    };
    PriorityQueue.prototype._left = function (index) {
        return 2 * index + 1;
    };
    PriorityQueue.prototype._right = function (index) {
        return 2 * index + 2;
    };
    PriorityQueue.prototype._hasLeft = function (index) {
        return this._left(index) < this._heap.length;
    };
    PriorityQueue.prototype._hasRight = function (index) {
        return this._right(index) < this._heap.length;
    };
    PriorityQueue.prototype._swap = function (a, b) {
        var tmp = this._heap[a];
        this._heap[a] = this._heap[b];
        this._heap[b] = tmp;
    };
    return PriorityQueue;
}());
exports.PriorityQueue = PriorityQueue;
//# sourceMappingURL=priority-queue.js.map