"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseLogger = void 0;
const path_1 = require("path");
const levels_1 = require("./levels");
const dump_writer_1 = require("./dump-writer");
const file_utils_1 = require("./file-utils");
class BaseLogger {
    constructor(root, name) {
        this._logFile = null;
        this._level = levels_1.LogLevel.info;
        this._root = root;
        this._name = name;
        this._options = root.options;
    }
    get name() {
        return this._name;
    }
    get level() {
        return this._level;
    }
    get options() {
        return this._options;
    }
    setup(options) {
        this._options = options;
        if (this._options.enableFile) {
            let dir = this._root.rootDir;
            this._logFile = (0, path_1.join)(dir, this._name + '.log');
        }
        else {
            this._logFile = null;
        }
        this._level = this._options.subLevels[this._name];
        if (!this._level) {
            this._level = this.options.level;
        }
        this._implInit();
    }
    sublogger(name) {
        return this._root.sublogger(name);
    }
    _implInit() {
        throw new Error('Not Implemented');
    }
    flush() { }
    outputStream(fileName) {
        if (!this.options.enableFile) {
            return null;
        }
        const filePath = (0, path_1.join)(this._root.rootDir, fileName);
        (0, file_utils_1.ensureFileDirectory)(filePath);
        const writer = new dump_writer_1.DumpWriter(filePath);
        return writer;
    }
    outputFile(fileName, contents) {
        const writer = this.outputStream(fileName);
        if (!writer) {
            return Promise.resolve();
        }
        return writer.write(contents).close();
    }
}
exports.BaseLogger = BaseLogger;
//# sourceMappingURL=base.js.map