"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DumpWriter = void 0;
const fs_1 = require("fs");
const the_lodash_1 = __importDefault(require("the-lodash"));
const the_promise_1 = require("the-promise");
class DumpWriter {
    constructor(filePath) {
        this._indent = 0;
        this._writer = (0, fs_1.createWriteStream)(filePath);
    }
    write(obj) {
        if (the_lodash_1.default.isNullOrUndefined(obj)) {
            return this;
        }
        if (the_lodash_1.default.isString(obj) || the_lodash_1.default.isNumber(obj) || the_lodash_1.default.isBoolean(obj)) {
            this._writer.write('    '.repeat(this._indent));
            this._writer.write(obj);
            this._writer.write('\n');
        }
        else {
            for (const x of JSON.stringify(obj, null, 4).split('\n')) {
                this._writer.write('    '.repeat(this._indent));
                this._writer.write(x);
                this._writer.write('\n');
            }
        }
        return this;
    }
    writeHeader(str) {
        this._writer.write('\n');
        this._writer.write('**** ' + str + '\n');
        return this;
    }
    newLine() {
        this._writer.write('\n');
        return this;
    }
    indent() {
        this._indent++;
        return this;
    }
    unindent() {
        this._indent--;
        return this;
    }
    close() {
        return the_promise_1.MyPromise.construct((resolve, reject) => {
            this._writer.on('error', (err) => {
                reject(err);
            });
            this._writer.end(null, 'utf8', () => {
                resolve();
            });
        });
    }
}
exports.DumpWriter = DumpWriter;
//# sourceMappingURL=dump-writer.js.map