"use strict";
/** Because of issues with pino verison dependency this files is copied from original */
/** Copied from: https://github.com/pinojs/pino-multi-stream **/
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PinoLogger = void 0;
const fs_1 = require("fs");
const the_lodash_1 = __importDefault(require("the-lodash"));
const pino_1 = __importDefault(require("pino"));
const PinoMultiStream = require("./pino-multi-stream");
const base_1 = require("../base");
const levels_1 = require("../levels");
const LEVEL_DICT = {
    [levels_1.LogLevel.error]: 'error',
    [levels_1.LogLevel.warn]: 'warn',
    [levels_1.LogLevel.info]: 'info',
    [levels_1.LogLevel.verbose]: 'debug',
    [levels_1.LogLevel.debug]: 'debug',
    [levels_1.LogLevel.silly]: 'trace',
};
class PinoLogger extends base_1.BaseLogger {
    constructor(root, name) {
        super(root, name);
    }
    get logger() {
        return this._log;
    }
    close() { }
    _getLevel(level) {
        return LEVEL_DICT[level];
    }
    _implInit() {
        const myLevel = this._getLevel(this.level);
        const pinoOptions = {
            name: this.name,
            level: myLevel,
        };
        const outputStreamList = [];
        if (this.options.pretty) {
            const prettyOptions = {
                levelFirst: false,
                translateTime: 'yyyy-mm-dd HH:MM:ss.l',
                ignore: 'pid,hostname',
            };
            const prettyStream = PinoMultiStream.prettyStream({
                prettyPrint: prettyOptions
            });
            outputStreamList.push({ level: myLevel, stream: prettyStream });
        }
        else {
            outputStreamList.push({ level: myLevel, stream: process.stdout });
        }
        process.stdout.setMaxListeners(process.stdout.getMaxListeners() + 1);
        if (this._logFile) {
            const streamOptions = {
                flags: 'a',
            };
            const logFileStream = (0, fs_1.createWriteStream)(this._logFile, streamOptions);
            outputStreamList.push({ level: myLevel, stream: logFileStream });
        }
        const myMultiStream = pino_1.default.multistream(outputStreamList);
        this._log = (0, pino_1.default)(pinoOptions, myMultiStream);
    }
    exception(error) {
        this.error('*** EXCEPTION HAPPENED ***', error);
    }
    error(msg, ...args) {
        this._executeLog(levels_1.LogLevel.error, msg, ...args);
    }
    warn(msg, ...args) {
        this._executeLog(levels_1.LogLevel.warn, msg, ...args);
    }
    info(msg, ...args) {
        this._executeLog(levels_1.LogLevel.info, msg, ...args);
    }
    verbose(msg, ...args) {
        this._executeLog(levels_1.LogLevel.verbose, msg, ...args);
    }
    debug(msg, ...args) {
        this._executeLog(levels_1.LogLevel.debug, msg, ...args);
    }
    silly(msg, ...args) {
        this._executeLog(levels_1.LogLevel.silly, msg, ...args);
    }
    _executeLog(level, msg, ...args) {
        const xlevel = this._getLevel(level);
        const handler = this.logger[xlevel];
        if (handler.name == 'noop') {
            return;
        }
        const mergingObj = {};
        if (args.length > 0) {
            const count = (msg.match(/%s|%d|%O|%o|%j/g) || []).length;
            const formatArgs = the_lodash_1.default.take(args, count);
            const objArgs = the_lodash_1.default.drop(args, count);
            for (let i in objArgs) {
                const obj = objArgs[i];
                if (obj instanceof Error) {
                    msg += ' %s';
                    formatArgs.push(obj.stack);
                }
                else {
                    mergingObj[`arg${i}`] = obj;
                }
            }
            args = formatArgs;
            for (let i = 0; i < args.length; i++) {
                let val = args[i];
                if (val instanceof Error) {
                    mergingObj[`arg${the_lodash_1.default.keys(mergingObj).length}`] = 'Error: ' + val.message;
                    args[i] = val.stack;
                }
            }
        }
        handler.call(this._log, mergingObj, msg, ...args);
    }
    flush() {
        this.logger.flush();
    }
}
exports.PinoLogger = PinoLogger;
//# sourceMappingURL=pino.js.map