"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RootLogger = void 0;
const fs_extra_1 = require("fs-extra");
const options_1 = require("./options");
const pino_1 = require("./loggers/pino");
const file_utils_1 = require("./file-utils");
class RootLogger {
    constructor(name, options) {
        this._subloggers = {};
        this._rootDir = null;
        if (options) {
            this._rootOptions = options;
        }
        else {
            this._rootOptions = new options_1.Options();
        }
        this._setupOutputDir();
        this._rootLogger = this.sublogger(name);
    }
    get rootDir() {
        return this._rootDir;
    }
    get logger() {
        return this._rootLogger;
    }
    get options() {
        return this._rootOptions;
    }
    close() {
        for (let key in this._subloggers) {
            let logger = this._subloggers[key];
            logger.close();
        }
        this._subloggers = {};
    }
    sublogger(name) {
        if (name in this._subloggers) {
            return this._subloggers[name];
        }
        let logger = this._create(name);
        this._subloggers[name] = logger;
        return logger;
    }
    _setupOutputDir() {
        if (!this._rootOptions.enableFile) {
            return;
        }
        let dir = 'logs';
        if (this._rootOptions.path) {
            dir = this._rootOptions.path;
        }
        if (this._rootOptions.cleanOnStart) {
            (0, fs_extra_1.emptyDirSync)(dir);
        }
        (0, file_utils_1.ensureDirectory)(dir);
        this._rootDir = dir;
    }
    _create(name) {
        let logger = new pino_1.PinoLogger(this, name);
        logger.setup(this._rootOptions);
        logger.info('Initialized');
        return logger;
    }
}
exports.RootLogger = RootLogger;
//# sourceMappingURL=root.js.map