"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BlockingResolver = void 0;
var the_lodash_1 = __importDefault(require("the-lodash"));
var promise_1 = require("./promise");
var BlockingResolver = /** @class */ (function () {
    function BlockingResolver(cb) {
        this._value = null;
        this._isBusy = false;
        this._resolveWaiters = [];
        this._rejectWaiters = [];
        this._cb = cb;
    }
    BlockingResolver.prototype.reset = function () {
        this._value = null;
    };
    BlockingResolver.prototype.resolve = function () {
        var _this = this;
        if (the_lodash_1.default.isNotNullOrUndefined(this._value)) {
            return Promise.resolve(this._value);
        }
        return promise_1.MyPromise.construct(function (resolve, reject) {
            _this._resolveWaiters.push(resolve);
            _this._rejectWaiters.push(reject);
            if (_this._isBusy) {
                return;
            }
            _this._isBusy = true;
            promise_1.MyPromise.try(_this._cb)
                .then(function (result) {
                _this._isBusy = false;
                var waiters = _this._resolveWaiters;
                _this._resolveWaiters = [];
                _this._rejectWaiters = [];
                _this._value = result;
                for (var _i = 0, waiters_1 = waiters; _i < waiters_1.length; _i++) {
                    var waiter = waiters_1[_i];
                    waiter(result);
                }
                return null;
            })
                .catch(function (reason) {
                _this._isBusy = false;
                var waiters = _this._rejectWaiters;
                _this._resolveWaiters = [];
                _this._rejectWaiters = [];
                for (var _i = 0, waiters_2 = waiters; _i < waiters_2.length; _i++) {
                    var waiter = waiters_2[_i];
                    waiter(reason);
                }
                return null;
            });
        });
    };
    return BlockingResolver;
}());
exports.BlockingResolver = BlockingResolver;
//# sourceMappingURL=blocking-resolver.js.map