export type Resolvable<T> = T | PromiseLike<T>;
export type MapperFunction<T, R> = (item: T) => R | Promise<R>;
export interface ExecuteOptions {
    concurrency?: number;
    unlimitedRetries?: boolean;
    retryCount?: number;
    coolDownOnFailure?: boolean;
    initRetryDelay?: number;
    maxRetryDelay?: number;
    retryDelayCoeff?: number;
    waitCompleteBeforeExit?: boolean;
}
export declare class CExecuteOptions {
    concurrency: number;
    unlimitedRetries: boolean;
    retryCount: number;
    coolDownOnFailure: boolean;
    initRetryDelay: number;
    maxRetryDelay: number;
    retryDelayCoeff: number;
    waitCompleteBeforeExit: boolean;
}
export interface RetryOptions {
    unlimitedRetries?: boolean;
    retryCount?: number;
    initRetryDelay?: number;
    maxRetryDelay?: number;
    retryDelayCoeff?: number;
    canContinueCb?: (reason: any) => boolean | Promise<boolean>;
}
export declare class CRetryOptions {
    unlimitedRetries: boolean;
    retryCount: number;
    initRetryDelay: number;
    maxRetryDelay: number;
    retryDelayCoeff: number;
    canContinueCb?: (reason: any) => boolean | Promise<boolean>;
    retryTimeout: number;
    failureCount: number;
}
export declare class MyPromise {
    static execute<T, R>(items: T[] | null, action: MapperFunction<T, R>, options?: ExecuteOptions): Promise<R[]>;
    static parallel<T, R>(items: T[] | null, action: MapperFunction<T, R>): Promise<R[]>;
    static serial<T, R>(items: T[] | null, action: MapperFunction<T, R>): Promise<R[]>;
    static try<T>(action: () => Resolvable<T>): Promise<T>;
    static retry<T>(action: () => Resolvable<T>, options?: RetryOptions): Promise<T>;
    private static _promiseRetryLoop;
    private static _promiseRetryHandleFailure;
    private static _promiseRetryWithTimeout;
    static delay(timeoutMs: number): Promise<void>;
    static timeout(timeoutMs: number): Promise<void>;
    static construct<T = void>(callback: (resolve: (thenableOrResult: Resolvable<T>) => void, reject: (error?: any) => void) => void): Promise<T>;
}
//# sourceMappingURL=promise.d.ts.map